@@ -7,10 +7,8 @@
  *	create_config_popup()
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <Xm/Xm.h>
 #include <Xm/DialogS.h>
@@ -26,9 +24,13 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-static void done_callback(), toggle_callback(), mailer_callback(),
-	    timeout_callback(), ewarn_prog_callback(), lwarn_prog_callback(),
-	    alarm_prog_callback();
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void toggle_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void ewarn_prog_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void lwarn_prog_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void alarm_prog_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void mailer_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void timeout_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -52,7 +54,7 @@ static Widget		timeout;	/* max lifetime of notifiers */
  * It's too much trouble to keep them for next time.
  */
 
-void destroy_config_popup()
+void destroy_config_popup(void)
 {
 	char		*string;	/* contents of text widget */
 	char		*p;		/* for stripping leading blanks */
@@ -94,6 +96,7 @@ void destroy_config_popup()
 		XTDESTROYWIDGET(shell);
 		have_shell = FALSE;
 		mainlist->modified = TRUE;
+		write_mainlist();
 	}
 }
 
@@ -103,7 +106,7 @@ void destroy_config_popup()
  * initialized with data from config.
  */
 
-void create_config_popup()
+void create_config_popup(void)
 {
 	Widget			form, frame, form2, rowcol, w;
 	Arg			args[20];
@@ -112,12 +115,12 @@ void create_config_popup()
 	int			len;
 
 	destroy_config_popup();
-	len = XTextWidth(font[FONT_STD], "Early warning:", 14);
+	len = XTextWidth(font[FONT_STD], _("Early warning:"), 14);
 
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmDO_NOTHING);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("Alarm Options",
+	shell = XtCreatePopupShell(_("Alarm Options"),
 			applicationShellWidgetClass, toplevel, args, n);
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
@@ -126,7 +129,8 @@ void create_config_popup()
 	set_icon(shell, 1);
 	form = XtCreateManagedWidget("cnfform1", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback, help_callback, (XtPointer)"opt");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"opt");
 
 							/*-- early warn --*/
 	n = 0;
@@ -141,8 +145,8 @@ void create_config_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("cnfform2", xmFormWidgetClass,
 			frame, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback,
-					help_callback, (XtPointer)"opt_early");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"opt_early");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -150,7 +154,7 @@ void create_config_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		len);			n++;
-	w = XtCreateManagedWidget("Early warning:", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Early warning:"), xmLabelWidgetClass,
 			form2, args, n);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -165,23 +169,23 @@ void create_config_popup()
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.ewarn_window);	n++;
-	w = XtCreateManagedWidget("Green window", xmToggleButtonWidgetClass,
-		rowcol, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-				toggle_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_early_w");
+	w = XtCreateManagedWidget(_("Green window"), xmToggleButtonWidgetClass,
+			rowcol, args, n);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			toggle_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_early_w");
 
 	n = 0;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.ewarn_mail);	n++;
-	w = XtCreateManagedWidget("Send mail", xmToggleButtonWidgetClass,
-		rowcol, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-				toggle_callback, (XtPointer)1);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_early_m");
+	w = XtCreateManagedWidget(_("Send mail"), xmToggleButtonWidgetClass,
+			rowcol, args, n);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			toggle_callback, (XtPointer)1);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_early_m");
 
 	form2 = XtCreateManagedWidget("cnfform3", xmFormWidgetClass,
 			rowcol, NULL, 0);
@@ -191,12 +195,12 @@ void create_config_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.ewarn_exec);	n++;
-	w = XtCreateManagedWidget("Execute", xmToggleButtonWidgetClass,
-		form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-				toggle_callback, (XtPointer)2);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_early_x");
+	w = XtCreateManagedWidget(_("Execute"), xmToggleButtonWidgetClass,
+			form2, args, n);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			toggle_callback, (XtPointer)2);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_early_x");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -212,10 +216,10 @@ void create_config_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	ewarn_prog = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(ewarn_prog, XmNactivateCallback,
-				ewarn_prog_callback, (XtPointer)NULL);
-	XtAddCallback(ewarn_prog, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_early_x");
+	XtAddCallback(ewarn_prog, XmNactivateCallback, (XtCallbackProc)
+			ewarn_prog_callback, (XtPointer)NULL);
+	XtAddCallback(ewarn_prog, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_early_x");
 	if (config.ewarn_prog)
 		print_text_button(ewarn_prog, "%s", config.ewarn_prog);
 
@@ -233,8 +237,8 @@ void create_config_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("cnfform4", xmFormWidgetClass,
 			frame, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback,
-					help_callback, (XtPointer)"opt_late");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_late");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -242,7 +246,7 @@ void create_config_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		len);			n++;
-	w = XtCreateManagedWidget("Late warning:", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Late warning:"), xmLabelWidgetClass,
 			form2, args, n);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -257,23 +261,23 @@ void create_config_popup()
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.lwarn_window);	n++;
-	w = XtCreateManagedWidget("Yellow window", xmToggleButtonWidgetClass,
-		rowcol, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-				toggle_callback, (XtPointer)3);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_late_w");
+	w = XtCreateManagedWidget(_("Yellow window"),
+			xmToggleButtonWidgetClass, rowcol, args, n);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			toggle_callback, (XtPointer)3);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_late_w");
 
 	n = 0;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.lwarn_mail);	n++;
-	w = XtCreateManagedWidget("Send mail", xmToggleButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Send mail"), xmToggleButtonWidgetClass,
 			rowcol, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-				toggle_callback, (XtPointer)4);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_late_m");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			toggle_callback, (XtPointer)4);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_late_m");
 
 	form2 = XtCreateManagedWidget("cnfform5", xmFormWidgetClass,
 			rowcol, NULL, 0);
@@ -283,12 +287,12 @@ void create_config_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.lwarn_exec);	n++;
-	w = XtCreateManagedWidget("Execute", xmToggleButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Execute"), xmToggleButtonWidgetClass,
 			form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-				toggle_callback, (XtPointer)5);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_late_x");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			toggle_callback, (XtPointer)5);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_late_x");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -304,10 +308,10 @@ void create_config_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	lwarn_prog = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(lwarn_prog, XmNactivateCallback,
-				lwarn_prog_callback, (XtPointer)NULL);
-	XtAddCallback(lwarn_prog, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_late_x");
+	XtAddCallback(lwarn_prog, XmNactivateCallback, (XtCallbackProc)
+			lwarn_prog_callback, (XtPointer)NULL);
+	XtAddCallback(lwarn_prog, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_late_x");
 	if (config.lwarn_prog)
 		print_text_button(lwarn_prog, "%s", config.lwarn_prog);
 
@@ -325,8 +329,8 @@ void create_config_popup()
 			form, args, n);
 	form2 = XtCreateManagedWidget("cnfform6", xmFormWidgetClass,
 			frame, NULL, 0);
-	XtAddCallback(form2, XmNhelpCallback,
-					help_callback, (XtPointer)"opt_alarm");
+	XtAddCallback(form2, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_alarm");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -334,7 +338,7 @@ void create_config_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		len);			n++;
-	w = XtCreateManagedWidget("Alarm:", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Alarm:"), xmLabelWidgetClass,
 			form2, args, n);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -349,23 +353,23 @@ void create_config_popup()
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.alarm_window);	n++;
-	w = XtCreateManagedWidget("Red window", xmToggleButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Red window"), xmToggleButtonWidgetClass,
 			rowcol, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-				toggle_callback, (XtPointer)6);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_alarm_a");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			toggle_callback, (XtPointer)6);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_alarm_a");
 
 	n = 0;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.alarm_mail);	n++;
-	w = XtCreateManagedWidget("Send mail", xmToggleButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Send mail"), xmToggleButtonWidgetClass,
 			rowcol, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-				toggle_callback, (XtPointer)7);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_alarm_m");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			toggle_callback, (XtPointer)7);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_alarm_m");
 
 	form2 = XtCreateManagedWidget("cnfform7", xmFormWidgetClass,
 			rowcol, NULL, 0);
@@ -375,12 +379,12 @@ void create_config_popup()
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		config.alarm_exec);	n++;
-	w = XtCreateManagedWidget("Execute", xmToggleButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Execute"), xmToggleButtonWidgetClass,
 			form2, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback,
-				toggle_callback, (XtPointer)8);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_alarm_x");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			toggle_callback, (XtPointer)8);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_alarm_x");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -396,10 +400,10 @@ void create_config_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	alarm_prog = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form2, args, n);
-	XtAddCallback(alarm_prog, XmNactivateCallback,
-				alarm_prog_callback, (XtPointer)NULL);
-	XtAddCallback(alarm_prog, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_alarm_x");
+	XtAddCallback(alarm_prog, XmNactivateCallback, (XtCallbackProc)
+			alarm_prog_callback, (XtPointer)NULL);
+	XtAddCallback(alarm_prog, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_alarm_x");
 	if (config.alarm_prog)
 		print_text_button(alarm_prog, "%s", config.alarm_prog);
 
@@ -410,10 +414,10 @@ void create_config_popup()
 	XtSetArg(args[n], XmNtopOffset,		16);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	w = XtCreateManagedWidget("Mailer:", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Mailer:"), xmLabelWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_mailer");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_mailer");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -429,10 +433,10 @@ void create_config_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	mailer = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form, args, n);
-	XtAddCallback(mailer, XmNactivateCallback,
-				mailer_callback, (XtPointer)NULL);
-	XtAddCallback(mailer, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_mailer");
+	XtAddCallback(mailer, XmNactivateCallback, (XtCallbackProc)
+			mailer_callback, (XtPointer)NULL);
+	XtAddCallback(mailer, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_mailer");
 	if (config.mailer)
 		print_text_button(mailer, "%s", config.mailer);
 
@@ -443,10 +447,10 @@ void create_config_popup()
 	XtSetArg(args[n], XmNtopOffset,		16);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	w = XtCreateManagedWidget("Windows time out after", xmLabelWidgetClass,
-			form, args, n);
-	XtAddCallback(w, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_timeout");
+	w = XtCreateManagedWidget(_("Windows time out after"),
+			xmLabelWidgetClass, form, args, n);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_timeout");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -462,10 +466,10 @@ void create_config_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	timeout = XtCreateManagedWidget("", xmTextFieldWidgetClass,
 			form, args, n);
-	XtAddCallback(timeout, XmNactivateCallback,
-				timeout_callback, (XtPointer)NULL);
-	XtAddCallback(timeout, XmNhelpCallback,
-				help_callback, (XtPointer)"opt_timeout");
+	XtAddCallback(timeout, XmNactivateCallback, (XtCallbackProc)
+			timeout_callback, (XtPointer)NULL);
+	XtAddCallback(timeout, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_timeout");
 	if (config.wintimeout > 59)
 		print_text_button(timeout, "%s",
 					mktimestring(config.wintimeout, TRUE));
@@ -480,12 +484,12 @@ void create_config_popup()
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback,
-					done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,
-					help_callback, (XtPointer)"opt_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"opt_done");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -497,16 +501,17 @@ void create_config_popup()
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, help_callback, (XtPointer)"opt");
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)"opt");
-
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)help_callback,
+			(XtPointer)"opt");
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)help_callback,
+			(XtPointer)"opt");
 
 	XtPopup(shell, XtGrabNone);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
 	have_shell = TRUE;
 }
 
@@ -517,20 +522,20 @@ void create_config_popup()
  */
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_config_popup();
 }
 
 
 /*ARGSUSED*/
-static void toggle_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void toggle_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	switch(item) {
 	  case 0:	config.ewarn_window = data->set;	break;
@@ -547,10 +552,10 @@ static void toggle_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void ewarn_prog_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void ewarn_prog_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
@@ -562,10 +567,10 @@ static void ewarn_prog_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void lwarn_prog_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void lwarn_prog_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
@@ -577,10 +582,10 @@ static void lwarn_prog_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void alarm_prog_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void alarm_prog_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
@@ -592,10 +597,10 @@ static void alarm_prog_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void mailer_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void mailer_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
@@ -607,10 +612,10 @@ static void mailer_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void timeout_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void timeout_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	char				*text = XmTextFieldGetString(widget);
 
