@@ -1,7 +1,12 @@
+#ifndef _CONFIG_H
+#define _CONFIG_H
+
+#include "linuxjunk.h"
+
 /*
  * if defined, compile in xmbase-grok support, mainly grok database access
  * code. You need grok 1.4 and up to really use this. See my homepage to find
- * out about the grok database manager (http://www.in-berlin.de/User/bitrot).
+ * out about the grok database manager (http://www.bitrot.de/).
  */
 
 #define PLANGROK
@@ -12,18 +17,31 @@
  * X and motif stuff.
  */
 
-#define DB_FILE		".dayplan"		/* public file name, no path */
-#define DB_PUB_PATH	"~/.dayplan"		/* public appts & config */
-#define DB_PRIV_PATH	"~/.dayplan.priv"	/* private appointments */
-#define HOLIDAY_PATH	"~/.holiday"		/* holiday database */
-#define HOLIDAY_NAME	"holiday"		/* global holiday dbase (LIB)*/
-#define LOCK_PATH	"/tmp/.pland%d"	/* daemon lock/pid file, %d is uid */
-#define PLAN_PATH	"/tmp/.plan%d"	/* plan lock/pid file, %d is uid */
-#define HELP_FN		"plan.help"	/* help text file */
-#define DAEMON_FN	"pland"		/* daemon program */
-#define ALARM_FN	"notifier"	/* program that shows alarm popup */
+#ifndef PLANLOCK			 /* defaults for cc -D options */
+#define PLANLOCK	/tmp/.plan%d
+#endif
+#ifndef PLANDLOCK			 /* defaults for cc -D options */
+#define PLANDLOCK	/tmp/.pland%d
+#endif
+#ifndef DOFORK				 /* is -f or -F default? */
+#define DOFORK		TRUE
+#endif
+
+#ifdef PLANHOME
+#define DB_PUB_PATH	"~/" PLANHOME "/dayplan"
+#define DB_PRIV_PATH	"~/" PLANHOME "/dayplan.priv"
+#define HOLIDAY_PATH	"~/" PLANHOME "/holiday"
+#else
+#define DB_PUB_PATH	"~/.dayplan"	 /* public appts & config */
+#define DB_PRIV_PATH	"~/.dayplan.priv"/* private appointments */
+#define HOLIDAY_PATH	"~/.holiday"	 /* holiday database */
+#endif
+#define HOLIDAY_NAME	"holiday"	 /* global holiday dbase (LIB)*/
+#define HELP_FN		"plan.help"	 /* help text file */
+#define DAEMON_FN	"pland"		 /* daemon program */
+#define ALARM_FN	"notifier"	 /* program that shows alarm popup */
 #define PS_SPOOLER	"lp"
-#define DEFAULTPATH	"/usr/local/lib:/usr/local/bin:/bin:/usr/bin:/usr/sbin:/usr/ucb:/usr/bsd:/usr/bin/X11:.:../misc"
+#define DEFAULTPATH	"/usr/local/lib:/usr/local/bin:/bin:/usr/bin:/usr/sbin:/usr/ucb:/usr/bsd:/usr/bin/X11:/usr/freeware/bin:/usr/freeware/lib:.:../misc"
 
 
 #if defined(XlibSpecificationRelease) && defined(sgi) || defined(linux)
@@ -45,9 +63,6 @@
 #ifndef PID_T
 #define PID_T		pid_t		/* from types.h, see -DPID_T */
 #endif
-#ifndef S_IFDIR				/* some Linuces hide this */
-#define S_IFDIR		040000		/* I'll hate myself for this */
-#endif					/* in the morning... */
 
 #define BOOL		int
 #define TRUE		1
@@ -88,6 +103,8 @@ struct config {			/* global configuration data */
 	BOOL		nomonthshadow;	/* month only shows days in the month*/
 	BOOL		share_mainwin;	/* all views go into mainwindow */
 	BOOL		resize_mainwin;	/* auto-resize mainwin on view chg */
+	BOOL		webplan;	/* called from cgi-bin, no user */
+	char		*webplan_host;	/* called from cgi-bin, netplan host */
 
 	BOOL		sunday_first;	/* TRUE for US style, else European */
 	BOOL		ampm;		/* TRUE for US style, else European */
@@ -97,9 +114,11 @@ struct config {			/* global configuration data */
 	BOOL		weeknum;	/* TRUE prints week numbers */
 	BOOL		gpsweek;	/* TRUE prints GPS week numbers */
 	BOOL		nopast;		/* TRUE skips todays past daybox notes*/
+	BOOL		insecure_script;/* TRUE lets pland run netplan scripts*/
 	BOOL		weekwarn;	/* TRUE shows warnings in week view */
 	BOOL		weekuser;	/* TRUE shows user names in week bars*/
 	BOOL		fullweek;	/* TRUE if week #1 is the one w 7 days*/
+	BOOL		thu_week;	/* TRUE if week #1 is the one w Thursd*/
 	BOOL		colorcode_m;	/* TRUE shows user color in month view*/
 	BOOL		owner_only;	/* TRUE is only owner can write file */
 	BOOL		ownonly;	/* TRUE if only own appts in apptmenu*/
@@ -114,8 +133,8 @@ struct config {			/* global configuration data */
 	int		dst_begin_time;	/* time of day dst_begin */
 	int		dst_end_time;	/* time of day dst_end */
 
-	int		early_time;	/* default # of secs for early warn */
-	int		late_time;	/* default # of secs for late warn */
+	time_t		early_time;	/* default # of secs for early warn */
+	time_t		late_time;	/* default # of secs for late warn */
 
 	int		calbox_xs[2];	/* main window: width of one day */
 	int		calbox_ys[2];	/* main window: height of one day */
@@ -181,6 +200,8 @@ struct config {			/* global configuration data */
 	BOOL		pr_omit_appts;	/* TRUE: omit all apts from printout */
 	BOOL		pr_omit_priv;	/* TRUE: omit private appts */
 	BOOL		pr_omit_others; /* FALSE: omit everyone else's appts */ 
+	int		pr_color;	/* TRUE: generate color PostScript */
+	char		*language;	/* 0=English, or "german", "french"..*/
 };
 
 
@@ -216,6 +237,7 @@ struct entry {			/* one day-schedule entry */
 	BOOL		hide_in_w;	/* don't show in week view */
 	BOOL		hide_in_o;	/* don't show in year overview */
 	BOOL		hide_in_d;	/* don't show in day view */
+	BOOL		todo;		/* todo item, auto-advance */
 	char		acolor;		/* text col: 0=std, 1..8=HBLACK.. */
 					/* --- rest is for internal use --- */
 	char		triggered;	/* 0=none, 1=early, 2=late, 3=time */
@@ -312,3 +334,4 @@ struct host {
 	int		fd;		/* socket connection to server */
 	XtInputId	x_id;		/* registered X event */
 };
+#endif /* _CONFIG_H */
