@@ -43,21 +43,21 @@ char *monthname[] =	    { "Janvier", "Fvrier", "Mars", "Avril", "Mai",
  * return some sensible string representation of a date (no time)
  */
 
-char *mkdatestring(time)
-	time_t			time;		/* date in seconds */
+char *mkdatestring(
+	time_t		time)		/* date in seconds */
 {
-	static char		buf[40];	/* string representation */
-	struct tm		*tm;		/* time to m/d/y conv */
+	static char	buf[40];	/* string representation */
+	struct tm	*tm;		/* time to m/d/y conv */
 
 	tm = time_to_tm(time);
 	if (config.mmddyy)
 		sprintf(buf, "%s, %d/%d/%02d",
-					weekday_name[(tm->tm_wday+6)%7],
+					_(weekday_name[(tm->tm_wday+6)%7]),
 					tm->tm_mon+1, tm->tm_mday,
 					tm->tm_year % 100);
 	else
 		sprintf(buf, "%s, %d.%d.%02d",
-					weekday_name[(tm->tm_wday+6)%7],
+					_(weekday_name[(tm->tm_wday+6)%7]),
 					tm->tm_mday, tm->tm_mon+1,
 					tm->tm_year % 100);
 	return(buf);
@@ -68,12 +68,12 @@ char *mkdatestring(time)
  * return some sensible string representation of a time (no date)
  */
 
-char *mktimestring(time, dur)
-	time_t			time;		/* date in seconds */
-	BOOL			dur;		/* duration, not time-of-day */
+char *mktimestring(
+	time_t		time,		/* date in seconds */
+	BOOL		dur)		/* duration, not time-of-day */
 {
-	static char		buf[40];	/* string representation */
-	int			hour, min;	/* time components */
+	static char	buf[40];	/* string representation */
+	int		hour, min;	/* time components */
 
 	if (!dur)
 		time %= 86400;
@@ -97,17 +97,17 @@ char *mktimestring(time, dur)
  * Doesn't know about alpha month names yet.
  */
 
-time_t parse_datestring(text, dtime)
-	char			*text;		/* input string */
-	time_t			dtime;		/* appt start time, 0=today */
+time_t parse_datestring(
+	char		*text,		/* input string */
+	time_t		dtime)		/* appt start time, 0=today */
 {
-	time_t			today;		/* current date in seconds */
-	struct tm		*tm;		/* today's date */
-	long			num[3];		/* m,d,y or d,m,y */
-	int			nnum;		/* how many numbers in text */
-	long			i;		/* tmp counter */
-	char			*p;		/* text scan pointer */
-	char			buf[10];	/* lowercase weekday name */
+	time_t		today;		/* current date in seconds */
+	struct tm	*tm;		/* today's date */
+	long		num[3];		/* m,d,y or d,m,y */
+	int		nnum;		/* how many numbers in text */
+	long		i;		/* tmp counter */
+	char		*p;		/* text scan pointer */
+	char		buf[10];	/* lowercase weekday name */
 
 	today  = get_time();				/* today's date */
 	today -= today % 86400;
@@ -149,7 +149,7 @@ time_t parse_datestring(text, dtime)
 				- atoi(text+1) * 86400);
 							/* weekday name? */
 	for (i=0; i < 7; i++) {
-		strcpy(buf, weekday_name[i]);
+		strcpy(buf, _(weekday_name[i]));
 		*buf += 'a' - 'A';
 		if (!strncmp(buf, text, strlen(buf)))
 			break;
@@ -212,18 +212,18 @@ time_t parse_datestring(text, dtime)
  * duration is expected, interpret "0"..."23" as 0:00...23:00, instead of 0:23
  */
 
-time_t parse_timestring(text, duration)
-	char			*text;		/* input string */
-	BOOL			duration;	/* time-of-day or duration? */
+time_t parse_timestring(
+	char		*text,		/* input string */
+	BOOL		duration)	/* time-of-day or duration? */
 {
-	long			num[3];		/* h,m,s */
-	int			nnum;		/* how many numbers in text */
-	int			ndigits;	/* digit counter */
-	char			*p = text;	/* text pointer */
-	int			i;		/* text index, backwards*/
-	char			ampm = 0;	/* 0, 'a', or 'p' */
-	char			sign = 0;	/* 0, '+', or '-' */
-	int			h=0, m=0, s=0;	/* hours, minutes, seconds */
+	long		num[3];		/* h,m,s */
+	int		nnum;		/* how many numbers in text */
+	int		ndigits;	/* digit counter */
+	char		*p = text;	/* text pointer */
+	int		i;		/* text index, backwards*/
+	char		ampm = 0;	/* 0, 'a', or 'p' */
+	char		sign = 0;	/* 0, '+', or '-' */
+	int		h=0, m=0, s=0;	/* hours, minutes, seconds */
 
 	while (*p == ' ' || *p == '\t')
 		p++;
@@ -288,15 +288,15 @@ time_t parse_timestring(text, duration)
  * parse string with both date and time
  */
 
-time_t parse_datetimestring(text)
-	char			*text;		/* input string */
+time_t parse_datetimestring(
+	char		*text)		/* input string */
 {
-	struct tm		tm1, tm2;	/* for adding date and time */
-	time_t			t;		/* parsed time */
+	struct tm	tm1, tm2;	/* for adding date and time */
+	time_t		t;		/* parsed time */
 
 	while (*text == ' ' || *text == '\t')
 		text++;
-	t = parse_datestring(text);
+	t = parse_datestring(text, 0);
 	tm1 = *time_to_tm(t);
 	while (*text && *text != ' ' && *text != '\t')
 		text++;
@@ -317,18 +317,17 @@ time_t parse_datetimestring(text)
  * replace the usual popup. Not as pretty, but faster.
  */
 
-void parse_warnstring(text, early, late, noalarm)
-	char			*text;		/* input string */
-	time_t			*early, *late;	/* early and late in minutes */
-	BOOL			*noalarm;	/* final alarm too? */
+void parse_warnstring(
+	char		*text,		/* input string */
+	time_t		*early,		/* early warning in minutes */
+	time_t		*late,		/* late warning in minutes */
+	BOOL		*noalarm)	/* final alarm too? */
 {
-	long			num[2], tmp;	/* early, late, swap temp */
-	int			nnum;		/* how many numbers in text */
-	char			*p;		/* text scan pointer */
+	long		num[2], tmp;	/* early, late, swap temp */
+	int		nnum;		/* how many numbers in text */
+	char		*p;		/* text scan pointer */
 
 	if (*text == '=') {
-		if (!config.late_time && !config.early_time)
-			config.late_time = 5*60;
 		*late    = config.late_time;
 		*early   = config.early_time;
 		*noalarm = FALSE;
@@ -352,6 +351,4 @@ void parse_warnstring(text, early, late, noalarm)
 	}
 	*late  = num[1] * 60;
 	*early = num[0] * 60;
-	if (num[1]) config.late_time  = *late;
-	if (num[0]) config.early_time = *early;
 }
