@@ -10,10 +10,8 @@
  * first the structure is called "struct week".
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <varargs.h>
 #include <Xm/Xm.h>
@@ -33,9 +31,11 @@
 #include "cal.h"
 
 extern MOUSE locate_in_day_calendar();
-static void resize_canvas();
-static void done_callback(), edit_callback(), sync_callback();
-static void day_callback(), prev_callback(), next_callback();
+static void prev_callback(Widget, int, XmToggleButtonCallbackStruct *);
+static void next_callback(Widget, int, XmToggleButtonCallbackStruct *);
+static void done_callback(Widget, int, XmToggleButtonCallbackStruct *);
+static void edit_callback(Widget, int, XmToggleButtonCallbackStruct *);
+static void sync_callback(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern struct config	config;		/* global configuration data */
@@ -52,7 +52,7 @@ static Widget		shell;		/* week window, 0 if none */
  * destroy the day menu. Remove it from the screen, and destroy its widgets.
  */
 
-void destroy_day_menu()
+void destroy_day_menu(void)
 {
 	if (shell) {
 		if (!parent_form)
@@ -70,8 +70,8 @@ void destroy_day_menu()
  * create the day menu for the day beginning on curr_day.
  */
 
-void create_day_menu(parent)
-	Widget		parent;
+void create_day_menu(
+	Widget		parent)
 {
 	Arg		args[15];
 	int		n;
@@ -81,12 +81,13 @@ void create_day_menu(parent)
 	build_day(FALSE, FALSE);
 
 	form = create_view_form(&shell, parent_form = parent, 'd',
-				day.canvas_xs, day.canvas_ys, "Day View");
+				day.canvas_xs, day.canvas_ys, _("Day View"));
 	if (!form) {
 		draw_day_calendar(NULL);
 		return;
 	}
-	XtAddCallback(form, XmNhelpCallback, help_callback, (XtPointer)"day");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day");
 
 							/*-- buttons --*/
 	n = 0;
@@ -94,24 +95,26 @@ void create_day_menu(parent)
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		50);			n++;
-	w = XtCreateManagedWidget("Prev", xmPushButtonWidgetClass,
+	XtSetArg(args[n], XmNwidth,		60);			n++;
+	w = XtCreateManagedWidget(_("Prev"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, prev_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"day_prev");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			prev_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"day_prev");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	w);			n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		50);			n++;
-	w = XtCreateManagedWidget("Next", xmPushButtonWidgetClass,
+	XtSetArg(args[n], XmNwidth,		60);			n++;
+	w = XtCreateManagedWidget(_("Next"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback,next_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,    help_callback, (XtPointer)
-								"day_next");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			next_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day_next");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -119,11 +122,12 @@ void create_day_menu(parent)
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"day_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"day_done");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
@@ -131,10 +135,12 @@ void create_day_menu(parent)
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback,help_callback, (XtPointer)"day");
-	XtAddCallback(w, XmNhelpCallback,    help_callback, (XtPointer)"day");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -143,11 +149,12 @@ void create_day_menu(parent)
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Edit", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Edit"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, edit_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"day_edit");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			edit_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"day_edit");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -157,11 +164,12 @@ void create_day_menu(parent)
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
 	XtSetArg(args[n], XmNsensitive,		!all_files_served());	n++;
-	w = XtCreateManagedWidget("Sync", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Sync"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, sync_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)
-								"day_sync");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			sync_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"day_sync");
 
 							/*--- infotext --- */
 	n = 0;
@@ -213,7 +221,7 @@ void create_day_menu(parent)
 	if (!parent) {
 		XtPopup(shell, XtGrabNone);
 		closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-		XmAddWMProtocolCallback(shell, closewindow,
+		XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
 				done_callback, (XtPointer)shell);
 	}
 }
@@ -225,11 +233,13 @@ void create_day_menu(parent)
  * Make it a bit larger for the shadow.
  */
 
-static void resize_canvas(shell, scroll, canvas, xs, ys)
-	Widget		shell;		/* shell with the DrawingArea */
-	Widget		scroll;		/* scrolling area around canvas */
-	Widget		canvas;		/* DrawingArea */
-	int		xs, ys;		/* new DrawingArea size */
+#if 0
+static void resize_canvas(
+	Widget		shell,		/* shell with the DrawingArea */
+	Widget		scroll,		/* scrolling area around canvas */
+	Widget		canvas,		/* DrawingArea */
+	int		xs,		/* new DrawingArea size */
+	int		ys)
 {
 	Dimension	sh_xs, sh_ys;	/* previous size of the shell */
 	Dimension	can_xs, can_ys;	/* previous size of the canvas */
@@ -243,6 +253,7 @@ static void resize_canvas(shell, scroll, canvas, xs, ys)
 	set_widget_size(shell,  sh_xs - can_xs + xs,
 				sh_ys - can_ys + ys);
 }
+#endif
 
 
 /*-------------------------------------------------- callbacks --------------*/
@@ -251,10 +262,10 @@ static void resize_canvas(shell, scroll, canvas, xs, ys)
  */
 
 /*ARGSUSED*/
-static void prev_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void prev_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	curr_day -= 86400;
 	build_day(FALSE, FALSE);
@@ -263,10 +274,10 @@ static void prev_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void next_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void next_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	curr_day += 86400;
 	build_day(FALSE, FALSE);
@@ -275,10 +286,10 @@ static void next_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (parent_form)
 		create_view('m');
@@ -288,10 +299,10 @@ static void done_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void edit_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void edit_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	create_list_popup(mainlist, curr_day, config.day_ndays*86400,
 					0, (struct entry *)0, 0, 0);
@@ -299,10 +310,10 @@ static void edit_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void sync_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void sync_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (!can_edit_appts())
 		return;
