@@ -19,10 +19,8 @@
  *					sense at the moment.
  */
 
-#ifndef MIPS
-#include <stdlib.h>
-#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
 #include <Xm/Xm.h>
 #include <Xm/Form.h>
@@ -35,11 +33,6 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-
-extern void		destroy_user_sel_popup();
-extern void		create_user_sel_popup();
-static void		user_sel_callback(), abort_callback();
-
 extern Display		*display;	/* everybody uses the same server */
 extern Pixel		color[NCOLS];	/* colors: COL_* */
 extern struct config	config;		/* global configuration data */
@@ -49,6 +42,7 @@ extern struct user	*user;		/* user list (from file_r.c) */
 extern BOOL		interactive;	/* interactive or fast appt entry? */
 extern int		curr_month;	/* month being displayed, 0..11 */
 extern int		curr_year;	/* year being displayed, since 1900 */
+extern time_t		last_x_timer;	/* when did last X timer happen? */
 
 struct edit		edit;		/* info about entry being edited */
 
@@ -59,8 +53,8 @@ struct edit		edit;		/* info about entry being edited */
  * been installed by got_entry_press.
  */
 
-static void got_new_user(newuser)
-	int	newuser;
+static void got_new_user(
+	int	newuser)
 {
 	int	olduser;
 
@@ -83,11 +77,12 @@ static void got_new_user(newuser)
  * user clicked on one of the buttons in the appointment entry menu
  */
 
-void got_entry_press(lw, x, y, on, shift)
-	struct listmenu		*lw;		/* which menu */
-	int			x, y;		/* which column/row */
-	int			on;		/* enable radio but: on/off */
-	int			shift;		/* arrow but: 1=shift key */
+void got_entry_press(
+	struct listmenu		*lw,		/* which menu */
+	int			x,		/* which column/row */
+	int			y,
+	int			on,		/* enable radio but: on/off */
+	int			shift)		/* arrow but: 1=shift key */
 {
 	register struct entry	*ep;		/* affected entry */
 	int			num;		/* number of entries so far */
@@ -99,10 +94,26 @@ void got_entry_press(lw, x, y, on, shift)
 	num = lw->sublist ? lw->sublist->nentries : 0;
 	if (y-1 > num)					/* illegal entry? */
 		return;
-	if (y-1 < num && !prepare_for_modify(lw->sublist->entry[y-1]->user)) {
-		if (x == SC_ENABLE)
-			XtVaSetValues(lw->entry[y][x], XmNset, !on, NULL);
-		return;
+	if (y-1 < num) {
+		ep = lw->sublist->entry[y-1];
+		if (user[name_to_user(ep->user)].readonly)
+			switch(x) {			/* readonly: show */
+			  case SC_MESSAGE:
+				create_text_popup(_("Message"),
+						&ep->message, x, TRUE);
+				return;
+
+			  case SC_SCRIPT:
+				if (!ep->notime)
+					create_text_popup(_("Shell Script"),
+						&ep->script, x, TRUE);
+				return;
+			}
+		if (!prepare_for_modify(lw->sublist->entry[y-1]->user)) {
+			if (x == SC_ENABLE)
+				XtVaSetValues(lw->entry[y][x], XmNset, !on, 0);
+			return;
+		}
 	}
 	if (edit.editing && (edit.y != y || edit.menu != lw))
 		confirm_new_entry();
@@ -113,19 +124,22 @@ void got_entry_press(lw, x, y, on, shift)
 			clone_entry(&edit.entry, lw->sublist->entry[y-1]);
 			if (!server_entry_op(&edit.entry, 'l')) {
 				create_error_popup(lw->shell, 0, "%s\n%s\n",
-					"Somebody else is editing this entry.",
-					"Please try again later.");
+					_("Somebody else is editing this "\
+					  "entry. Please try again later."));
 				return;
 			}
 		} else {
-			if (x != SC_DATE && x != SC_TIME) {
+			if (x != SC_DATE && x != SC_TIME && x != SC_NOTE) {
 				create_error_popup(lw->shell, 0,
-					"Please enter time or date first");
+					_("Please enter time or date first"));
 				return;
 			}
 			clone_entry(&edit.entry, (struct entry *)0);
 			now = get_time();
 			edit.entry.time = lw->time ? lw->time : now - now%60;
+			edit.entry.notime = x == SC_NOTE;
+			edit.entry.late_warn  = config.late_time;
+			edit.entry.early_warn = config.early_time;
 		}
 		edit.editing	= TRUE;
 		edit.changed	= FALSE;
@@ -144,8 +158,8 @@ void got_entry_press(lw, x, y, on, shift)
 		break;
 
 	  case SC_USER:
-		create_user_sel_popup(lw->entry[y][x],
-				name_to_user(ep->user), got_new_user);
+		create_user_sel_popup(lw->entry[y][x], name_to_user(ep->user),
+						(BOOL (*)())got_new_user);
 		break;
 
 	  case SC_TIME:
@@ -179,13 +193,14 @@ void got_entry_press(lw, x, y, on, shift)
 		break;
 
 	  case SC_MESSAGE:
-		create_text_popup("Message", &edit.entry.message, x);
+		create_text_popup(_("Message"), &edit.entry.message, x, FALSE);
 		break;
 
 	  case SC_SCRIPT:
 		if (ep->notime)
 			break;
-		create_text_popup("Shell Script", &edit.entry.script, x);
+		create_text_popup(_("Shell Script"), &edit.entry.script, x,
+									FALSE);
 		break;
 
 	  case SC_EXCEPT:
@@ -197,6 +212,13 @@ void got_entry_press(lw, x, y, on, shift)
 		got_new_user(0);
 		break;
 
+	  case SC_TODO:
+		print_pixmap(lw->entry[y][SC_TODO], PIC_TODO, ep->todo^=TRUE);
+		edit.changed = TRUE;
+		edit.entry.suspended = FALSE;
+		sensitize_edit_buttons();
+		break;
+
 	  case SC_I_DATE:
 	  case SC_D_DATE:
 		temp = inc * (shift ? 7 : 1) * 86400;
@@ -283,9 +305,12 @@ void got_entry_press(lw, x, y, on, shift)
  * the old and the new user modified (if non-null), or reclassify as own
  * if old or new user is read-only. If it ends up with a different user,
  * tell the old server to delete and the new server to add.
+ * If it's more than 30 seconds since the last timer event, assume it's
+ * dead (bug or incompatibility in the XFree server as of June 99) and
+ * write synchronously from now on.
  */
 
-void confirm_new_entry()
+void confirm_new_entry(void)
 {
 	BOOL		changed;
 	unsigned int	new_file;
@@ -330,12 +355,12 @@ void confirm_new_entry()
 				prepare_for_modify(0);
 				addentry = FALSE;
 			} else if (!server_entry_op(&edit.entry, 'w')) {
-				create_error_popup(0, 0, werror_msg);
+				create_error_popup(0, 0, _(werror_msg));
 				edit.entry.file = old_file;
 			}
 		} else if (new_file == edit.entry.file) {	/* same file */
 			if (!server_entry_op(&edit.entry, 'w')) {
-				create_error_popup(0, 0, werror_msg);
+				create_error_popup(0, 0, _(werror_msg));
 				addentry = FALSE;
 			}
 			server_entry_op(&edit.entry, 'u');
@@ -346,7 +371,7 @@ void confirm_new_entry()
 			edit.entry.file = new_file;
 			edit.entry.id   = 0;
 			if (!server_entry_op(&edit.entry, 'w')) {
-				create_error_popup(0, 0, werror_msg);
+				create_error_popup(0, 0, _(werror_msg));
 				edit.entry.file = old_file;
 				edit.entry.id   = old_id;
 			}
@@ -370,6 +395,16 @@ void confirm_new_entry()
 			update_all_listmenus();
 			redraw_all_views();
 			mainlist->modified = TRUE;
+			if (last_x_timer != (time_t)-1 &&
+			    last_x_timer < get_time()-30) {
+				fprintf(stderr, "plan: X server fails to send "
+						"timer events, switching to sy"
+						"nchronous file writing. Time "
+						"displays will be wrong.\n");
+				last_x_timer = (time_t)-1;
+			}
+			if (last_x_timer == (time_t)-1)
+				write_mainlist();
 		}
 	}
 }
@@ -379,7 +414,7 @@ void confirm_new_entry()
  * undo all editing, restore the entry before we started editing
  */
 
-void undo_new_entry()
+void undo_new_entry(void)
 {
 	if (edit.editing) {
 		server_entry_op(&edit.entry, 'u');
@@ -398,10 +433,11 @@ void undo_new_entry()
  * user entered text into one of the buttons in the entry list
  */
 
-void got_entry_text(lw, x, y, text)
-	struct listmenu		*lw;		/* which menu */
-	int			x, y;		/* which column/row */
-	char			*text;		/* text input by user */
+void got_entry_text(
+	struct listmenu		*lw,		/* which menu */
+	int			x,		/* which column/row */
+	int			y,
+	char			*text)		/* text input by user */
 {
 	register struct entry	*ep;		/* affected entry */
 	register char		*p;		/* to remove trailing \n's */
@@ -503,9 +539,9 @@ void got_entry_text(lw, x, y, text)
 	if (x == SC_DATE || x == SC_ENDDATE || x == SC_TIME)
 		if (ep->rep_last && ep->rep_last < ep->time) {
 			create_error_popup(lw->shell, 0,
-				"The new date is after the last-trigger date,\n"
-				"%s. The last-trigger date has been disabled.",
-						mkdatestring(ep->rep_last));
+				_("The new date is after the last-trigger "\
+				  "date,\n %s. The last-trigger date has been"\
+				  " disabled."), mkdatestring(ep->rep_last));
 			ep->rep_every = 0;
 			ep->rep_last  = 0;
 		}
@@ -526,7 +562,7 @@ void got_entry_text(lw, x, y, text)
  * being edited and has been changed, the Undo button should be sensitive.
  */
 
-void sensitize_edit_buttons()
+void sensitize_edit_buttons(void)
 {
 	Arg			args;
 
