@@ -13,10 +13,6 @@
  *					that make up the entry list array. If
  *					widgets exist already, make sure that
  *					there are enough and remove excess.
- *	list_widget_pos(x, y, xpos, ypos, width, height, align)
- *					Calculate position and size etc of
- *					each button in the entry list array.
- *
  *	prepare_for_modify(name)	check if other user's file is writable,
  *					mark modified if yes
  *	edit_list_button(doedit, w, x, y)
@@ -25,10 +21,8 @@
  */
 
 #include <stdio.h>
-#include <time.h>
-#ifndef MIPS
 #include <stdlib.h>
-#endif
+#include <time.h>
 #include <Xm/Xm.h>
 #include <Xm/Form.h>
 #include <Xm/LabelP.h>
@@ -42,7 +36,7 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-#define NBLANK		3	/* add blank rows 3 this many at a time */
+#define NBLANK		3	/* add blank rows this many at a time */
 				/* dimensions of text entry area */
 #define X_MARGIN	4	/* width of margin at left/right edges */
 #define X_ENABLE	30	/* width of enable checkbutton */
@@ -52,17 +46,25 @@
 #define X_ARROW		13	/* width of up/down arrows, Y_ROW/2 */
 #define X_NOTEGAP	10	/* width of blank gap before note text field */
 #define X_OPTION	26	/* width of square option button */
-#define X_NOTE		(X_LABEL+5*X_OPTION)
+#define X_NOTE		(X_LABEL+6*X_OPTION)
 #define X_TOTAL		(X_MARGIN*2 + X_ENABLE + X_LABEL*3 + X_ARROW*3 +\
 			 X_DATE + X_TIME*3 + X_NOTEGAP + X_NOTE)
 #define Y_MARGIN	8	/* height of margin at top/bottom edges */
 #define Y_ROW		30	/* height of a single row */
 #define Y_GAP		6	/* height of gap between entry row pairs */
 
-void create_entry_widgets(), edit_list_button(), list_widget_pos();
-static void create_list_widgets();
-static void list_confirm(), list_undo(), list_dup(), list_delete(),
-	    list_done(), list_pin(), list_own(), list_entry(), list_edit();
+static void destroy_list_menu	(struct listmenu *);
+static void create_list_widgets	(struct listmenu *, int);
+static void list_widget_pos	(int, int, int *, int *, int *, int *, int *);
+static void list_confirm	(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_undo		(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_dup		(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_delete		(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_done		(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_pin		(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_own		(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_entry		(Widget, int, XmToggleButtonCallbackStruct *);
+static void list_edit		(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -91,15 +93,16 @@ static struct listmenu	*listmenu;	/* all important list popup widgets */
  * button exists.
  */
 
-static struct listmenu *find_widget_in_list_menu(w)
-	Widget			w;		/* button to find */
+static struct listmenu *find_widget_in_list_menu(
+	Widget		w)		/* button to find */
 {
-	struct listmenu		*scan;		/* popup scan pointer */
+	struct listmenu	*scan;		/* popup scan pointer */
 
-	while (w = XtParent(w))
+	do
 		for (scan=listmenu; scan; scan=scan->next)
 			if (w == scan->shell)
 				return(scan);
+	while (w = XtParent(w));
 	return(0);
 }
 
@@ -112,14 +115,13 @@ static struct listmenu *find_widget_in_list_menu(w)
  * is one.
  */
 
-static struct listmenu *create_list_menu(time, period, key, entry,
-					 user_plus_1, private)
-	time_t			time;		/* for what day? */
-	time_t			period;		/* for how many days? */
-	char			*key;		/* keyword lookup? */
-	struct entry		*entry;		/* just this one entry? */
-	int			user_plus_1;	/* which user file */
-	BOOL			private;	/* only private */
+static struct listmenu *create_list_menu(
+	time_t			time,		/* for what day? */
+	time_t			period,		/* for how many days? */
+	char			*key,		/* keyword lookup? */
+	struct entry		*entry,		/* just this one entry? */
+	int			user_plus_1,	/* which user file */
+	BOOL			private)	/* only private */
 {
 	register struct listmenu *scan;		/* popup scan pointer */
 
@@ -147,7 +149,7 @@ static struct listmenu *create_list_menu(time, period, key, entry,
 							/* no, make new one */
 	if (!scan) {
 		if (!(scan=(struct listmenu *)malloc(sizeof(struct listmenu))))
-			fatal("no memory");
+			fatal(_("no memory"));
 		scan->popped      = TRUE;
 		scan->valid       = FALSE;
 		scan->pinned      = FALSE;
@@ -180,11 +182,10 @@ static struct listmenu *create_list_menu(time, period, key, entry,
  * changes.
  */
 
-static void destroy_list_menu(lw)
-	struct listmenu		*lw;
+static void destroy_list_menu(
+	struct listmenu	*lw)
 {
-	struct tm		*tm;		/* time to m/d/y conv */
-	int			oldday;
+	struct tm	*tm;		/* time to m/d/y conv */
 
 	edit_list_button(0, lw, 0, 0);
 	XmToggleButtonSetState(lw->pin, lw->pinned = FALSE, FALSE);
@@ -202,9 +203,9 @@ static void destroy_list_menu(lw)
  * knows about all list menus.
  */
 
-void update_all_listmenus()
+void update_all_listmenus(void)
 {
-	struct listmenu		*scan;		/* popup scan pointer */
+	struct listmenu	*scan;		/* popup scan pointer */
 
 	for (scan=listmenu; scan; scan=scan->next)
 		if (scan->popped) {
@@ -220,7 +221,7 @@ void update_all_listmenus()
  * option in the config pulldown.
  */
 
-void destroy_all_listmenus()
+void destroy_all_listmenus(void)
 {
 	struct listmenu		*scan, *next;	/* popup scan pointer */
 
@@ -245,28 +246,27 @@ void destroy_all_listmenus()
  * list to decide how many buttons to create initially.
  */
 
-void create_list_popup(list, time, period, key, entry, user_plus_1, private)
-	struct plist		*list;
-	time_t			time;		/* for what day? */
-	time_t			period;		/* for how many days? */
-	char			*key;		/* keyword lookup? */
-	struct entry		*entry;		/* just this one entry? */
-	int			user_plus_1;	/* which user file */
-	BOOL			private;	/* only private */
+void create_list_popup(
+	struct plist	*list,
+	time_t		time,		/* for what day? */
+	time_t		period,		/* for how many days? */
+	char		*key,		/* keyword lookup? */
+	struct entry	*entry,		/* just this one entry? */
+	int		user_plus_1,	/* which user file */
+	BOOL		private)	/* only private */
 {
-	int			n = list->nentries + NBLANK;
-	struct listmenu		*w;
-	char			title[200];	/* menu title string */
-	char			*p;		/* temp for holiday lookup */
-	struct tm		*tm;		/* time to m/d/y conv */
-	struct holiday		*hp, *shp;	/* to check for holidays */
+	struct listmenu	*w;
+	char		title[200];	/* menu title string */
+	char		*p;		/* temp for holiday lookup */
+	struct tm	*tm;		/* time to m/d/y conv */
+	struct holiday	*hp, *shp;	/* to check for holidays */
 
 	if (!can_edit_appts())
 		return;
 	time   -= time   % 86400;
 	period -= period % 86400;
 	w = create_list_menu(time, period, key, entry, user_plus_1, private);
-	create_list_widgets(w, n - n%NBLANK);
+	create_list_widgets(w, 0);
 	if (time) {
 		strcpy(title, mkdatestring(time));
 		if (period) {
@@ -295,14 +295,14 @@ void create_list_popup(list, time, period, key, entry, user_plus_1, private)
 	} else if (w->key) {
 		sprintf(title, "/%.40s/", w->key);
 	} else if (entry) {
-		strcpy(title, "Entry from week view");
+		strcpy(title, _("Entry from week view"));
 	} else if (user_plus_1) {
-		strcpy(title, user_plus_1 == 1 ? "Own"
+		strcpy(title, user_plus_1 == 1 ? _("Own")
 					       : user[user_plus_1-1].name);
 	} else if (private) {
-		strcpy(title, "Private");
+		strcpy(title, _("Private"));
 	} else
-		strcpy(title, "All Entries");
+		strcpy(title, _("All Entries"));
 
 	print_button(w->title, title);
 	create_sublist(list, w);
@@ -315,14 +315,14 @@ void create_list_popup(list, time, period, key, entry, user_plus_1, private)
  * itself. The number of initial entry rows in the list is set to <nentries>.
  */
 
-static void create_list_widgets(w, nentries)
-	struct listmenu		*w;		/* create which menu */
-	int			nentries;	/* how many entries */
+static void create_list_widgets(
+	struct listmenu	*w,		/* create which menu */
+	int		nentries)	/* how many entries */
 {
-	Widget			form, scroll, help;
-	Arg			args[15];
-	int			n, width;
-	Atom			closewindow;
+	Widget		form, scroll, help;
+	Arg		args[15];
+	int		n, width;
+	Atom		closewindow;
 
 	if (w->valid) {
 		XtPopup(w->shell, XtGrabNone);
@@ -335,7 +335,7 @@ static void create_list_widgets(w, nentries)
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmUNMAP);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	w->shell = XtCreatePopupShell("Schedule",
+	w->shell = XtCreatePopupShell(_("Schedule"),
 			applicationShellWidgetClass, toplevel, args, n);
 	
 #	ifdef EDITRES
@@ -345,8 +345,8 @@ static void create_list_widgets(w, nentries)
 	set_icon(w->shell, 1);
 	form = XtCreateWidget("dayform", xmFormWidgetClass,
 			w->shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback,
-					help_callback, (XtPointer)"day");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day");
 
 							/*-- title -- */
 	n = 0;
@@ -362,14 +362,14 @@ static void create_list_widgets(w, nentries)
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
+	XtSetArg(args[n], XmNwidth,		72);			n++;
 	XtSetArg(args[n], XmNsensitive,		False);			n++;
-	w->confirm = XtCreateManagedWidget("Confirm", xmPushButtonWidgetClass,
-			form, args, n);
-	XtAddCallback(w->confirm, XmNactivateCallback,
-				list_confirm, (XtPointer)0);
-	XtAddCallback(w->confirm, XmNhelpCallback,
-				help_callback, (XtPointer)"day_confirm");
+	w->confirm = XtCreateManagedWidget(_("Confirm"),
+			xmPushButtonWidgetClass, form, args, n);
+	XtAddCallback(w->confirm, XmNactivateCallback, (XtCallbackProc)
+			list_confirm, (XtPointer)0);
+	XtAddCallback(w->confirm, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day_confirm");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -377,14 +377,14 @@ static void create_list_widgets(w, nentries)
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	w->confirm);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
+	XtSetArg(args[n], XmNwidth,		72);			n++;
 	XtSetArg(args[n], XmNsensitive,		False);			n++;
-	w->undo = XtCreateManagedWidget("Undo", xmPushButtonWidgetClass,
+	w->undo = XtCreateManagedWidget(_("Undo"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w->undo, XmNactivateCallback,
-					list_undo, (XtPointer)0);
-	XtAddCallback(w->undo, XmNhelpCallback,
-					help_callback, (XtPointer)"day_undo");
+	XtAddCallback(w->undo, XmNactivateCallback, (XtCallbackProc)
+			list_undo, (XtPointer)0);
+	XtAddCallback(w->undo, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day_undo");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -392,13 +392,14 @@ static void create_list_widgets(w, nentries)
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	w->undo);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
+	XtSetArg(args[n], XmNwidth,		72);			n++;
 	XtSetArg(args[n], XmNsensitive,		False);			n++;
-	w->dup = XtCreateManagedWidget("Dup", xmPushButtonWidgetClass,
+	w->dup = XtCreateManagedWidget(_("Dup"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w->dup, XmNactivateCallback, list_dup, (XtPointer)0);
-	XtAddCallback(w->dup, XmNhelpCallback,     help_callback,
-							(XtPointer)"day_dup");
+	XtAddCallback(w->dup, XmNactivateCallback, (XtCallbackProc)
+			list_dup, (XtPointer)0);
+	XtAddCallback(w->dup, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"day_dup");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -406,13 +407,14 @@ static void create_list_widgets(w, nentries)
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	w->dup);		n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
+	XtSetArg(args[n], XmNwidth,		72);			n++;
 	XtSetArg(args[n], XmNsensitive,		False);			n++;
-	w->del = XtCreateManagedWidget("Delete", xmPushButtonWidgetClass,
+	w->del = XtCreateManagedWidget(_("Delete"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w->del, XmNactivateCallback, list_delete, (XtPointer)0);
-	XtAddCallback(w->del, XmNhelpCallback,     help_callback,
-							(XtPointer)"day_del");
+	XtAddCallback(w->del, XmNactivateCallback, (XtCallbackProc)
+			list_delete, (XtPointer)0);
+	XtAddCallback(w->del, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"day_del");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -420,13 +422,13 @@ static void create_list_widgets(w, nentries)
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	w->del);		n++;
 	XtSetArg(args[n], XmNleftOffset,	32);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
-	help = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	XtSetArg(args[n], XmNwidth,		72);			n++;
+	help = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(help, XmNactivateCallback,
-					help_callback, (XtPointer)"day");
-	XtAddCallback(help, XmNhelpCallback,
-					help_callback, (XtPointer)"day");
+	XtAddCallback(help, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day");
+	XtAddCallback(help, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day");
 
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
@@ -434,12 +436,13 @@ static void create_list_widgets(w, nentries)
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNleftWidget,	help);			n++;
 	XtSetArg(args[n], XmNleftOffset,	8);			n++;
-	XtSetArg(args[n], XmNwidth,		64);			n++;
-	w->done = XtCreateManagedWidget("Done", xmPushButtonWidgetClass,
+	XtSetArg(args[n], XmNwidth,		72);			n++;
+	w->done = XtCreateManagedWidget(_("Done"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w->done, XmNactivateCallback, list_done, (XtPointer)0);
-	XtAddCallback(w->done, XmNhelpCallback,     help_callback,
-							(XtPointer)"day_done");
+	XtAddCallback(w->done, XmNactivateCallback, (XtCallbackProc)
+			list_done, (XtPointer)0);
+	XtAddCallback(w->done, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"day_done");
 
 	n = 0;
 	XtSetArg(args[n], XmNselectColor,	color[COL_RED]);	n++;
@@ -447,11 +450,12 @@ static void create_list_widgets(w, nentries)
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
-	w->pin = XtCreateManagedWidget("Pin", xmToggleButtonWidgetClass,
+	w->pin = XtCreateManagedWidget(_("Pin"), xmToggleButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w->pin, XmNvalueChangedCallback, list_pin, (XtPointer)0);
-	XtAddCallback(w->pin, XmNhelpCallback, help_callback,
-							(XtPointer)"day_pin");
+	XtAddCallback(w->pin, XmNvalueChangedCallback, (XtCallbackProc)
+			list_pin, (XtPointer)0);
+	XtAddCallback(w->pin, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day_pin");
 
 	n = 0;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
@@ -461,15 +465,16 @@ static void create_list_widgets(w, nentries)
 	XtSetArg(args[n], XmNrightWidget,	w->pin);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNset,		config.ownonly);	n++;
-	w->own = XtCreateManagedWidget("Own Only", xmToggleButtonWidgetClass,
-			form, args, n);
-	XtAddCallback(w->own, XmNvalueChangedCallback, list_own, (XtPointer)0);
-	XtAddCallback(w->own, XmNhelpCallback, help_callback,
-							(XtPointer)"day_own");
+	w->own = XtCreateManagedWidget(_("Own Only"),
+			xmToggleButtonWidgetClass, form, args, n);
+	XtAddCallback(w->own, XmNvalueChangedCallback, (XtCallbackProc)
+			list_own, (XtPointer)0);
+	XtAddCallback(w->own, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day_own");
 
 							/*-- scroll --*/
 	n = 0;
-	width = X_TOTAL + 32 +
+	width = X_TOTAL + 34 +
 		(config.notewidth > X_NOTE ? config.notewidth - X_NOTE : 0);
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		w->title);		n++;
@@ -486,23 +491,24 @@ static void create_list_widgets(w, nentries)
 	XtSetArg(args[n], XmNscrollingPolicy,	XmAUTOMATIC);		n++;
 	scroll = XtCreateWidget("lscroll", xmScrolledWindowWidgetClass,
 			form, args, n);
-	XtAddCallback(scroll, XmNhelpCallback,
-					help_callback, (XtPointer)"day");
+	XtAddCallback(scroll, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"day");
 
 	n = 0;
 	w->list = XtCreateWidget("list", xmBulletinBoardWidgetClass,
 			scroll, args, n);
 	XtManageChild(w->list);
 
-	create_entry_widgets(w, nentries+NBLANK - nentries%NBLANK);
+	create_entry_widgets(w, nentries);
 
 	XtManageChild(scroll);
 	XtManageChild(form);
 	XtPopup(w->shell, XtGrabNone);
 
+	XtVaSetValues(w->shell, XmNdeleteResponse, XmDO_NOTHING, NULL);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(w->shell, closewindow,
-					list_done, (XtPointer)w->shell);
+	XmAddWMProtocolCallback(w->shell, closewindow, (XtCallbackProc)
+			list_done, (XtPointer)w->shell);
 }
 
 
@@ -521,7 +527,7 @@ static void create_list_widgets(w, nentries)
 static char *help_name[SC_N] = {
 	"day_enable", "day_user", "day_date", "day_enddate", "day_time",
 	"day_length", "day_advance", "day_advdays", "day_note", "day_recycle",
-	"day_message", "day_script", "day_except", "day_private",
+	"day_message", "day_script", "day_except", "day_private", "day_todo",
 	"day_date", "day_enddate", "day_time", "day_length", "day_advance",
 	"day_advdays",
 	"day_date", "day_enddate", "day_time", "day_length", "day_advance",
@@ -530,44 +536,50 @@ static char *help_name[SC_N] = {
 	"day_advdays", "day_flags"
 };
 
-void create_entry_widgets(w, nentries)
-	struct listmenu		*w;
-	int			nentries;
+void create_entry_widgets(
+	struct listmenu	*w,
+	int		nentries)
 {
-	int			x, y;
-	Arg			args[15];
-	int			n;
-	int			xpos, ypos;
-	int			width, height;
-	int			align;
-	char			*name;
-	WidgetClass		class;
+	int		x, y;
+	Arg		args[15];
+	int		n;
+	int		xpos, ypos;
+	int		width, height;
+	int		align;
+	char		*name;
+	WidgetClass	class;
 
-	nentries = NBLANK;				/* check # of rows: */
-	n = w->sublist ? w->sublist->nentries : 0;
-	if (n+2 > w->nentries) {			/* need more? */
-		nentries = n+NBLANK - n%NBLANK;
+	nentries = nentries+NBLANK - nentries%NBLANK;
+	/* right number of rows? */ 
+	if (nentries == w->nentries)
+		return;
 
-	} else if (n+NBLANK < w->nentries) {		/* have too many? */
-		nentries = n+NBLANK - n%NBLANK;
+	/* make the list size fit the new number of rows */
+	n = 0;
+	list_widget_pos(SC_NOTE, nentries+1,
+					&xpos, &ypos, &width, &height, &align);
+	XtSetArg(args[n], XmNheight, ypos); n++;
+	XtSetValues(w->list, args, n);
+
+	/* have too many? */
+	if (nentries < w->nentries) {
 		for (y=nentries+1; y <= w->nentries; y++)
 			for (x=0; x < SC_N; x++)
 				XtDestroyWidget(w->entry[y][x]);
-		if (w->nentries > nentries)
-			w->nentries = nentries;
-		return;
-	} else						/* within tolerance */
+		w->nentries = nentries;
 		return;
+	}
 
+	/* need more! */
 	n = (nentries+1) * SC_N * sizeof(Widget *);
 	if (w->entry && !(w->entry = (Widget (*)[])realloc(w->entry, n)) ||
 	   !w->entry && !(w->entry = (Widget (*)[])malloc(n)))
-		fatal("no memory");
+		fatal(_("no memory"));
 
+	XtUnmanageChild(w->list);
 	for (x=0; x < SC_N; x++) {
 	    for (y=w->nentries; y <= nentries; y++) {
 		list_widget_pos(x, y, &xpos, &ypos, &width, &height, &align);
-		XtUnmanageChild(w->list);
 		class = xmPushButtonWidgetClass;
 		name  = "";
 		n = 0;
@@ -578,17 +590,18 @@ void create_entry_widgets(w, nentries)
 			n++;
 			break;
 
-		  case SC_USER:     name = "Group"; break;
-		  case SC_DATE:     name = "Date";  break;
-		  case SC_TIME:     name = "Time";  break;
-		  case SC_ADVANCE:  name = "Warn";  break;
-		  case SC_NOTE:     name = "Note";  break;
+		  case SC_USER:     name = _("Group"); break;
+		  case SC_DATE:     name = _("Date");  break;
+		  case SC_TIME:     name = _("Time");  break;
+		  case SC_ADVANCE:  name = _("Warn");  break;
+		  case SC_NOTE:     name = _("Note");  break;
 
 		  case SC_RECYCLE:
 		  case SC_MESSAGE:
 		  case SC_SCRIPT:
 		  case SC_EXCEPT:
 		  case SC_PRIVATE:
+		  case SC_TODO:
 			XtSetArg(args[n], XmNlabelType, XmPIXMAP); n++;
 			break;
 
@@ -612,13 +625,13 @@ void create_entry_widgets(w, nentries)
 			class = xmArrowButtonWidgetClass;
 			break;
 
-		  case SC_L_DATE:    name = "beg:";  break;
-		  case SC_L_ENDDATE: name = "end:";  break;
-		  case SC_L_TIME:    name = "beg:";  break;
-		  case SC_L_LENGTH:  name = "len:";  break;
-		  case SC_L_ADVANCE: name = "min:";  break;
-		  case SC_L_ADVDAYS: name = "days:"; break;
-		  case SC_L_FLAGS:   name = "opt:";  break;
+		  case SC_L_DATE:    name = _("beg:");  break;
+		  case SC_L_ENDDATE: name = _("end:");  break;
+		  case SC_L_TIME:    name = _("beg:");  break;
+		  case SC_L_LENGTH:  name = _("len:");  break;
+		  case SC_L_ADVANCE: name = _("min:");  break;
+		  case SC_L_ADVDAYS: name = _("days:"); break;
+		  case SC_L_FLAGS:   name = _("opt:");  break;
 		}
 		if (!y || x >= SC_L)
 			class = xmLabelWidgetClass;
@@ -641,12 +654,15 @@ void create_entry_widgets(w, nentries)
 		if (x < SC_L) {
 		    if (y && x)
 			XtAddCallback(w->entry[y][x], XmNactivateCallback,
-				list_entry, (XtPointer)(x + y * SC_N));
+						(XtCallbackProc)list_entry,
+						(XtPointer)(x + y * SC_N));
 		    if (y && !x)
 			XtAddCallback(w->entry[y][x], XmNvalueChangedCallback,
-				list_entry, (XtPointer)(x + y * SC_N));
+						(XtCallbackProc)list_entry,
+						(XtPointer)(x + y * SC_N));
 		}
-		XtAddCallback(w->entry[y][x], XmNhelpCallback, help_callback,
+		XtAddCallback(w->entry[y][x], XmNhelpCallback,
+						(XtCallbackProc)help_callback,
 						(XtPointer)help_name[x]);
 	    }
 	}
@@ -659,12 +675,14 @@ void create_entry_widgets(w, nentries)
  * return position, size, and alignment of a widget in the scroll list
  */
 
-void list_widget_pos(x, y, xpos, ypos, width, height, align)
-	int			x, y;		/* row/column */
-	int			*xpos, *ypos;	/* returned pixel pos */
-	int			*width;		/* returned width */
-	int			*height;	/* returned height */
-	int			*align;		/* ret. text alignment: l,c,r*/
+static void list_widget_pos(
+	int		x,		/* row/column */
+	int		y,
+	int		*xpos,		/* returned pixel pos */
+	int		*ypos,
+	int		*width,		/* returned width */
+	int		*height,	/* returned height */
+	int		*align)		/* ret. text alignment: l,c,r*/
 {
 	*width  = X_LABEL;
 	*height = Y_ROW;
@@ -723,6 +741,7 @@ void list_widget_pos(x, y, xpos, ypos, width, height, align)
 	  case SC_SCRIPT:
 	  case SC_EXCEPT:
 	  case SC_PRIVATE:
+	  case SC_TODO:
 		*ypos += Y_ROW;
 		*xpos += X_LABEL*4 + X_TIME*3 + X_DATE + X_ARROW*3 +
 					X_NOTEGAP + X_OPTION * (x-SC_FLAGS);
@@ -787,20 +806,20 @@ void list_widget_pos(x, y, xpos, ypos, width, height, align)
  * because that would overwrite edit.entry, including the ID for netplan.
  */
 
-void edit_list_button(doedit, w, x, y)
-	int			doedit;		/* 1=edit, 0=unedit, 2=del */
-	struct listmenu		*w;		/* create which menu */
-	int			x;		/* column, SC_* */
-	int			y;		/* row, y=0: title */
+void edit_list_button(
+	int		doedit,		/* 1=edit, 0=unedit, 2=del */
+	struct listmenu	*w,		/* create which menu */
+	int		x,		/* column, SC_* */
+	int		y)		/* row, y=0: title */
 {
-	Arg			args[15];
-	int			n;
-	int			xpos, ypos;
-	int			width, height;
-	int			align;
-	char			*text;
-	char			*space;
-	static BOOL		busy;		/* not re-entrant */
+	Arg		args[15];
+	int		n;
+	int		xpos, ypos;
+	int		width, height;
+	int		align;
+	char		*text = "";
+	char		*space;
+	static BOOL	busy;		/* not re-entrant */
 
 	if (busy || !w)				/* not editing */
 		return;
@@ -816,7 +835,7 @@ void edit_list_button(doedit, w, x, y)
 		XtDestroyWidget(w->text);
 		if (x && y)
 			print_button(w->entry[y][x], "%s",
-						mkbuttonstring(w, x, y));
+					text = mkbuttonstring(w, x, y));
 	}
 	w->text = 0;
 	if (doedit != 1)
@@ -835,19 +854,18 @@ void edit_list_button(doedit, w, x, y)
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	w->text = XtCreateManagedWidget("text", xmTextWidgetClass,
 			w->list, args, n);
-	XtAddCallback(w->text, XmNactivateCallback, list_edit,(XtPointer)NULL);
-	XtAddCallback(w->text, XmNhelpCallback, help_callback,
-						(XtPointer)help_name[x]);
+	XtAddCallback(w->text, XmNactivateCallback, (XtCallbackProc)
+			list_edit, (XtPointer)NULL);
+	XtAddCallback(w->text, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)help_name[x]);
 	XmProcessTraversal(w->text, XmTRAVERSE_CURRENT);
 
-	text = "";
 	if (w->sublist && w->sublist->nentries >= y-1 &&
-			!(w->sublist->nentries == y-1 && x == SC_TIME)) {
+			!(w->sublist->nentries == y-1 && x == SC_TIME))
 		text = mkbuttonstring(w, x, y);
-		if ((x == SC_DATE || x == SC_ENDDATE) &&
-						(space = strchr(text, ' ')))
-			text = space+1;
-	}
+	if ((x == SC_DATE || x == SC_ENDDATE) &&
+					(space = strchr(text, ' ')))
+		text = space+1;
 	print_text_button(w->text, "%s", text);
 	w->xedit = x;
 	w->yedit = y;
@@ -863,8 +881,8 @@ void edit_list_button(doedit, w, x, y)
  * now. Return TRUE if writing can proceed, or FALSE on error.
  */
 
-BOOL prepare_for_modify(name)
-	char		*name;		/* user name or 0 */
+BOOL prepare_for_modify(
+	char		*name)		/* user name or 0 */
 {
 	int		u;		/* index into user array */
 
@@ -876,26 +894,26 @@ BOOL prepare_for_modify(name)
 	if (user[u].readonly) {
 		if (user[u].fromserver)
 			create_error_popup(0, 0,
-"Cannot modify appointments of %s,\n\
+_("Cannot modify appointments of %s,\n\
 server on %s denies write permission.\n\
 Re-check the permissions with File->Reread database.\n\
 You can not disable individual appointments, but you\n\
-can disable all with the Config->User list popup.",
+can disable all with the Config->User list popup."),
 					name, user[u].server);
 		else if (user[u].grok)
 			create_error_popup(0, 0,
-"Cannot modify appointments of %s because they\n\
+_("Cannot modify appointments of %s because they\n\
 were read from a grok database. Saving is not\n\
-implemented for grok databases. The file is\n%s",
+implemented for grok databases. The file is\n%s"),
 					name, user[u].path);
 		else
 			create_error_popup(0, 0,
-"Cannot modify appointments of %s,\n\
+_("Cannot modify appointments of %s,\n\
 no write permission for %s\n\
 or %s/.dayplan.\n\n\
 Re-check the permissions with File->Reread database.\n\
 You can not disable individual appointments, but you\n\
-can disable all with the Config->User list popup.",
+can disable all with the Config->User list popup."),
 					name, user[u].path, user[u].path);
 		return(FALSE);
 	}
@@ -911,10 +929,10 @@ can disable all with the Config->User list popup.",
  */
 
 /*ARGSUSED*/
-static void list_confirm(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_confirm(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (find_widget_in_list_menu(widget) == edit.menu)
 		confirm_new_entry();
@@ -922,10 +940,10 @@ static void list_confirm(widget, item, data)
 
 
 /*ARGSUSED*/
-static void list_undo(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_undo(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
 	if (lw == edit.menu && prepare_for_modify(edit.entry.user)) {
@@ -936,10 +954,10 @@ static void list_undo(widget, item, data)
 
 
 /*ARGSUSED*/
-static void list_dup(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_dup(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct entry tmp;
 	struct listmenu *lw = find_widget_in_list_menu(widget);
@@ -963,10 +981,10 @@ static void list_dup(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void list_delete(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_delete(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
 	if (!edit.editing || lw != edit.menu
@@ -992,10 +1010,10 @@ static void list_delete(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void list_done(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_done(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
 	if (lw)
@@ -1003,10 +1021,10 @@ static void list_done(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void list_pin(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_pin(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
 	if (lw)
@@ -1014,10 +1032,10 @@ static void list_pin(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void list_own(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_own(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct listmenu *lw = find_widget_in_list_menu(widget);
 	if (lw) {
@@ -1028,10 +1046,10 @@ static void list_own(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void list_entry(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_entry(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct listmenu			*lw = find_widget_in_list_menu(widget);
 	int				x = item % SC_N;
@@ -1043,10 +1061,10 @@ static void list_entry(widget, item, data)
 }
 
 /*ARGSUSED*/
-static void list_edit(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void list_edit(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	struct listmenu			*lw = find_widget_in_list_menu(widget);
 	char				*text = XmTextGetString(widget);
