@@ -6,19 +6,18 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #ifdef MIPS
 #include <sys/types.h>
 #include <sys/fcntl.h>
-#else
-#include <stdlib.h>
 #endif
 #ifdef _APOLLO_SOURCE
 #include <sys/types.h>
 #include <sys/fcntl.h>
 #endif
-#ifdef ULTRIX
+#if defined(ULTRIX) || defined(__EMX__)
 #include <sys/types.h>
 #endif
 #include <sys/stat.h>
@@ -26,8 +25,7 @@
 #include <time.h>
 #include <errno.h>
 #include <Xm/Xm.h>
-#include "config.h"
-#include "proto.h"
+#include "cal.h"
 #include "version.h"
 #ifdef PLANGROK
 #include "grok.h"
@@ -36,19 +34,15 @@
 
 #define NDAYS		28			/* must agree with cal.h */
 
-#ifdef MIPS
-extern char		*getenv();
-extern char		*malloc();
-#endif
-static int		readfile();
-static void		make_default_user();
-static void		convert_dbase();
+static int  readfile		(struct plist **, char *, int, BOOL);
+static void make_default_user	(char *);
+static void convert_dbase	(struct plist **, struct user *, char *);
 
 extern char		*progname;		/* argv[0] */
 extern struct plist	*mainlist;		/* all schedule entries */
 extern struct config	config;			/* global configuration data */
 struct user		*user;			/* user list for week view */
-static int		maxusers;		/* max # of users in u list */
+int			maxusers;		/* max # of users in u list */
 int			nusers;			/* # of users in user list */
 char			Print_Spooler[100];	/* print spooling command */
 
@@ -66,7 +60,7 @@ char			Print_Spooler[100];	/* print spooling command */
  * files or the servers.
  */
 
-BOOL read_mainlist()
+BOOL read_mainlist(void)
 {
 	struct stat		sbuf;		/* check for directories */
 	char			msgbuf[4096];	/* default message buffer */
@@ -93,28 +87,34 @@ BOOL read_mainlist()
 		user = 0;
 	}
 	nusers = maxusers = 0;
-							/* main data */
-	if (error = readfile(&mainlist, DB_PUB_PATH, 0, TRUE))
-		sprintf(msg+strlen(msg),
-			"Failed to read master file %s, error %d\n",
-			DB_PUB_PATH, error);
-	else if (!access(DB_PUB_PATH, F_OK) && access(DB_PUB_PATH, W_OK))
-		sprintf(msg+strlen(msg),
-		      "Warning: own config and data file %s is not writable\n",
-								DB_PUB_PATH);
+
+	if (config.webplan) {				/*webplan: dummy user*/
+		make_default_user(resolve_tilde(DB_PUB_PATH));
+		obtain_netplan_users(config.webplan_host ? config.webplan_host
+							 : "localhost");
+	} else {					/* main data */
+		if (error = readfile(&mainlist, DB_PUB_PATH, 0, TRUE))
+			sprintf(msg+strlen(msg),
+				_("Failed to read master file %s, error %d\n"),
+				DB_PUB_PATH, error);
+		else if (!access(resolve_tilde(DB_PUB_PATH), F_OK) &&
+			  access(resolve_tilde(DB_PUB_PATH), W_OK))
+			sprintf(msg+strlen(msg), _("Warning: own config and "
+				"data file %s is not writable\n"),DB_PUB_PATH);
 
 							/* private data */
-	if (error = readfile(&mainlist, DB_PRIV_PATH, 0, FALSE))
-		sprintf(msg+strlen(msg),
-			"Failed to read private file %s, error %d\n",
-			DB_PRIV_PATH, error);
-	else if (!access(DB_PRIV_PATH, F_OK) && access(DB_PRIV_PATH, W_OK))
-		sprintf(msg+strlen(msg),
-			"Warning: own private data file %s is not writable\n",
-								DB_PRIV_PATH);
+		if (error = readfile(&mainlist, DB_PRIV_PATH, 0, FALSE))
+			sprintf(msg+strlen(msg),
+				_("Failed to read private file %s, error %d\n"),
+				DB_PRIV_PATH, error);
+		else if (!access(resolve_tilde(DB_PRIV_PATH), F_OK) &&
+			  access(resolve_tilde(DB_PRIV_PATH), W_OK))
+			sprintf(msg+strlen(msg), _("Warning: own private data "
+				"file %s is not writable\n"), DB_PRIV_PATH);
 
-	make_default_user(resolve_tilde(DB_PUB_PATH));	/* network connection*/
-	if (p = attach_to_network())
+		make_default_user(resolve_tilde(DB_PUB_PATH));
+	}
+	if (p = attach_to_network())			/* network connection*/
 		strcat(msg, p);
 	read_from_server(&mainlist, 0, 0);
 							/* user data */
@@ -125,12 +125,12 @@ BOOL read_mainlist()
 		}
 		if (!user[u].path || !user[u].name) {
 			sprintf(msg+strlen(msg),
-				"file of user #%d not read, no name or path\n",
+			     _("file of user #%d not read, no name or path\n"),
 								u);
 			continue;
 		}
-		if (!stat(user[u].path, &sbuf) && (sbuf.st_mode & S_IFDIR))
-			sprintf(path, "%s/%s", user[u].path, DB_FILE);
+		if (!stat(user[u].path, &sbuf) && IS_DIR(sbuf.st_mode))
+			strcpy(path, resolve_tilde(DB_PUB_PATH));
 		else
 			strcpy(path, user[u].path);
 		user[u].readonly = !access(path, F_OK) && !!access(path, W_OK);
@@ -143,14 +143,14 @@ BOOL read_mainlist()
 		if ((error = readfile(&mainlist, path, u, FALSE)) &&
 							error != ENOENT)
 			sprintf(msg+strlen(msg),
-				"Failed to read file %s of user %s, error %d\n",
+			    _("Failed to read file %s of user %s, error %d\n"),
 				user[u].path, user[u].name, error);
 	}
 	rebuild_repeat_chain(mainlist);
 
 	if (*msg)
 		create_error_popup(0, 0,
-				"Error while reading files:\n%s", msg);
+				_("Error while reading files:\n%s"), msg);
 	mainlist->modified = FALSE;
 	return(!*msg);
 }
@@ -175,17 +175,16 @@ BOOL read_mainlist()
  * Returns nonzero if the file could not be read.
  */
 
-static int readfile(list, path, u, conf)
-	struct plist		**list;		/* list to add to */
-	char			*path;		/* file to read list from */
-	int			u;		/* user number, 0=own */
-	BOOL			conf;		/* if TRUE, config stuff too */
+static int readfile(
+	struct plist	**list,		/* list to add to */
+	char		*path,		/* file to read list from */
+	int		u,		/* user number, 0=own */
+	BOOL		conf)		/* if TRUE, config stuff too */
 {
-	register struct config	*c = &config;
-	FILE			*fp;		/* open file */
-	BOOL			writable;	/* can we lock the file? */
-	char			line[1024];	/* line buffer */
-	int			lineno = 0;	/* first line == "grok"? */
+	FILE		*fp;		/* open file */
+	BOOL		writable;	/* can we lock the file? */
+	char		line[1024];	/* line buffer */
+	int		lineno = 0;	/* first line == "grok"? */
 
 	if (conf)				/* defaults for 't' line */
 		guess_tzone();
@@ -201,12 +200,12 @@ static int readfile(list, path, u, conf)
 		if (!lineno++ && !strncmp(line, "grok", 4)) {
 #ifndef PLANGROK
 			create_error_popup(0, 0,
-				"%s is a\ngrok database, not supported", path);
+			     _("%s is a\ngrok database, not supported"), path);
 #else
 			extern FORM *form_create();
 			struct user *up = &user[u];
 			if (!u)
-				create_error_popup(0, 0, "The first file in the file list\n(%s)\nmust not be a grok database!\nTrying to continue, you may lose data.", path);
+				create_error_popup(0, 0, _("The first file in the file list\n(%s)\nmust not be a grok database!\nTrying to continue, you may lose data."), path);
 			form_delete(up->form);
 			dbase_delete(up->dbase);
 			up->grok     = TRUE;
@@ -244,24 +243,24 @@ static int readfile(list, path, u, conf)
  * prepended to the usual numerical date/time string.
  */
 
-void parse_file_line(list, path, name, conf, line)
-	struct plist		**list;		/* list to add to */
-	char			*path;		/* file/server to read from */
-	char			*name;		/* user name, 0=not yet known*/
-	BOOL			conf;		/* if TRUE, config stuff too */
-	char			*line;		/* line to be parsed */
+void parse_file_line(
+	struct plist		**list,		/* list to add to */
+	char			*path,		/* file/server to read from */
+	char			*name,		/* user name, 0=not yet known*/
+	BOOL			conf,		/* if TRUE, config stuff too */
+	char			*line)		/* line to be parsed */
 {
 	register struct config	*c = &config;
 	int			fid, rid;	/* network file ID and row ID*/
 	char			*instring;	/* string at line[2] or [3] */
-	register char		*p, *q;		/* line scan pointer */
+	register char		*p;		/* line scan pointer */
 	static struct entry	entry;		/* temp entry before adding */
 	static struct entry	*ep = 0;	/* list entry being read */
 	int			n, m;		/* tmp entry # of ep in list */
 	struct tm		tm;		/* m/d/y h:m:s to time conv */
 	int			tmp[9];		/* temps for sscanf */
 	int			acol, ndays;	/* more temps for sscanf */
-	char			sflag, pflag, nflag;
+	char			tflag, sflag, pflag, nflag;
 	char			nmflag, nyflag, nwflag, noflag, ndflag;
 	char			**string;	/* string to add to */
 	int			len;		/* new length of string */
@@ -285,10 +284,10 @@ void parse_file_line(list, path, name, conf, line)
 
 	  case 'V':
 		line[strlen(line)-1] = 0;
-		sprintf(buf1, "plan %s", VERSION);
+		sprintf(buf1, "plan %s", VERSION JAPANVERSION);
 		if (strcmp(line, buf1))
-			fprintf(stderr,
-		"%s: WARNING: file %s is version %s, program version is %s\n",
+			fprintf(stderr, _("%s: WARNING: file %s is version "\
+					  "%s, program version is %s\n"),
 						progname, path, line, buf1);
 		break;
 
@@ -302,10 +301,12 @@ void parse_file_line(list, path, name, conf, line)
 		c->gpsweek        = line[7]  == 'g';
 		c->weeknum        = line[7]  != '-';
 		c->nopast         = line[8]  != '-';
+		c->insecure_script= line[9]  != '-';
 		c->weekwarn       = line[10] != '-';
 		c->weekuser       = line[11] != '-';
 		c->week_bignotime = line[12] != '-';
-		c->fullweek       = line[13] != '-';
+		c->fullweek       = line[13] == 'w';
+		c->thu_week       = line[13] == 't';
 		c->colorcode_m    = line[14] != '-';
 		c->ownonly	  = line[15] != '-';
 		sscanf(line+16, "%d %d %d %d %d %d",
@@ -388,6 +389,7 @@ void parse_file_line(list, path, name, conf, line)
 		c->pr_omit_appts  = line[2] != '-';
 		c->pr_omit_priv   = line[3] != '-';
 		c->pr_omit_others = line[4] != '-';
+		c->pr_color	  = line[5] != '-';
 		c->pr_mode        = atoi(line+13);
 		break;
 
@@ -414,7 +416,7 @@ void parse_file_line(list, path, name, conf, line)
 			user = user ? realloc(user, n * sizeof(struct user))
 				    : malloc(n * sizeof(struct user));
 			if (!user)
-				fatal("no memory");
+				fatal(_("no memory"));
 			memset(user+maxusers, 0,
 					(n-maxusers) * sizeof(struct user));
 			maxusers = n;
@@ -443,6 +445,14 @@ void parse_file_line(list, path, name, conf, line)
 		nusers++;
 		break;
 
+	  case 'L':
+		if (c->language)
+			free(c->language);
+		c->language = mystrdup(line+2);
+		for (p=c->language; *p > ' '; p++);
+		*p = 0;
+		break;
+
 	  case '0':
 	  case '1':
 	  case '2':
@@ -459,14 +469,14 @@ void parse_file_line(list, path, name, conf, line)
 		nmflag = nyflag = nwflag = noflag = ndflag = 0;
 		acol = ndays = 0;
 		sscanf(line,
-       "%d/%d/%d %d:%d:%d %d:%d:%d %d:%d:%d %d:%d:%d %c%c%c%c%c%c%c%c-- %d %d",
+      "%d/%d/%d %d:%d:%d %d:%d:%d %d:%d:%d %d:%d:%d %c%c%c%c%c%c%c%c%c- %d %d",
 			&tm.tm_mon, &tm.tm_mday, &tm.tm_year,
 			&tm.tm_hour, &tm.tm_min, &tm.tm_sec,
 			tmp+0, tmp+1, tmp+2,
 			tmp+3, tmp+4, tmp+5,
 			tmp+6, tmp+7, tmp+8,
 			&sflag, &pflag, &nflag,
-			&nmflag, &nyflag, &nwflag, &noflag, &ndflag,
+			&nmflag, &nyflag, &nwflag, &noflag, &ndflag, &tflag,
 			&acol, &ndays);
 		tm.tm_mon--;
 		if (tm.tm_year < 70)
@@ -488,6 +498,7 @@ void parse_file_line(list, path, name, conf, line)
 		entry.hide_in_w    = nwflag == 'W';
 		entry.hide_in_o    = noflag == 'O';
 		entry.hide_in_d    = ndflag == 'D';
+		entry.todo	   = tflag  == 't';
 		entry.acolor       = acol;
 		entry.user	   = name ? mystrdup(name) : 0;
 		entry.file	   = fid;
@@ -524,7 +535,7 @@ void parse_file_line(list, path, name, conf, line)
 			ep->except[n] = tm_to_time(&tm);
 		} else
 			fprintf(stderr,
-				"too many exception dates for appt");
+				_("too many exception dates for appt"));
 		break;
 
 	  case 'N':
@@ -545,7 +556,7 @@ void parse_file_line(list, path, name, conf, line)
 add:			len  = *string ? strlen(*string) : 0;
 		len += strlen(instring) + 2;
 		if (!(p = malloc(len))) {
-			fprintf(stderr, "%s: no memory", progname);
+			fprintf(stderr, _("%s: no memory"), progname);
 			exit(1);
 		}
 		if (*string) {
@@ -558,7 +569,7 @@ add:			len  = *string ? strlen(*string) : 0;
 		break;
 	
 	  default:
-		fprintf(stderr, "%s: %s: illegal line:\n%s",
+		fprintf(stderr, _("%s: %s: illegal line:\n%s"),
 						progname, path, line);
 	}
 }
@@ -570,22 +581,26 @@ add:			len  = *string ? strlen(*string) : 0;
  * not a null pointer because everybody relies on that.
  */
 
-static void make_default_user(path)
-	char		*path;		/* file path for own .dayplan */
+static void make_default_user(
+	char		*path)		/* file path for own .dayplan */
 {
 	struct passwd	*pw;
 	char		host[1024], *name;
 
 	if (user && nusers && user[0].name)
 		return;
-	pw = getpwuid(getuid());
-	name = pw ? pw->pw_name : getenv("LOGNAME");
-	if (!name)
-		name = "unknown";
+	if (config.webplan)
+		name  = "webplan";
+	else {
+		pw = getpwuid(getuid());
+		name = pw ? pw->pw_name : getenv("LOGNAME");
+		if (!name)
+			name = _("unknown");
+	}
 	if (!user) {
 		maxusers = 10;
 		if (!(user = malloc(maxusers * sizeof(struct user))))
-			fatal("no memory");
+			fatal(_("no memory"));
 		memset(user, 0, maxusers * sizeof(struct user));
 	}
 	if (gethostname(host, sizeof(host)))
@@ -593,7 +608,7 @@ static void make_default_user(path)
 	user[0].name    = mystrdup(name);
 	user[0].path    = mystrdup(path);
 	user[0].server  = mystrdup(host);
-	user[0].alarm   = TRUE;
+	user[0].alarm   = !config.webplan;
 	user[0].file_id = -1;
 	nusers = 1;
 }
@@ -604,10 +619,10 @@ static void make_default_user(path)
  */
 
 #ifdef PLANGROK
-static void convert_dbase(list, up, db)
-	struct plist		**list;		/* list to add to */
-	register struct user	*up;		/* user with form/dbase */
-	char			*db;		/* db name for error messages*/
+static void convert_dbase(
+	struct plist		**list,		/* list to add to */
+	register struct user	*up,		/* user with form/dbase */
+	char			*db)		/* db name for error messages*/
 {
 	struct entry		*elist;		/* temporary list of entries */
 	register struct entry	*ep;		/* list entry being read */
@@ -624,7 +639,7 @@ static void convert_dbase(list, up, db)
 	if ((en = up->dbase->nrows) < 1 || (fn = up->form->nitems) < 1)
 		return;
 	if (!(elist = (struct entry *)malloc(en * sizeof(struct entry))))
-		fatal("no memory for appointment list");
+		fatal(_("no memory for appointment list"));
 	for (ep=elist, ei=0; ei < en; ei++, ep++) {
 		clone_entry(ep, (struct entry *)0);
 		ep->grok_row = ei;
@@ -643,7 +658,7 @@ static void convert_dbase(list, up, db)
 			def_n = fi;
 	}
 	if (!have_d && def_d < 0) {
-		create_error_popup(0, 0, "xmbase-grok database %s\ncannot be read because the calendar\ninterface is %s, and there are no\ndate fields to automatically generate one.", db, tagged ? "incomplete" : "missing");
+		create_error_popup(0, 0, _("xmbase-grok database %s\ncannot be read because the calendar\ninterface is %s, and there are no\ndate fields to automatically generate one."), db, tagged ? _("incomplete") : _("missing"));
 		return;
 	}
 	if (!have_d)
@@ -695,7 +710,7 @@ static void convert_dbase(list, up, db)
 		} else
 			destroy_entry(ep);
 	if (!n)
-		create_error_popup(0, 0, "%d of %d appointments from grok database\n%s discarded\nbecause of invalid date/time.", en-n, en, db);
+		create_error_popup(0, 0, _("%d of %d appointments from grok database\n%s discarded\nbecause of invalid date/time."), en-n, en, db);
 
 	free((void *)elist);
 }
