@@ -21,7 +21,7 @@
 #include "cal.h"
 #include "version.h"
 
-BOOL writefile();
+static BOOL writefile(struct plist *, char *, int, int);
 
 extern int		errno;
 extern char		*progname;		/* argv[0] */
@@ -40,8 +40,9 @@ extern BOOL		reread;			/* need to re-read db file */
  * original from the backup if the rewrite failed. Return FALSE on failure.
  */
 
-BOOL copyfile(source, target)
-	char		*source, *target;
+BOOL copyfile(
+	char		*source,
+	char		*target)
 {
 	FILE		*sfp, *tfp;
 	char		line[1024];	/* line buffer */
@@ -82,32 +83,34 @@ BOOL copyfile(source, target)
  * the file, even in network mode.
  */
 
-void write_mainlist()
+void write_mainlist(void)
 {
 	struct stat	sbuf;		/* check for directories */
 	int		u;		/* user counter */
 	char		path[1024];	/* user file name to write */
 
-	if (mainlist->modified &&
-	    writefile(mainlist, DB_PUB_PATH,  0, WR_PUBLIC|WR_CONFIG)&&
+	if (!config.webplan &&
+	    mainlist->modified &&
+	    writefile(mainlist, DB_PUB_PATH,  0, WR_PUBLIC|WR_CONFIG) &&
 	    writefile(mainlist, DB_PRIV_PATH, 0, WR_PRIVATE))
 		mainlist->modified = FALSE;
 
-	for (u=0; u < nusers; u++) {
-		if (u == 0 && !user[u].fromserver)
-			continue;
+	for (u=1; u < nusers; u++) {
 		if (user[u].fromserver || !user[u].modified)
 			continue;
 		if (!user[u].path || !user[u].name) {
 			create_error_popup(0, 0,
-			 "file of user #%d not written, no name or path\n", u);
+			 _("file of user #%d not written, no name or path\n"),
+									u);
 			continue;
 		}
-		if (!stat(user[u].path, &sbuf) && (sbuf.st_mode & S_IFDIR))
-			sprintf(path, "%s/%s", user[u].path, DB_FILE);
+		if (!stat(resolve_tilde(user[u].path), &sbuf) &&
+							IS_DIR(sbuf.st_mode))
+			strcpy(path, DB_PUB_PATH);
 		else
 			strcpy(path, user[u].path);
-		user[u].readonly = !access(path, F_OK) && !!access(path, W_OK);
+		user[u].readonly = !access(resolve_tilde(path), F_OK) &&
+				   !access(resolve_tilde(path), W_OK);
 		user[u].time     = get_time();
 		if (writefile(mainlist, path, u, WR_PUBLIC))
 			user[u].modified = 0;
@@ -142,22 +145,20 @@ static int write_to_file(line) char *line;
 	{ errno = 0; fprintf(curr_fp, "%s", line);
 	  return(errno && errno != ENOTTY); }
 
-BOOL writefile(list, path, u, what)
-	struct plist		*list;		/* list to write */
-	char			*path;		/* file to write list to */
-	int			u;		/* user index, 0=own */
-	int			what;		/* bitmap of WR_* macros */
+static BOOL writefile(
+	struct plist		*list,		/* list to write */
+	char			*path,		/* file to write list to */
+	int			u,		/* user index, 0=own */
+	int			what)		/* bitmap of WR_* macros */
 {
 	register struct config	*c = &config;
 	FILE			*fp;		/* open file */
 	char			backpath[1024];	/* path of backup file */
 	char			line[1024];	/* line buffer */
 	char			*name;		/* name of user, 0=own */
-	register char		*p, *q;		/* string copy pointers */
+	register char		*p;		/* string copy pointers */
 	register struct entry	*ep;		/* list entry being written */
 	int			i;		/* entry counter */
-	int			j;		/* exception counter */
-	struct tm		*tm;		/* time to m/d/y h:m:s conv */
 	BOOL			write_error = FALSE;
 
 	list->locked = TRUE;
@@ -174,7 +175,7 @@ BOOL writefile(list, path, u, what)
 		return(TRUE);
 #else
 		create_error_popup(0, 0,
-			"%s is an\nxmbase-grok database, cannot write file",
+			_("%s is an\nxmbase-grok database, cannot write file"),
 			path);
 		return(FALSE);
 #endif
@@ -184,7 +185,7 @@ BOOL writefile(list, path, u, what)
 	unlink(backpath);
 	if (!copyfile(path, backpath)) {
 		create_error_popup(0, errno,
-			"Failed to back up database %s\nto %s, aborted write",
+		      _("Failed to back up database %s\nto %s, aborted write"),
 			path, backpath);
 		unlink(backpath);
 		list->locked = FALSE;
@@ -192,13 +193,13 @@ BOOL writefile(list, path, u, what)
 	}
 	if (!(fp = fopen(path, "w"))) {			/* rewrite database */
 		create_error_popup(0, errno,
-			"Failed to create appointment\ndatabase %s", path);
+			_("Failed to create appointment\ndatabase %s"), path);
 		list->locked = FALSE;
 		return(FALSE);
 	}
 	if ((what & WR_PRIVATE) && chmod(path, 0600))
 		create_error_popup(0, errno,
-			"Warning: cannot chmod 0600 appointment\ndatabase %s",
+		      _("Warning: cannot chmod 0600 appointment\ndatabase %s"),
 		     	path);
 	lockfile(fp, TRUE);
 
@@ -206,7 +207,7 @@ BOOL writefile(list, path, u, what)
 		FILE *rfp;
 		if (!(rfp = fopen(backpath, "r")) && errno != ENOENT) {
 			create_error_popup(0, errno,
-				"Failed to read copy of user\ndatabase %s",
+				_("Failed to read copy of user\ndatabase %s"),
 				backpath);
 			write_error = TRUE;
 		}
@@ -231,10 +232,10 @@ BOOL writefile(list, path, u, what)
 		for (p=c->alarm_prog; p && *p; p++)
 			if (*p == '\n') *p = ';';
 		errno = 0;
-		fprintf(fp, "plan %s\n", VERSION);
+		fprintf(fp, "plan %s\n", VERSION JAPANVERSION);
 		write_error |= errno && errno != ENOTTY;
 		fprintf(fp,
-			"o\t%c%c%c%c%c%c%c-%c%c%c%c%c%c %d %d %d %d %d %d\n",
+			"o\t%c%c%c%c%c%c%c%c%c%c%c%c%c%c %d %d %d %d %d %d\n",
 					c->sunday_first	  ? 's' : '-',
 					c->ampm		  ? 'a' : '-',
 					c->mmddyy	  ? 'm' : '-',
@@ -243,14 +244,16 @@ BOOL writefile(list, path, u, what)
 					c->gpsweek	  ? 'g' :
 					c->weeknum	  ? 'w' : '-',
 					c->nopast	  ? 'n' : '-',
+					c->insecure_script? 'i' : '-',
 					c->weekwarn	  ? 'w' : '-',
 					c->weekuser	  ? 'u' : '-',
 					c->week_bignotime ? 's' : '-',
+					c->thu_week	  ? 't' :
 					c->fullweek	  ? 'w' : '-',
 					c->colorcode_m	  ? 'c' : '-',
 					c->ownonly	  ? 'o' : '-',
-					c->early_time,
-					c->late_time,
+					(int)c->early_time,
+					(int)c->late_time,
 					(int)c->wintimeout,
 					c->week_minhour,
 					c->week_maxhour,
@@ -298,10 +301,11 @@ BOOL writefile(list, path, u, what)
 					c->yov_display,
 					c->yov_user);
 		write_error |= errno && errno != ENOTTY;
-		fprintf(fp, "P\t%c%c%c------- %d\n",
+		fprintf(fp, "P\t%c%c%c%c------ %d\n",
 					c->pr_omit_appts  ? 'a' : '-',
 					c->pr_omit_priv   ? 'p' : '-',
 					c->pr_omit_others ? 'o' : '-',
+					c->pr_color	  ? 'c' : '-',
 					c->pr_mode);
 		if (*Print_Spooler) {
 			fprintf(fp, "p\t%s\n", Print_Spooler);
@@ -311,6 +315,10 @@ BOOL writefile(list, path, u, what)
 			fprintf(fp, "m\t%s\n", c->mailer);
 			write_error |= errno && errno != ENOTTY;
 		}
+		if (c->language) {
+			fprintf(fp, "L\t%s\n", c->language);
+			write_error |= errno && errno != ENOTTY;
+		}
 		write_error |= errno && errno != ENOTTY;
 		for (i=0; i < nusers; i++) {
 			fprintf(fp,"u\t%-15s %-20s %d %2d %d %d %d %d %s %d\n",
@@ -351,16 +359,16 @@ BOOL writefile(list, path, u, what)
 		if (copyfile(backpath, path)) {
 			unlink(backpath);
 			create_error_popup(0, errno,
-"Failed to write appointment database file\n\"%s\".\n\
+_("Failed to write appointment database file\n\"%s\".\n\
 Your recent changes have been discarded.\n\
-Check disk space and permissions of the directory!", path);
+Check disk space and permissions of the directory!"), path);
 		} else
 			create_error_popup(0, errno,
-"Failed to write appointment database file\n\"%s\".\n\
+_("Failed to write appointment database file\n\"%s\".\n\
 Your recent changes have been discarded.\n\
 Check disk space and permissions of the directory!\n\n\
 Could not restore original contents. Backup is in\n\
-%s, requires manual restore", path, backpath);
+%s, requires manual restore"), path, backpath);
 		reread = TRUE;
 		return(FALSE);
 	}
@@ -374,9 +382,9 @@ Could not restore original contents. Backup is in\n\
  * a callback function for each line. Returns FALSE for all types of failure.
  */
 
-int write_one_entry(callback, ep)
-	int			(*callback)();	/* function that writes line */
-	register struct entry	*ep;		/* list entry to write */
+int write_one_entry(
+	int			(*callback)(),	/* function that writes line */
+	register struct entry	*ep)		/* list entry to write */
 {
 	char			line[10240];	/* line buffer */
 	register char		*p, *q;		/* string copy pointers */
@@ -386,7 +394,7 @@ int write_one_entry(callback, ep)
 
 	tm = time_to_tm(ep->time);
 	sprintf(line,
-"%d/%d/%d  %d:%d:%d  %d:%d:%d  %d:%d:%d  %d:%d:%d  %c%c%c%c%c%c%c%c-- %d %d\n",
+"%d/%d/%d  %d:%d:%d  %d:%d:%d  %d:%d:%d  %d:%d:%d  %c%c%c%c%c%c%c%c%c- %d %d\n",
 		(int)tm->tm_mon+1,
 		(int)tm->tm_mday,
 		(int)tm->tm_year + 1900,
@@ -410,6 +418,7 @@ int write_one_entry(callback, ep)
 		(int)ep->hide_in_w ? 'W' : '-',
 		(int)ep->hide_in_o ? 'O' : '-',
 		(int)ep->hide_in_d ? 'D' : '-',
+		(int)ep->todo	   ? 't' : '-',
 		(int)ep->acolor,
 		(int)ep->days_warn / 86400);
 
