@@ -12,15 +12,15 @@
  *					<year>. Sets holiday and sm_holiday
  *					arrays. If force is set, re-eval even
  *					if year is the same as last time.
+ *	dump_holiday(year)		print holiday list for a year (webplan)
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <time.h>
 #ifndef NEWSOS4
-#ifdef STDLIBMALLOC
-#include <stdlib.h>
-#else
+#ifndef STDLIBMALLOC
 #include <malloc.h>
 #endif
 #endif
@@ -45,9 +45,13 @@
 #define	BEFORE		-1
 #define AFTER		-2
 
-static int	 calc_easter();
+static void setliteraldate(int, int, int, int *);
+static int calc_easter(int);
+static int calc_pascha(int);
+extern int yyparse(void);
 
-#if defined(bsdi)||defined(linux)||defined(__NetBSD__)||defined(__FreeBSD__)||defined(HPGCC)
+
+#if defined(bsdi)||defined(linux)||defined(__NetBSD__)||defined(__FreeBSD__)||defined(HPGCC)||defined(__EMX__)
 int yylineno;
 #else
 extern int	 yylineno;		/* current line # being parsed */
@@ -63,25 +67,23 @@ int		 parse_year = -1;	/* year being parsed, 0=1970..99=2069*/
 static char	*filename;		/* holiday filename */
 static char	 errormsg[200];		/* error message if any, or "" */
 static int	 easter_julian;		/* julian date of Easter Sunday */
+static int	 pascha_julian;		/* julian date of Pascha Sunday */
 static char	*holiday_name;		/* strdup'd yacc_string */
 
 struct holiday	 holiday[366];		/* info for each day, separate for */
 struct holiday	 sm_holiday[366];	/* full-line texts under, and small */
 					/* texts next to day number */
-
 extern short	monthlen[12];
 extern short	monthbegin[12];
 
 
-static void setliteraldate();
-
-yyerror(msg) char *msg;
+int yyerror(char *msg)
 {
-	fprintf(stderr, "%s: %s in line %d of %s\n", progname,
+	fprintf(stderr, _("%s: %s in line %d of %s\n"), progname,
 					msg, yylineno+1, filename);
 	if (!*errormsg)
 		sprintf(errormsg,
-		      "Problem with holiday file %s:\n%.80s in line %d",
+		      _("Problem with holiday file %s:\n%.80s in line %d"),
 					filename, msg, yylineno+1);
 	return(0);
 }
@@ -96,9 +98,9 @@ yyerror(msg) char *msg;
  * Return an error message if an error occurred, 0 otherwise.
  */
 
-char *parse_holidays(year, force)
-	int			year;		/* year to parse for, 0=1970 */
-	BOOL			force;		/* file has changed, re-read */
+char *parse_holidays(
+	int			year,		/* year to parse for, 0=1970 */
+	BOOL			force)		/* file has changed, re-read */
 {
 	register struct holiday *hp;
 	register int		d, n;
@@ -114,6 +116,7 @@ char *parse_holidays(year, force)
 		year = parse_year;
 	parse_year = year;
 	easter_julian = calc_easter(year + 1900);
+	pascha_julian = calc_pascha(year + 1900);
 
 	for (hp=holiday, d=0; d < 366; d++, hp++)
 		if (hp->string) {
@@ -175,12 +178,12 @@ char *parse_holidays(year, force)
  * can be ANY or LAST.
  */
 
-void setwday(num, wday, month, off, length)
-	int		num;		/* which, 1st..5th, ANY, or LAST */
-	int		wday;		/* 1=monday..7=sunday */
-	int		month;		/* month, 1..12, ANY, or LAST */
-	int		off;		/* offset in days */
-	int		length;		/* length in days */
+void setwday(
+	int		num,		/* which, 1st..5th, ANY, or LAST */
+	int		wday,		/* 1=monday..7=sunday */
+	int		month,		/* month, 1..12, ANY, or LAST */
+	int		off,		/* offset in days */
+	int		length)		/* length in days */
 {
 	int		min_month = 0, max_month = 11;
 	int		min_num   = 0, max_num   = 4;
@@ -218,14 +221,14 @@ void setwday(num, wday, month, off, length)
  * (This routine contributed by Peter Littlefield <plittle@sofkin.ca>)
  */
 
-void setdoff(wday, rel, month, day, year, off, length)
-	int		rel;		/* -1=before, -2=after */
-	int		wday;		/* 1=monday..7=sunday */
-	int		month;		/* month, 1..12, ANY, or LAST */
-	int		day;		/* 1..31, ANY, or LAST */
-	int		year;		/* 1..2069, or ANY */
-	int		off;		/* offset in days */
-	int		length;		/* length in days */
+void setdoff(
+	int		wday,		/* 1=monday..7=sunday */
+	int		rel,		/* -1=before, -2=after */
+	int		month,		/* month, 1..12, ANY, or LAST */
+	int		day,		/* 1..31, ANY, or LAST */
+	int		year,		/* 1..2069, or ANY */
+	int		off,		/* offset in days */
+	int		length)		/* length in days */
 {
 	int		min_month = 0, max_month = 11;
 	int		min_day   = 1, max_day   = 31;
@@ -272,12 +275,12 @@ void setdoff(wday, rel, month, day, year, off, length)
  * the month).
  */
 
-void setdate(month, day, year, off, length)
-	int		month;		/* 1..12, ANY, or LAST */
-	int		day;		/* 1..31, ANY, or LAST */
-	int		year;		/* 1..2069, or ANY */
-	int		off;		/* offset in days */
-	int		length;		/* length in days */
+void setdate(
+	int		month,		/* 1..12, ANY, or LAST */
+	int		day,		/* 1..31, ANY, or LAST */
+	int		year,		/* 1..2069, or ANY */
+	int		off,		/* offset in days */
+	int		length)		/* length in days */
 {
 	int		min_month = 0, max_month = 11;
 	int		min_day   = 1, max_day   = 31;
@@ -325,11 +328,11 @@ static int colormap[10] = {
 	0, COL_HBLACK, COL_HRED, COL_HGREEN, COL_HYELLOW,
 	COL_HBLUE, COL_HMAGENTA, COL_HCYAN, COL_HWHITE, COL_WEEKEND };
 
-static void setliteraldate(month, day, off, dup)
-	int		month;		/* 0..11 */
-	int		day;		/* 1..31 */
-	int		off;		/* offset in days */
-	int		*dup;		/* flag for later free() */
+static void setliteraldate(
+	int		month,		/* 0..11 */
+	int		day,		/* 1..31 */
+	int		off,		/* offset in days */
+	int		*dup)		/* flag for later free() */
 {
 	int julian = JULIAN(month, day) + off;
 	struct holiday *hp = yacc_small ? &sm_holiday[julian]
@@ -350,12 +353,13 @@ static void setliteraldate(month, day, off, dup)
  * set a holiday relative to Easter
  */
 
-void seteaster(off, length)
-	int		off;		/* offset in days */
-	int		length;		/* length in days */
+void seteaster(
+	int		off,		/* offset in days */
+	int		length,		/* length in days */
+	int		pascha)		/* 0=Easter, 1=Christian Orthodox */
 {
 	int		dup = 0;	/* flag for later free() */
-	int julian = easter_julian + off;
+	int julian = (pascha ? pascha_julian : easter_julian) + off;
 	struct holiday *hp = yacc_small ? &sm_holiday[julian]
 					: &holiday[julian];
 
@@ -380,8 +384,8 @@ void seteaster(off, length)
  * all this right...
  */
 
-static int calc_easter(year)
-	int		year;		/* Easter in which year? */
+static int calc_easter(
+	int		year)		/* Easter in which year? */
 {
 	int golden, cent, grcor, clcor, extra, epact, easter;
 
@@ -414,6 +418,25 @@ static int calc_easter(year)
 }
 
 
+/*
+ * set a holiday relative to Pascha, which is the Christian Orthodox Easter.
+ * Algorithm provided by Efthimios Mavrogeorgiadis <emav@enl.auth.gr>.
+ */
+
+static int calc_pascha(
+	int		year)		/* Pascha in which year? */
+{
+	int a = year % 19;
+	int b = (19 * a + 15) % 30;
+	int c = (year + year/4 + b) % 7;
+	int d = b - c;
+	int e = d - 3 - (2 - year/100 + year/400);
+	int day = e - 30 * e/31;
+	int month = 4 + e/31;
+	return(31 + 28+!(year&3) + (month==4 ? 0 : 31) + day-1);
+}
+
+
 /*
  * functions used for [] syntax: (Erwin Hugo Achermann <acherman@inf.ethz.ch>)
  *
@@ -424,8 +447,8 @@ static int calc_easter(year)
  * monthday_from_day (day, *m, *d, *y)	gets month/day/cur_year from <day>
  */
 
-int day_from_name(str)
-	char	*str;
+int day_from_name(
+	char	*str)
 {
 	int	i;
 	char	*name;
@@ -445,7 +468,9 @@ int day_from_easter(void)
 }
 
 
-int day_from_monthday(int m, int d)
+int day_from_monthday(
+	int	m,
+	int	d)
 {
 	if (m == 13)
 		return(365 + LEAPYEAR(parse_year));
@@ -453,8 +478,11 @@ int day_from_monthday(int m, int d)
 }
 
 
-void monthday_from_day(day, m, d, y)
-	int	day, *m, *d, *y;
+void monthday_from_day(
+	int	day,
+	int	*m,
+	int	*d,
+	int	*y)
 {
 	int	i, len;
 
@@ -475,8 +503,10 @@ void monthday_from_day(day, m, d, y)
 }
 
 
-int day_from_wday(day, wday, num)
-	int	day, wday, num;
+int day_from_wday(
+	int	day,
+	int	wday,
+	int	num)
 {
 	int	wkday, yday, weeknum;
 
@@ -485,3 +515,50 @@ int day_from_wday(day, wday, num)
 	day += num * 7;
 	return (day);
 }
+
+
+/*
+ * This function implements the -H option. Its main purpose is for the web
+ * interface. Written by Michel Bourget, extended by thomas@bitrot.de.
+ */
+
+static char *julian_to_date(
+	int	julian,
+	int	year)
+{
+	static char str[32];
+	int 	total, i, d, m;
+	int	nbdays[12] = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
+
+	total=0;
+	for (i=1; i <= 12; i++) {
+		if (i==2 && (year%4) == 0)
+			nbdays[i-1] = 29;
+		total += nbdays[i-1];
+		if (total < julian)
+			continue;
+		m = i;
+		d = julian - total + nbdays[i-1];
+		sprintf(str, "%d.%d.%d", d, m, year+1900);
+		return(str);
+	}
+	return("ERROR");
+}
+
+
+void dump_holiday(
+	int	year)
+{
+	int	i;
+
+	parse_holidays(year -= 1900, TRUE);
+	for (i=0; i < 366; i++) {
+		if (holiday[i].string)
+			printf("%d;%s;%s\n", i+1, julian_to_date(i+1, year),
+						holiday[i].string);
+		if (sm_holiday[i].string)
+			printf("%d;%s;%s\n", i+1, julian_to_date(i+1, year),
+						sm_holiday[i].string);
+	}
+	fflush(stdout);
+}
