@@ -4,7 +4,6 @@
  * few routines used by everyone are also here.
  *
  *	main(argc, argv)		Guess.
- *	fatal(char *fmt, ...)		Prints an error message and exits.
  *	resynchronize_daemon()		Called when the database on disk has
  *					changed; tell the daemon to re-read.
  *	register_X_input(fd)		network.c opened new server socket
@@ -15,24 +14,23 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <time.h>
 #include <fcntl.h>
 #include <pwd.h>
 #ifndef VARARGS
 #include <stdarg.h>
 #endif
-#ifndef MIPS
-#include <unistd.h>
-#include <stdlib.h>
-#endif
 #include <errno.h>
 #include <ctype.h>
 #include <signal.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <Xm/Xm.h>
 #include <Xm/Text.h>
 #include <X11/StringDefs.h>
+#include <sys/stat.h>				  /* umask() */
 #include "cal.h"
 #include "version.h"
 
@@ -41,14 +39,23 @@
 extern unsigned short e2j(), sj2j();
 #endif
 
-static void init_resources(), init_colors(), init_fonts(), init_daemon();
-static void timer_callback(), usage(), non_interactive(), sighand();
-static void socket_callback();
-static int  dumptoday();
-extern void run_daemon();
+static void non_interactive	(int, char *[]);
+static int  dumptoday		(char *, int, BOOL, BOOL, char *, BOOL);
+static BOOL dumpfilelist	(void);
+static void sighand		(int);
+static void usage		(void);
+static void init_resources	(void);
+static void init_colors		(void);
+static void init_fonts		(void);
+static void init_daemon		(void);
+static void timer_callback	(XtPointer, XtIntervalId *);
+static void socket_callback	(XtPointer, int *, XtInputId *);
+extern void run_daemon		();
 #ifdef MIPS
-void exit();
-extern char *getenv();
+extern void exit		(int);
+#endif
+#ifdef __FreeBSD__
+static void plan_exit		(int);
 #endif
 
 Display			*display;	/* everybody uses the same server */
@@ -62,11 +69,13 @@ struct config		config;		/* global configuration data */
 char			*progname;	/* argv[0] */
 BOOL			interactive;	/* interactive or fast appt entry? */
 XFontStruct		*font[NFONTS];	/* fonts: FONT_* */
+XColor			xcolor[NCOLS];	/* useful for PostScript color */
 Pixel			color[NCOLS];	/* colors: COL_* */
 int			curr_month;	/* month being displayed, 0..11 */
 int			curr_year;	/* year being displayed, since 1900 */
+time_t			last_x_timer;	/* when did last X timer happen? */
 struct plist		*mainlist;	/* list of all schedule entries */
-extern struct user	*user;			/* user list for week view */
+extern struct user	*user;		/* user list for week view */
 extern Pixmap		pixmap[NPICS];	/* common symbols */
 extern Pixmap	    graypixmap[NPICS];	/* common symbols, grayed-out */
 static BOOL		nodaemon;	/* don't insist on a daemon (-s) */
@@ -91,32 +100,41 @@ static String fallbacks[] = {
  * initialize everything and create the main calendar window
  */
 
-int main(argc, argv)
-	int			argc;
-	char			*argv[];
+int main(
+	int			argc,
+	char			*argv[])
 {
-	int			n, i, u;
+	int			n, i;
 	time_t			now;
 	struct tm		*tm;
 	char			buf[80], *name;
-	BOOL			nofork = FALSE;
+	BOOL			dofork = DOFORK;
 	BOOL			nolock = FALSE;
 	BOOL			others = FALSE;
+	BOOL			showid = FALSE;
+	char			*ulist = 0;
 	char			*errmsg;
 	XGCValues		gcval;
 
+#ifdef __FreeBSD__
+	atexit(plan_exit);
+#endif
 	interactive = FALSE;
 	if ((progname = strrchr(argv[0], '/')) && progname[1])
 		progname++;
 	else
 		progname = argv[0];
+	if (!strcmp(progname, "webplan"))
+		config.webplan = TRUE;
 	tzset();
 	now = get_time();
 	tm = time_to_tm(now);
 	curr_month = tm->tm_mon;
 	curr_year  = tm->tm_year;
 	set_tzone();
-
+#ifdef PLANHOME
+	mkdir(resolve_tilde("~/" PLANHOME), 0755);
+#endif
 	if (argc > 1 && isdigit(*argv[1])) {		/* non-interactive? */
 		non_interactive(argc, argv);
 		_exit(0);
@@ -124,16 +142,17 @@ int main(argc, argv)
 	for (n=1; n < argc; n++)			/* options */
 		if (*argv[n] != '-')
 			usage();
+				/* multicharacter options are Xt/Xm, skip */
 		else if (argv[n][2] < 'a' || argv[n][2] > 'z')
 			switch(argv[n][1]) {
 			  case 'd':
 				for (i=0; fallbacks[i]; i++)
-					printf("%s%s\n", progname,
-							 fallbacks[i]);
+					printf("%s%s\n",progname,fallbacks[i]);
 				fflush(stdout);
 				return(0);
 			  case 'v':
-				fprintf(stderr, "%s: %s\n", progname, VERSION);
+				fprintf(stderr, "%s: %s\n", progname,
+							VERSION JAPANVERSION);
 				return(0);
 			  case 's':
 				nodaemon = TRUE;
@@ -142,7 +161,10 @@ int main(argc, argv)
 				rundaemon = TRUE;
 				break;
 			  case 'f':
-				nofork = TRUE;
+				dofork = FALSE;
+				break;
+			  case 'b':
+				dofork = TRUE;
 				break;
 			  case 'k':
 				nolock = TRUE;
@@ -150,15 +172,37 @@ int main(argc, argv)
 			  case 'o':
 			  	others = TRUE;
 				break;
+			  case 'u':
+			  	ulist = argv[++n];
+				break;
+			  case 'i':
+				showid = TRUE;
+				break;
 			  case 't':
 			  case 'T':
 				if (argv[n][2])
 					_exit(dumptoday(argv[n]+2,
 					     argv[n+1] ? atoi(argv[n+1]) : 1,
-					     argv[n][1] == 't', others));
+					     argv[n][1]=='t', others,
+					     ulist, showid));
 				_exit(dumptoday(argv[n+1],
 					     argv[n+2] ? atoi(argv[n+2]) : 1,
-					     argv[n][1] == 't', others));
+					     argv[n][1]=='t', others,
+					     ulist, showid));
+			  case 'W':
+				config.webplan = TRUE;
+				if (argv[n+1] && *argv[n+1] != '-')
+					config.webplan_host = argv[++n];
+				break;
+			  case 'F':
+				_exit(!dumpfilelist());
+			  case 'H':
+				if (argv[n+1])
+					dump_holiday(atoi(argv[n+1]));
+			  	_exit(0);
+			  case 'X':
+				fprintf(stderr, "-X not yet supported\n");
+				break;	/*<<<*/
 			  default:
 				usage();
 			}
@@ -166,7 +210,7 @@ int main(argc, argv)
 			break;
 
 	(void)umask(0077);
-	if (!nofork) {					/* background */
+	if (dofork) {					/* background */
 		PID_T pid = fork();
 		if (pid < 0)
 			perror("can't fork");
@@ -178,11 +222,10 @@ int main(argc, argv)
 	config.ewarn_window = TRUE;
 	config.lwarn_window = TRUE;
 	config.alarm_window = TRUE;
-	config.early_time   = 45*60;
-	config.late_time    = 5*60;
-	config.week_ndays= 7;
+	config.week_ndays   = 7;
 	config.week_minhour = 8;
 	config.week_maxhour = 20;
+	config.dst_flag	    = 3;
 	name            = getenv("LOGNAME");
 	if (!name) name = getenv("USER");
 	if (!name) name = getenv("user");
@@ -226,16 +269,16 @@ int main(argc, argv)
 	set_icon(toplevel, 0);
 	XSetForeground(display, xor_gc, color[COL_WIREFRAME]);
 
-	create_list(&mainlist);
-	create_cal_widgets(toplevel);
-	read_mainlist();
+	read_mainlist();	/* get config: net, tzone mode, language, ...*/
 	set_tzone();
+	create_list(&mainlist);
+	read_mainlist();	/* actually read apppointments */
+	create_cal_widgets(toplevel);
 
-	if (config.autodel)
-		(void)recycle_all(mainlist, TRUE, 0);
+	(void)recycle_all(mainlist, config.autodel, 0);
 	signal(SIGHUP, sighand);
 							/* lockfile ok? */
-	if (!startup_lock(PLAN_PATH, nolock))
+	if (!startup_lock(resolve_tilde(PLANLOCK), nolock))
 		if (!all_files_served())
 			create_multiple_popup(nolock);
 							/* holidays ok? */
@@ -243,6 +286,7 @@ int main(argc, argv)
 		create_error_popup(mainmenu.cal, 0, errmsg);
 							/* start */
 	timer_id = XtAppAddTimeOut(app, 100, timer_callback, 0);
+	last_x_timer = get_time();
 	XtRealizeWidget(toplevel);
 	resynchronize_daemon();
 	XtAppMainLoop(app);
@@ -256,9 +300,9 @@ int main(argc, argv)
  * re-read the database, and terminate.
  */
 
-static void non_interactive(argc, argv)
-	int		argc;			/* arguments from main */
-	char		*argv[];		/* arguments from main */
+static void non_interactive(
+	int		argc,			/* arguments from main */
+	char		*argv[])		/* arguments from main */
 {
 	time_t		now;
 	struct tm	*tm;			/* current date and time */
@@ -303,12 +347,33 @@ static void non_interactive(argc, argv)
 		  case 'l':
 			edit.entry.length = parse_timestring(argv[i+1], TRUE);
 			break;
+		  case 'n':
+			edit.entry.notime = TRUE;
+			edit.entry.length = 0;
+			i--;
+			break;
+		  case 'r':
+			edit.entry.rep_every = atoi(argv[i+1]) * 86400;
+			break;
+		  case 'd':
+			edit.entry.rep_days |= 1 << atoi(argv[i+1]);
+			break;
+		  case 'D':
+			edit.entry.rep_weekdays |= 1 << atoi(argv[i+1]);
+			break;
+		  case 'e':
+        		edit.entry.rep_last = parse_datestring(argv[i+1],
+								trigger);
+			break;
 		  case 'w':
 			edit.entry.early_warn = atoi(argv[i+1]) * 60;
 			break;
 		  case 'W':
 			edit.entry.late_warn = atoi(argv[i+1]) * 60;
 			break;
+		  case 'u':
+			edit.entry.user = mystrdup(argv[i+1]);
+			break;
 		  default:
 			usage();
 		}
@@ -319,20 +384,22 @@ static void non_interactive(argc, argv)
 		if (i < argc-1)
 			strcat(msg, " ");
 	}
+	if (user && !edit.entry.user)
+		edit.entry.user = mystrdup(user[0].name);
+
 	edit.editing	= TRUE;
 	edit.changed	= TRUE;
 	edit.entry.note = mystrdup(msg);
 	edit.entry.time = trigger;
-	if (user)
-		edit.entry.user = mystrdup(user[0].name);
+	edit.entry.file = user[name_to_user(edit.entry.user)].file_id;
 
 	confirm_new_entry();
 	(void)write_mainlist();
 	resynchronize_daemon();
 	printf("%s %s \"%.57s\"\n", mkdatestring(trigger),
 				    mktimestring(trigger, FALSE), msg);
-
-	sprintf(lockfile, PLAN_PATH, (int)getuid());
+	fflush(stdout);
+	sprintf(lockfile, resolve_tilde(PLANLOCK), (int)getuid());
 	if (fp = fopen(lockfile, "r")) {
 		fscanf(fp, "%d", &pid);
 		if (pid > 1)
@@ -344,14 +411,18 @@ static void non_interactive(argc, argv)
 /*
  * -t option, prints an ascii summary of all appointments on a day. This
  * is useful for cronjobs that send mail every morning. Return 1 if there
- * are no entries; this will be used as exit code (to suppress mail).
+ * are no entries; this will be used as exit code (to suppress mail). The
+ * <others> option (-o) prints not only own but also all other lists. The
+ * <ulist> option (-u) prints all lists named in the comma-separated ulist.
  */
 
-static int dumptoday(date, ndays, lengthmode, others)
-	char		*date;		/* dump what day, "" is today */
-	int		ndays;		/* number of days to dump */
-	BOOL		lengthmode;	/* replace end time with length? */
-	BOOL		others;		/* everybody else's appts too? */
+static int dumptoday(
+	char		*date,		/* dump what day, "" is today */
+	int		ndays,		/* number of days to dump */
+	BOOL		lengthmode,	/* replace end time with length? */
+	BOOL		others,		/* everybody else's appts too? */
+	char		*ulist,		/* comma-separated list of users */
+	BOOL		showid)		/* machine-readable format for WWW */
 {
 	struct lookup	lookup;		/* for finding entries */
 	time_t		start;		/* 0:00 of the day to dump */
@@ -361,47 +432,87 @@ static int dumptoday(date, ndays, lengthmode, others)
 	char		userstr[200];	/* buffer for user name */
 	int		i;		/* for checking exceptions */
 	time_t		trigger;
+	char		*dash, *p;
 
 	create_list(&mainlist);
 	read_mainlist();
 
 	start = parse_datestring(date && *date ? date : "today", 0);
 	do {
-		found = lookup_entry(&lookup, mainlist, start, TRUE, FALSE,
-								'*', -1);
-		while (found && lookup.trigger < start + 86400) {
-			struct entry *ep = &mainlist->entry[lookup.index];
-			trigger = lookup.trigger - lookup.trigger % 86400;
-			for (i=0; i < NEXC; i++)
-				if (ep->except[i] == trigger)
-					break;
-			if ((others || !ep->user
-				    || !strcmp(ep->user, user[0].name))
-				   		 && !ep->suspended && i==NEXC){
-				strcpy(timestr,
-					mktimestring(lookup.trigger, FALSE));
-				sprintf(userstr, ep->user ? "%s: " : "",
-					ep->user);
-				printf("%-13s   %-6s  %5s   %s%s\n",
-					mkdatestring(lookup.trigger),
-					ep->notime ? "-    " : timestr,
-					ep->length == 0 ? "-    " : lengthmode
-					    ? mktimestring(ep->length, TRUE)
-					    : mktimestring(lookup.trigger +
-					    		   ep->length, FALSE),
-					userstr,
-					mknotestring(ep));
-				numfound++;
-			}
-			found = lookup_next_entry(&lookup);
+	    for (found=lookup_entry(&lookup,mainlist,start,TRUE,FALSE,'*',-1);
+			found && lookup.trigger < start+86400;
+			found = lookup_next_entry(&lookup)) {
+		struct entry *ep = &mainlist->entry[lookup.index];
+		trigger = lookup.trigger - lookup.trigger % 86400;
+		for (i=0; i < NEXC; i++)
+			if (ep->except[i] == trigger)
+				break;
+		if (i < NEXC || ep->suspended || !ulist && !others &&
+				(ep->user && strcmp(ep->user, user[0].name)))
+			continue;
+		if (ulist) {
+			char *ul = mystrdup(ulist), *u;
+			for (u=strtok(ul, ","); u && !strcmp(u, ep->user);
+							     u=strtok(0, ","));
+			free(ul);
+			if (!u)
+				continue;
 		}
-		start += 86400;
+		strcpy(timestr, mktimestring(lookup.trigger, FALSE));
+		sprintf(userstr, ep->private ? "private: " :
+				 ep->user    ? "%s: "      : "", ep->user);
+		if (showid)
+			printf("%d;", ep->id);
+		dash = showid ? "-" : "-    ";
+		printf(showid ? "%s;%s;%s;%s;%s%s"
+			      : "%-13s   %-6s  %5s   %s%s%s",
+			mkdatestring(lookup.trigger),
+			ep->notime ? dash : timestr,
+			ep->length == 0 ? dash :
+			lengthmode ? mktimestring(ep->length, TRUE)
+				   : mktimestring(lookup.trigger +
+						  ep->length, FALSE),
+			userstr,
+			lookup.days_warn ? "Warn: " : "",
+			mknotestring(ep));
+		if (ep->note && ep->message) {
+			printf(", ");
+			for (p=ep->message; *p; p++)
+				putchar(*p == '\n' ? ' ' : *p);
+		}
+		putchar('\n');
+		numfound++;
+	    }
+	    start += 86400;
 	} while (--ndays > 0);
 	fflush(stdout);
 	return(numfound == 0);
 }
 
 
+/*
+ * -F option: read file list from server and print it to stdout. Should be
+ * used with -W option to select a server.
+ */
+
+static BOOL dumpfilelist(void)
+{
+	char		**list;		/* returned list */
+	int		num, i;		/* returned # of entries in list */
+
+	if (!get_netplan_filelist(config.webplan_host ?
+			config.webplan_host : "localhost", &list, &num))
+		return(FALSE);
+	for (i=0; i < num; i++) {
+		puts(list[i]);
+		free(list[i]);
+	}
+	fflush(stdout);
+	free(list);
+	return(TRUE);
+}
+
+
 /*
  * network.c has opened a new connection fd to a server. Register the file
  * descriptor with the X server so the event loop gets interrupted when
@@ -409,8 +520,8 @@ static int dumptoday(date, ndays, lengthmode, others)
  * modified an appointment and this plan ought to update its database.
  */
 
-XtInputId register_X_input(fd)
-	int		fd;		/* new connection */
+XtInputId register_X_input(
+	int		fd)		/* new connection */
 {
 	return(app ? XtAppAddInput(app, fd, (XtPointer)XtInputReadMask,
 					socket_callback, (XtPointer)0) : 0);
@@ -424,8 +535,8 @@ XtInputId register_X_input(fd)
  * does not have XtRemoveInput.
  */
 
-void unregister_X_input(x_id)
-	XtInputId	x_id;		/* closed connection */
+void unregister_X_input(
+	XtInputId	x_id)		/* closed connection */
 {
 	XtRemoveInput(x_id);
 }
@@ -437,15 +548,16 @@ void unregister_X_input(x_id)
  * appointment on the command line. That entry should appear in our menus.
  */
 
-static void sighand(sig)
-	int			sig;		/* signal type */
+static void sighand(
+	int			sig)		/* signal type */
 {
 	if (sig == SIGHUP) {				/* re-read database */
 		signal(SIGHUP, sighand);
 		reread = TRUE;
 	} else {					/* die */
 		(void)unlink(lockpath);
-		fprintf(stderr, "%s: killed with signal %d\n", progname, sig);
+		fprintf(stderr, _("%s: killed with signal %d\n"),
+							progname, sig);
 		exit(0);
 	}
 }
@@ -455,30 +567,44 @@ static void sighand(sig)
  * usage information
  */
 
-static void usage()
+static void usage(void)
 {
 	fprintf(stderr,
-	    "Usage 1: %s [options]\n\tOptions:\n%s%s%s%s%s%s%s%s%s%s%s\n",
+	    "GUI usage: %s [options]\n\tOptions:\n%s%s%s%s%s\n", progname,
+	    "\t-s\t\tstandalone, don't offer to start daemon\n",
+	    "\t-S\t\tautomatically start daemon if it doesn't exist\n",
+	    "\t-f\t\tdon't fork on startup\n",
+	    "\t-b\t\tdo fork on startup\n",
+	    "\t-k\t\tignore lock file and start up in any case\n");
+	fprintf(stderr,
+	    "append usage: %s %s%s%s%s%s%s%s%s%s%s%s%s\n", progname,
+	    "[mmdd]hhmm [options] [message]*\n",
+	    "\tAdd appointment at mm/dd hh:mm (default is today).\n",
+	    "\tOptions:\n",
+	    "\t-u U\t\tapply to user U instead of own appointments\n",
+	    "\t-l T\t\tappointment length is T (eg., 1:00 is one hour)\n",
+	    "\t-n\t\tappointment has no time-of-day\n",
+	    "\t-r N\t\trepeat every N days\n",
+	    "\t-d N\t\trepeat every day N (1..31) of the month\n",
+	    "\t-D N\t\trepeat every weekday N: 0=mon, 1=tue, ... 6=sun\n",
+	    "\t-e D\t\tend date, stop repeating on date D\n",
+	    "\t-w N\t\tearly warning is N minutes before hhmm time\n",
+	    "\t-W N\t\tlate warning is N minutes before hhmm time\n");
+	fprintf(stderr,
+	    "batch usage: %s options\n\tOptions:\n%s%s%s%s%s%s%s%s%s%s%s%s",
 	    progname,
 	    "\t-h\t\tprint this help text\n",
 	    "\t-d\t\tdump fallback app-defaults and exit\n",
 	    "\t-v\t\tprint version string\n",
+	    "\t-W [H]\t\tcalled from cgi-bin, get files from server host H\n",
+	    "\t-H N\t\tdump all holidays in year N (1970..2037)\n",
+	    "\t-F\t\tdump all files found on netplan server set with -W\n",
 	    "\t-t [D [n]]\ttext dump of n days, starting with date D\n",
 	    "\t-T [D [n]]\tsame as -t, print end time instead of length\n",
-	    "\t-o\t\tmodifies -t/-T output to include other users\n",
 	    "\t\t\teg: -t, -t +3, -T tomorrow, -o -t 24.12. 3, -o -T wed 7\n",
-	    "\t-s\t\tstandalone, don't offer to start daemon\n",
-	    "\t-S\t\tautomatically start daemon if it doesn't exist\n",
-	    "\t-f\t\tdon't fork on startup\n",
-	    "\t-k\t\tignore lock file and start up in any case\n");
-	fprintf(stderr,
-	    "Usage 2: %s [mmdd]hhmm [options] [message]*\n%s%s%s%s%s",
-	    progname,
-	    "\tAdd appointment at mm/dd hh:mm (default is today).\n",
-	    "\tOptions:\n",
-	    "\t-l T\t\tappointment length is T (eg., 1:00 is one hour)\n",
-	    "\t-w N\t\tearly warning is N minutes before hhmm time\n",
-	    "\t-W N\t\tlate warning is N minutes before hhmm time\n");
+	    "\t-o\t\tmodifies -t/-T output to show other users\n",
+	    "\t-u N\t\tmodifies -t/-T to show comma-separated user list N\n",
+	    "\t-i\t\tmake -t/-T machine-readable (used by WWW frontend)\n");
 	exit(1);
 }
 
@@ -487,11 +613,16 @@ static void usage()
  * exit is redefined here so it the database is written back before the
  * program dies for any reason - including Motif-Quit.
  * How is this for a hack :-) That's what you get for downloading sources
- * from alt.sources...
+ * from alt.sources... This trick doesn't work on FreeBSD, but atexit is
+ * not available everywhere so it's #ifdefed.
  */
 
-void exit(ret)
-	int ret;
+#ifdef __FreeBSD__
+void plan_exit(
+#else
+void exit(
+#endif
+	int	ret)
 {
 	static int exiting = 0;
 	if (!exiting++) {
@@ -503,7 +634,9 @@ void exit(ret)
 		}
 	}
 	_exit(ret);
+#ifndef __FreeBSD__
 	exit(ret);
+#endif
 }
 
 
@@ -515,11 +648,11 @@ void exit(ret)
 
 #define get_rsrc(A,B,C,D) do_get_rsrc((XtPointer)A, B, C, D)
 
-void do_get_rsrc(ret, res_name, res_class_name, res_type)
-	XtPointer	ret;
-	char		*res_name;
-	char		*res_class_name;
-	char		*res_type;
+void do_get_rsrc(
+	XtPointer	ret,
+	char		*res_name,
+	char		*res_class_name,
+	char		*res_type)
 {
 	XtResource	res_list[1];
 
@@ -535,7 +668,7 @@ void do_get_rsrc(ret, res_name, res_class_name, res_type)
 }
 
 
-static void init_resources()
+static void init_resources(void)
 {
 	register struct config	*c = &config;
 	char			*startup_as = 0;
@@ -587,11 +720,10 @@ static void init_resources()
  * to set_color(COL_XXX).
  */
 
-static void init_colors()
+static void init_colors(void)
 {
 	Screen			*screen = DefaultScreenOfDisplay(display);
 	Colormap		cmap;
-	XColor			rgb;
 	int			i, d;
 	char			*c, *n, class_name[256];
 
@@ -650,18 +782,23 @@ static void init_colors()
 		strcpy(class_name, n);
 		class_name[0] &= ~('a'^'A');
 		get_rsrc(&c, n, class_name, XtRString);
-		if (!XParseColor(display, cmap, c, &rgb))
-			fprintf(stderr, "%s: unknown color for %s\n",
+		if (!XParseColor(display, cmap, c, &xcolor[i]))
+			fprintf(stderr, _("%s: unknown color for %s\n"),
 							progname, n);
-		else if (!XAllocColor(display, cmap, &rgb))
-			fprintf(stderr, "%s: can't alloc color for %s\n",
+		else if (!XAllocColor(display, cmap, &xcolor[i]))
+			fprintf(stderr, _("%s: can't alloc color for %s\n"),
 							progname, n);
 		else {
-			color[i] = rgb.pixel;
+			color[i] = xcolor[i].pixel;
 			continue;
 		}
-		color[i] = d ? BlackPixelOfScreen(screen)
-			     : WhitePixelOfScreen(screen);
+		if (d) {
+			color[i] = BlackPixelOfScreen(screen);
+			xcolor[i].red = xcolor[i].green = xcolor[i].blue = 0;
+		} else {
+			color[i] = WhitePixelOfScreen(screen);
+			xcolor[i].red = xcolor[i].green = xcolor[i].blue = ~0;
+		}
 	}
 }
 
@@ -671,7 +808,7 @@ static void init_colors()
  * loaded into the GC as necessary.
  */
 
-static void init_fonts()
+static void init_fonts(void)
 {
 	int			i;
 	char			*f, *nf, class_name[256];
@@ -700,10 +837,11 @@ static void init_fonts()
 		class_name[0] &= ~('a'^'A');
 		get_rsrc(&nf, f, class_name, XtRString);
 		if (!(font[i] = XLoadQueryFont(display, nf))) {
-			fprintf(stderr, "plan: warning: bad font for %s\n", f);
+			fprintf(stderr, _("plan: warning: bad font for %s\n"),
+									f);
 			if (!(font[i] = XLoadQueryFont(display, "variable")) &&
 			    !(font[i] = XLoadQueryFont(display, "fixed")))
-				fatal("can't load font \"variable\"\n", f);
+				fatal(_("can't load font \"variable\"\n"), f);
 		}
 	}
 	config.calbox_title[0]	= font[FONT_STD]   ->max_bounds.ascent +
@@ -725,14 +863,14 @@ static void init_fonts()
 
 static PID_T		daemon_pid;	/* process ID of daemon (gets SIGHUP)*/
 
-static void init_daemon()
+static void init_daemon(void)
 {
 	int			i, lockfd;	/* lockfile descriptor */
 	char			path[256];	/* lockfile path */
 	char			buf[12];	/* contents of file (pid) */
 
 	daemon_pid = 0;
-	sprintf(path, LOCK_PATH, (int)getuid());
+	sprintf(path, resolve_tilde(PLANDLOCK), (int)getuid());
 	if ((lockfd = open(path, O_RDONLY)) < 0) {
 		if (rundaemon) {
 			run_daemon(0);
@@ -745,7 +883,7 @@ static void init_daemon()
 		if (lockfd < 0) {
 			if (!nodaemon) {
 				int e = errno;
-				fprintf(stderr, "%s: WARNING - no daemon, ",
+				fprintf(stderr, _("%s: WARNING - no daemon, "),
 							progname);
 				errno = e;
 				perror(path);
@@ -754,7 +892,8 @@ static void init_daemon()
 		}
 	}
 	if (read(lockfd, buf, 10) < 5) {
-		fprintf(stderr,"%s: WARNING: daemon lockfile %s unreadable: ",
+		fprintf(stderr,
+			_("%s: WARNING: daemon lockfile %s unreadable: "),
 							progname, path);
 		perror("");
 		return;
@@ -765,19 +904,19 @@ static void init_daemon()
 }
 
 
-void resynchronize_daemon()
+void resynchronize_daemon(void)
 {
-	if (!daemon_pid || kill(daemon_pid, SIGHUP)) {
+	if (!config.webplan && (!daemon_pid || kill(daemon_pid, SIGHUP))) {
 		init_daemon();
 		if (!nodaemon && (!daemon_pid || kill(daemon_pid, SIGHUP))) {
-			fprintf(stderr, "%s: WARNING: can't signal daemon: ",
+			fprintf(stderr, _("%s: WARNING: can't signal daemon: "),
 								progname);
 			perror("");
 			if (interactive)
 				create_nodaemon_popup();
 			else
 				fprintf(stderr,
-				       "%s: WARNING: no daemon, run pland\n",
+				       _("%s: WARNING: no daemon, run pland\n"),
 								progname);
 		}
 	}
@@ -788,21 +927,25 @@ void resynchronize_daemon()
  * this routine gets called every 10 seconds. Redraw the main calendar when
  * midnight passes, to move the green highlight. Write the main list if it
  * has changed. Also, see if any old entries need to be recycled or deleted.
- * If we got a SIGHUP signal, re-read the database when it is safe.
+ * If we got a SIGHUP signal, re-read the database when it is safe. Keep the
+ * last X timer time in last_x_timer - recent XFree servers (as of June 99)
+ * appear to have a bug or incompatibility that prevents X timers from
+ * happening. This way other code can find out about the failure and write
+ * back changes immediately.
  */
 
 /*ARGSUSED*/
-static void timer_callback(data, id)
-	XtPointer		data;		/* not used */
-	XtIntervalId		*id;		/* not used */
+static void timer_callback(
+	XtPointer		data,		/* not used */
+	XtIntervalId		*id)		/* not used */
 {
 	static time_t		last_tod;	/* previous time-of-day */
 	time_t			tod;		/* current time-of-day */
 
 	timer_id = XtAppAddTimeOut(app, TIMER_PERIOD, timer_callback, 0);
 	set_tzone();
-	tod = get_time();
-	tod %= 86400;
+	last_x_timer = get_time();
+	tod = last_x_timer % 86400;
 	if (tod < last_tod)
 		redraw_all_views();
 
@@ -828,7 +971,7 @@ static void timer_callback(data, id)
 		update_all_listmenus();
 		redraw_all_views();
 	}
-	if (config.autodel && recycle_all(mainlist, TRUE, 0)) {
+	if (recycle_all(mainlist, config.autodel, 7)) {
 		draw_calendar(NULL);
 		update_all_listmenus();
 	}
@@ -844,10 +987,10 @@ static void timer_callback(data, id)
  * socked <fd> and let gets_server handle asynchronous events.
  */
 
-static void socket_callback(data, fd, x_id)
-	XtPointer	data;
-	int		*fd;
-	XtInputId	*x_id;
+static void socket_callback(
+	XtPointer	data,
+	int		*fd,
+	XtInputId	*x_id)
 {
 	char		buf[1024];	/* message buffer for gets_server */
 	BOOL		save_mod;	/* auto-update isn't a modification */
