@@ -11,10 +11,11 @@ typedef void *Widget;	/* dummy for prototype declarations in config.h */
 #include <stdarg.h>
 #include <time.h>
 #include <limits.h>
+#include <sys/types.h>
+#include <dirent.h>
 #ifdef IBM
 #include <sys/select.h>
 #endif
-#include <sys/types.h>
 #include <sys/time.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
@@ -108,12 +109,15 @@ wF R <row> -> wSR		write one row, R=0: create\\\n\
 dF R       ->			delete a row\\\n\
 lF R       -> lS		lock row for editing\\\n\
 uF R       ->			unlock row\\\n\
+q          ->                   close connection explicitly\\\n\
+L          -> LS<user> ... LS   list of users\\\n\
 -          -> ?<msg>		server wants client to put up error popup\\\n\
 .          -> .msg		debugging info";
 
 
 /*------------------------------------- networking --------------------------*/
-main(
+
+int main(
 	int		argc,
 	char		**argv)
 {
@@ -164,10 +168,11 @@ main(
 #endif
 #endif
 	if (getuid() == 0 || geteuid() == 0) {
-		log("switching from user <root> to <nobody>\n");
+		log("switching from user <root> to <uid %d gid %d>\n",
+						NOBODY_UID, NOBODY_GID);
 #ifndef __hpux
 #ifdef SETREUID
-		setregid(NOBODY_GID,NOBODY_GID);
+		setregid(NOBODY_GID, NOBODY_GID);
 #else
 		setgid(NOBODY_GID);
 		setegid(NOBODY_GID);
@@ -178,7 +183,7 @@ main(
 
 #ifndef __hpux
 #ifdef SETREUID
-		setreuid(NOBODY_UID,NOBODY_UID);
+		setreuid(NOBODY_UID, NOBODY_UID);
 #else
 		setuid(NOBODY_UID);
 		seteuid(NOBODY_UID);
@@ -297,7 +302,8 @@ main(
 			for (i=1; i < NGROUPS_MAX; i++)
 				cp->gids[i] = -1;
 
-			log("client %d connected from %s\n",fd,ip_addr(&addr));
+			log("client %d (%.200s) connected from %s\n", fd,
+						cp->descr, ip_addr(&addr));
 			reply(fd, cp, "!t%s enter ? for help", DVERSION);
 			cp->time = time(0);
 		}
@@ -306,8 +312,7 @@ main(
 				continue;
 			if (FD_ISSET(fd, &rd))			/* recv cmd */
 				if (!message(fd)) {
-					log("client %d (%.200s) disconnected\n"
-						,fd, client_list[fd].descr);
+					log("client %d disconnected\n", fd);
 					close_client(fd);
 					FD_CLR(fd, &rd0);
 					close(fd);
@@ -560,7 +565,7 @@ static void eval_message(
 	register char	*arg)		/* command and argument scan ptr */
 {
 	register struct client *c = &client_list[fd];
-	register char	*p, *q;		/* for eliminating \r and \\n->\n */
+	register char	*p;		/* for eliminating \r and \\n->\n */
 	register int	n, i;		/* number of bytes read from socket */
 	int		fid;		/* file ID argument */
 	BOOL            ronly;          /* read-only flag */
@@ -568,6 +573,8 @@ static void eval_message(
 	char            *id;
 	struct passwd   *pw;
 	char            buf[4096];
+	DIR		*dir;
+	struct dirent	*entry;
 
 	static const char * const cmode[] = {
 		"not connected",
@@ -576,7 +583,7 @@ static void eval_message(
 		"modified" };
 
 	if (verbose)
-		log("client %d (%.200s) sends %.400s", fd, c->descr, arg);
+		log("client %d sends %.400s", fd, arg);
 	switch(*arg++) {
 	  case '\n':
 		break;
@@ -587,7 +594,7 @@ static void eval_message(
 			release(c->descr);
 			release(c->user);
 			c->descr     = make_descr(c, id, arg);
-			c->user      = id;
+			c->user      = mystrdup(id);
 			c->uid       = pw->pw_uid;
 			c->auth_fail = FALSE;
 			setup_gids(c, pw->pw_gid, id);
@@ -601,6 +608,7 @@ static void eval_message(
 			}
 			strcpy(p, "\n");
 			log(buf);
+			id = 0;
 
 		} else if (do_auth) {
 			c->auth_fail = TRUE;
@@ -629,7 +637,7 @@ static void eval_message(
 				sprintf(p, " %d", c->gids[i]);
 				p += strlen(p);
 			}
-			strcpy(p, "\n");
+			strcpy(p, ")\n");
 			log(buf);
 		}
 		release(id);
@@ -687,7 +695,7 @@ static void eval_message(
 	  case 'l':
 		fid = atoi(arg); SKIP(arg);
 		rid = atoi(arg);
-		reply(fd, c, "l%c", "ft"[lock_row(fid, rid, fd, TRUE)]);
+		reply(fd, c, "l%c", "ft"[(int)lock_row(fid, rid, fd, TRUE)]);
 		break;
 
 	  case 'u':
@@ -718,7 +726,7 @@ static void eval_message(
 					"%.20s, since %.15s %.20s",
 					n, cp->descr, ip_addr(&cp->addr),
 					ctime(&cp->time)+4,
-					cmode[f->client[n]]);
+					cmode[(int)f->client[n]]);
 				appendbuf(out, msg, strlen(msg));
 				FD_SET(fd, &wr0);
 			}
@@ -728,6 +736,24 @@ static void eval_message(
 		FD_SET(fd, &wr0);
 		break; }
 
+	  case 'L':
+		if (dir = opendir(HOMEDIR "/" NETDIR)) {
+			while (entry = readdir(dir))
+				if (entry->d_name[0] != '.')
+					reply(fd, c, "Lt%s", entry->d_name);
+			closedir(dir);
+			reply(fd, c, "Lt");
+		} else
+			reply(fd, c, "Lf");
+		break;
+
+	  case 'q':
+		close_client(fd);
+		FD_CLR(fd, &rd0);
+		close(fd);
+		log("client %d disconnected\n", fd);
+		break;
+
 	  default:
 		error(fd, "%.2048s", usage);
 	}
@@ -792,22 +818,21 @@ static BOOL check_file(
 	char		*msg = 0;	/* file error message */
 
 	if (strstr("..", fname))
-		msg = "\"..\" in %.20s not allowed%s";
+		msg = "\"..\" in %.80s not allowed%s";
 	else if (fstat(fileno(fp), &sbuf) < 0)
-		msg = "cannot stat %.20s%s";
-	else if ((sbuf.st_mode & S_IFMT) == S_IFDIR)
-		msg = "%.20s is a directory%s";
+		msg = "cannot stat %.80s%s";
+	else if (IS_DIR(sbuf.st_mode))
+		msg = "%.80s is a directory%s";
 	else if ((sbuf.st_mode & S_IFMT) == S_IFLNK)
-		msg = "%.20s is a symbolic link%s";
+		msg = "%.80s is a symbolic link%s";
 	else if (sbuf.st_mode & S_IFCHR)
-		msg = "%.20s is a device node%s";
+		msg = "%.80s is a device node%s";
 	else if (sbuf.st_nlink != 1)
-		msg = "%.20s has more than one link%s";
+		msg = "%.80s has more than one link%s";
 	if (msg) {
 		error(0,  msg, fname, " (this is a security risk)");
 		error(fd, msg, fname, "\\\n(this is a security risk).");
-		log("client %d (%.200s) fails to open %.20s\n",
-							fd, c->descr, fname);
+		log("client %d fails to open %.80s\n", fd, fname);
 		return(FALSE);
 	}
 	return(TRUE);
@@ -846,8 +871,7 @@ static int open_file(
 	int		r, w, d;	/* permissions from access list */
 
 	if (!*fname) {
-		error(0, "client %d (%.200s) opens null file name",
-								fd, c->descr);
+		error(0, "client %d opens null file name", fd);
 		error(fd, "cannot open null file name");
 		return(-1);
 	}
@@ -860,8 +884,7 @@ static int open_file(
 		acl_verify(&r, &w, &d, fname, c);
 	ro = !w;
 	if (!r || *fname == '.') {
-		error(0, "access to %.20s refused to client %d (%.200s)",
-							fname, fd, c->descr);
+		error(0, "access to %.20s refused to client %d", fname, fd);
 		error(fd, "Access to file %.20s denied by server.", fname);
 		return(-1);
 	}
@@ -876,9 +899,8 @@ static int open_file(
 			if (!f->client[fd])
 				f->nclients++;
 			f->client[fd] = ro ? 1 : 2;
-			log("client %d (%.200s) opens cached file %.200s "
-			    "%.20s\n", fd, c->descr, fname,
-			    (ro ? "readonly" : "readwrite"));
+			log("client %d opens cached file %.200s %.20s\n", fd,
+					fname, ro ? "readonly" : "readwrite");
 			*ronly = ro;
 			return(fid);
 		}
@@ -950,12 +972,11 @@ static int open_file(
 				buf = reallocate(buf, size += BUFINC);
 			buf[i++] = c;
 		}
-		log("client %d (%.200s) opens new file %.20s (type %d), read %"
-			"d entries\n", fd, c->descr, fname, f->type, f->nrows);
+		log("client %d opens new file %.20s (type %d), read %d entrie"
+					"s\n", fd, fname, f->type, f->nrows);
 		fclose(fp);
 	} else
-		log("client %d (%.200s) opens non-existing file %.20s\n",
-			fd, c->descr, fname);
+		log("client %d opens non-existing file %.20s\n", fd, fname);
 	release(buf);
 	f->client[fd] = ro ? 1 : 2;	/* do this here to avoid notify msgs */
 	f->nclients   = 1;
@@ -981,7 +1002,7 @@ static void close_file(
 
 	if (fid < 0 || fid >= max_files || !f->name || !f->client[fd])
 		return;
-	log("client %d (%.200s) closes file %.20s\n", fd, c->descr, f->name);
+	log("client %d closes file %.20s\n", fd, f->name);
 	write_file(fid);			/* write changes */
 	f->client[fd] = 0;			/* detach client from file */
 	f->nclients--;
@@ -1221,7 +1242,7 @@ static BOOL lock_row(
 	int			fd,		/* client identifier */
 	BOOL			lock)		/* lock or unlock? */
 {
-	int			index, i;	/* index of new row in table */
+	int			index;		/* index of new row in table */
 	BOOL			found;		/* replace existing row? */
 	struct pfile		*f = &file_list[fid];
 
@@ -1283,8 +1304,7 @@ static void send_row(
 		sprintf(buf, "%ct%d %d ", opcode, fid, row->id);
 		appendbuf(&c->out, buf, strlen(buf));
 		if (verbose)
-			log("client %d (%.200s) reply %.50s<data>\n",
-							fd, c->descr, buf);
+			log("client %d reply %.50s<data>\n", fd, buf);
 		for (p=row->data; *p; ) {
 			for (q=buf; *p && q < buf+sizeof(buf)-1; ) {
 				if (*p == '\n') {
@@ -1353,7 +1373,7 @@ static void reply(int fd, struct client *c, char *fmt, ...)
 	strcat(msg, "\n");
 	appendbuf(&client_list[fd].out, msg, strlen(msg));
 	if (verbose)
-		log("client %d (%.200s) reply %.400s", fd, c->descr, msg);
+		log("client %d reply %.400s", fd, msg);
 	FD_SET(fd, &wr0);
 }
 
@@ -1406,7 +1426,7 @@ void log(char *fmt, ...)
 
 
 /*
- * return static string descriping an IP address with port number
+ * return static string describing an IP address with port number
  */
 
 char *ip_addr(register struct sockaddr_in *addr)
@@ -1414,10 +1434,10 @@ char *ip_addr(register struct sockaddr_in *addr)
 	static char buf[64];
 	unsigned long a = ntohl(addr->sin_addr.s_addr);
 	sprintf(buf, "%d.%d.%d.%d:%d",
-		(a >> 24) & 255,
-		(a >> 16) & 255,
-		(a >>  8) & 255,
-		(a      ) & 255,
+		(int)((a >> 24) & 255),
+		(int)((a >> 16) & 255),
+		(int)((a >>  8) & 255),
+		(int)((a      ) & 255),
 		ntohs(addr->sin_port));
 	return(buf);
 }
