@@ -14,6 +14,7 @@
  */
 
 #include <stdio.h>
+#include <unistd.h>
 #include <errno.h>
 #include <time.h>
 #include <string.h>
@@ -23,7 +24,9 @@
 #include <stdarg.h>
 #endif
 #include <sys/types.h>
-#include <unistd.h>
+#ifdef __EMX__
+#include <sys/wait.h>
+#endif
 #include <Xm/Xm.h>
 #include <Xm/MessageB.h>
 #include <Xm/Protocols.h>
@@ -54,14 +57,15 @@ Author: Thomas Driemeyer\n\
 <thomas@bitrot.de, thomas@bitrot.in-berlin.de>\n\n\
 Send mail to majordomo@bitrot.de to subscribe\n\
 to the mailing list.  Or check out my home page:\n\n\
-http://www.bitrot.de      (coming soon)\n\
+http://www.bitrot.de\n\
 http://www.in-berlin.de/User/bitrot\n\n\
 The sources are available at\n\
-ftp://ftp.fu-berlin.de/pub/unix/graphics\
+ftp://bitrot.in-berlin.de/pub/plan\n\
+ftp://ftp.fu-berlin.de/pub/unix/graphics/plan\
 \n";
 
 
-void create_about_popup()
+void create_about_popup(void)
 {
 	char			msg[512];
 	Widget			dialog;
@@ -69,11 +73,11 @@ void create_about_popup()
 	Arg			args[10];
 	int			n;
 
-	sprintf(msg, about_message, VERSION, __DATE__);
+	sprintf(msg, _(about_message), VERSION JAPANVERSION, __DATE__);
 	s = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	n = 0;
 	XtSetArg(args[n], XmNmessageString,	s);			n++;
-	dialog = XmCreateInformationDialog(mainwindow, "About", args, n);
+	dialog = XmCreateInformationDialog(mainwindow, _("About"), args, n);
 	XmStringFree(s);
 	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON));
 	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON));
@@ -85,14 +89,21 @@ void create_about_popup()
 /*---------------------------------------------------------- errors ---------*/
 /*VARARGS*/
 #ifndef VARARGS
-void create_error_popup(Widget widget, int error, char *fmt, ...)
+void create_error_popup(
+	Widget			widget,
+	int			error,
+	char			*fmt, ...)
 {
 	va_list			parm;
 #else
-void create_error_popup(widget, error, fmt, a, b, c, d)
-	Widget			widget;
-	int			error, a, b, c, d;
-	char			*fmt;
+void create_error_popup(
+	Widget			widget,
+	int			error,
+	int			a,
+	int			b,
+	int			c,
+	int			d,
+	char			*fmt)
 {
 #endif
 	char			msg[10240];
@@ -102,7 +113,7 @@ void create_error_popup(widget, error, fmt, a, b, c, d)
 
 	if (!widget)
 		widget = mainwindow;
-	strcpy(msg, "ERROR:\n\n");
+	strcpy(msg, _("ERROR:\n\n"));
 
 #ifndef VARARGS
 	va_start(parm, fmt);
@@ -117,13 +128,13 @@ void create_error_popup(widget, error, fmt, a, b, c, d)
 		strcat(msg, sys_errlist[error]);
 	}
 #	endif
-	if (!interactive) {
+	if (!interactive || !widget) {
 		fputs(msg, stderr);
 		return;
 	}
 	string = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
 	XtSetArg(args, XmNmessageString, string);
-	dialog = XmCreateWarningDialog(widget, "Error", &args, 1);
+	dialog = XmCreateWarningDialog(widget, _("Error"), &args, 1);
 	XmStringFree(string);
 	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON));
 	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON));
@@ -137,13 +148,14 @@ static char nodaemon_message[] = "\
 Warning:\n\
 There is no Scheduler daemon. Without a daemon,\n\
 no action will be taken when an alarm triggers.\n\
-Please start \"%s\" in your ~/.xsession or ~/.sgisession file.";
+Please start \"%s\" in your ~/.xsession or\n\
+~/.sgisession file, or run plan with the -S option.";
 
 void run_daemon();
 static void cancel_callback();
 static BOOL running;
 
-void create_nodaemon_popup()
+void create_nodaemon_popup(void)
 {
 	char			msg[512];
 	Widget			dialog;
@@ -158,21 +170,22 @@ void create_nodaemon_popup()
 	if (suppress_daemon_warning)
 		return;
 #endif
-	sprintf(msg, nodaemon_message, DAEMON_FN);
+	sprintf(msg, _(nodaemon_message), DAEMON_FN);
 	s1 = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	s2 = XmStringCreateSimple("Start daemon now");
-	s3 = XmStringCreateSimple("Continue without daemon");
+	s2 = XmStringCreateSimple(_("Start daemon now"));
+	s3 = XmStringCreateSimple(_("Continue without daemon"));
 	n = 0;
 	XtSetArg(args[n], XmNmessageString,	s1);		n++;
 	XtSetArg(args[n], XmNokLabelString,	s2);		n++;
 	XtSetArg(args[n], XmNcancelLabelString,	s3);		n++;
-	dialog = XmCreateWarningDialog(mainwindow, "Warning", args, n);
+	dialog = XmCreateWarningDialog(mainwindow, _("Warning"), args, n);
 	XmStringFree(s1);
 	XmStringFree(s2);
 	XmStringFree(s3);
-	XtAddCallback(dialog, XmNokCallback, run_daemon, (XtPointer)NULL);
-	XtAddCallback(dialog, XmNcancelCallback, cancel_callback,
-							  (XtPointer)NULL);
+	XtAddCallback(dialog, XmNokCallback, (XtCallbackProc)
+			run_daemon, (XtPointer)NULL);
+	XtAddCallback(dialog, XmNcancelCallback, (XtCallbackProc)
+			cancel_callback, (XtPointer)NULL);
 	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON));
 	(void)XmInternAtom(display, "WM_DELETE_WINDOW", False);
 	XtManageChild(dialog);
@@ -181,37 +194,45 @@ void create_nodaemon_popup()
 
 /*
  * start the daemon. Nohup the daemon process so that it survives the death
- * of its parent. Also used by the -S autostart option.
+ * of its parent. Also used by the -S autostart option. pland immediately
+ * backgrounds itself, so the main process must call wait() to avoid zombies.
  */
 
 /*ARGSUSED*/
-void run_daemon(dialog)
-	Widget			dialog;		/* not used */
+void run_daemon(
+	Widget		dialog)		/* not used */
 {
-	char			path[1024];
-	PID_T			pid;
+	char		path[1024];
+	PID_T		pid;
 
 	running = FALSE;
 	if (!find_file(path, DAEMON_FN, TRUE)) {
-		fprintf(stderr, "%s: WARNING: can't find %s\n",
+		fprintf(stderr, _("%s: WARNING: can't find %s\n"),
 							progname, DAEMON_FN);
 		create_nodaemon_popup();
 		return;
 	}
 	pid = fork();
-	if (pid > 0)
+	if (pid > 0) {
+		wait(0);
 		return;
+	}
 	if (pid == 0) {
-		fprintf(stderr, "%s: starting %s\n", progname, DAEMON_FN);
+		fprintf(stderr, _("%s: starting %s\n"), progname, DAEMON_FN);
 #if defined(BSD) || defined(MIPS)
 		setpgrp(0, 0);
+#else
+#ifdef __EMX__
+
 #else
 		setsid();
 #endif
-		detach_from_network ();
+#endif
+		detach_from_network();
 		execl(path, DAEMON_FN, 0);
 	}
-	fprintf(stderr, "%s: WARNING: can't start %s: ", progname, DAEMON_FN);
+	fprintf(stderr, _("%s: WARNING: can't start %s: "), progname,
+								DAEMON_FN);
 	perror("");
 	create_nodaemon_popup();
 }
@@ -223,8 +244,8 @@ void run_daemon(dialog)
  */
 
 /*ARGSUSED*/
-static void cancel_callback(dialog)
-	Widget			dialog;
+static void cancel_callback(
+	Widget		dialog)
 {
 	running = FALSE;
 	suppress_daemon_warning = True;
@@ -241,32 +262,34 @@ attempt to kill the other program. Continuing\n\
 may cause loss of new appointment entries, and\n\
 command-line entry of appointments will not work.";
 
-static void kill_callback();
+static void kill_callback(Widget, XtPointer, XtPointer);
 
-
-void create_multiple_popup(nolock)
-	BOOL			nolock;		/* tried to kill competitor */
+void create_multiple_popup(
+	BOOL		nolock)		/* tried to kill competitor */
 {
-	char			msg[512];
-	Widget			dialog;
-	XmString		s1, s2, s3;
-	Arg			args[10];
-	int			n;
+	char		msg[512];
+	Widget		dialog;
+	XmString	s1, s2, s3;
+	Arg		args[10];
+	int		n;
 
-	sprintf(msg, multiple_message, progname,
-		nolock ? "The other program could not be killed.\n" : "");
+	sprintf(msg, _(multiple_message), progname,
+		nolock ? _("The other program could not be killed.\n") : "");
 	s1 = XmStringCreateLtoR(msg, XmSTRING_DEFAULT_CHARSET);
-	s2 = XmStringCreateSimple("Kill");
-	s3 = XmStringCreateSimple("Continue");
+	s2 = XmStringCreateSimple(_("Kill"));
+	s3 = XmStringCreateSimple(_("Continue"));
 	n = 0;
 	XtSetArg(args[n], XmNmessageString,	s1);		n++;
 	XtSetArg(args[n], XmNokLabelString,	s2);		n++;
 	XtSetArg(args[n], XmNcancelLabelString,	s3);		n++;
-	dialog = XmCreateWarningDialog(mainwindow, "Warning", args, n);
+	XtSetArg(args[1], XmNdialogStyle,
+			  XmDIALOG_FULL_APPLICATION_MODAL);	n++;
+	dialog = XmCreateWarningDialog(mainwindow, _("Warning"), args, n);
 	XmStringFree(s1);
 	XmStringFree(s2);
 	XmStringFree(s3);
-	XtAddCallback(dialog, XmNokCallback, kill_callback, (XtPointer)NULL);
+	XtAddCallback(dialog, XmNokCallback, (XtCallbackProc)
+			kill_callback, (XtPointer)NULL);
 	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON));
 	(void)XmInternAtom(display, "WM_DELETE_WINDOW", False);
 	XtManageChild(dialog);
@@ -278,32 +301,56 @@ void create_multiple_popup(nolock)
  */
 
 /*ARGSUSED*/
-static void kill_callback(dialog)
-	Widget			dialog;
+static void kill_callback(
+	Widget		dialog,
+	XtPointer	a,
+	XtPointer	b)
 {
-	if (!startup_lock(PLAN_PATH, TRUE))
+	if (!startup_lock(resolve_tilde(PLANLOCK), TRUE))
 		create_multiple_popup(TRUE);
 }
 
 
 /*---------------------------------------------------------- multiple wr ----*/
-void multiple_writer_warning_popup(widget)
-	Widget			widget;		/* install near this widget */
+void multiple_writer_warning_popup(
+	Widget		widget)		/* install near this widget */
 {
-	Widget			dialog;
-	XmString		string;
-	Arg			args;
+	Widget		dialog;
+	XmString	string;
+	Arg		args[2];
 
 	string = XmStringCreateLtoR(
-"WARNING:\n\n\
+_("WARNING:\n\n\
 You can now edit other users' appointments.\n\
 plan will normally notice multiple writes at the same\n\
 time (except over NFS), but will not notice if another\n\
 user has modified the same appointment file while you\n\
 were changing it. The older changes will get lost in\n\
-this case. Watch out!", XmSTRING_DEFAULT_CHARSET);
-	XtSetArg(args, XmNmessageString, string);
-	dialog = XmCreateWarningDialog(widget, "Error", &args, 1);
+this case. Watch out!)"), XmSTRING_DEFAULT_CHARSET);
+	XtSetArg(args[0], XmNmessageString, string);
+	XtSetArg(args[1], XmNdialogStyle, XmDIALOG_FULL_APPLICATION_MODAL);
+	dialog = XmCreateWarningDialog(widget, _("Error"), args, 2);
+	XmStringFree(string);
+	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON));
+	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON));
+	(void)XmInternAtom(display, "WM_DELETE_WINDOW", False);
+	XtManageChild(dialog);
+}
+
+
+/*---------------------------------------------------------- multiple wr ----*/
+void new_language_popup(
+	Widget		widget)		/* install near this widget */
+{
+	Widget		dialog;
+	XmString	string;
+	Arg		args[2];
+
+	string = XmStringCreateLtoR(_("The new language will be effective\n"
+			"after plan is restarted."), XmSTRING_DEFAULT_CHARSET);
+	XtSetArg(args[0], XmNmessageString, string);
+	XtSetArg(args[1], XmNdialogStyle, XmDIALOG_FULL_APPLICATION_MODAL);
+	dialog = XmCreateWarningDialog(widget, _("Warning"), args, 2);
 	XmStringFree(string);
 	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_CANCEL_BUTTON));
 	XtUnmanageChild(XmMessageBoxGetChild(dialog, XmDIALOG_HELP_BUTTON));
