@@ -8,12 +8,13 @@
  *
  * Originally by Karl Bunch, extensively hacked 23.12.94 by thomas@bitrot
  * Only-my-appointments toggle added by Richard G. Hash (rgh@shell.com)
+ * More hacking by thomas@bitrot 25.12.98, color
  */
 
 #include <stdio.h>
+#include <unistd.h>
 #include <time.h>
 #include <signal.h>
-#include <unistd.h>
 #include <Xm/Xm.h>
 #include <Xm/DialogS.h>
 #include <Xm/Form.h>
@@ -31,23 +32,26 @@
 #include <fcntl.h>
 #include <errno.h>
 
-#define PS_LIB "plan_cal.ps"
-
+#define PS_LIB		"plan_cal.ps"
 #ifdef JAPAN
-#define PS_LIB_SJ  "plan_calSJ.ps"
+#define PS_LIB_SJ	"plan_calSJ.ps"
 extern char		*localename;
 #endif
 #ifdef BSD
-extern FILE *popen();
+extern FILE		*popen();
 #endif
 
-int			Print_Calendar();
-static int		Print_Day();
-static void		OutStr();
-static void		mode_callback(), print_callback(), done_callback();
-static void		omit_appts_callback(), omit_priv_callback();
-static void		omit_others_callback();
-
+static void mode_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void omit_appts_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void omit_priv_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void omit_others_callback(Widget, int, XmToggleButtonCallbackStruct *);
+static void color_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void print_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void broken_pipe_handler	(int);
+static int Print_Calendar	(FILE *, int, int, int, int);
+static int Print_Day		(FILE *, int, int, int, int);
+static void OutStr		(FILE *, char *);
 
 extern int		curr_month, curr_year, curr_week;
 extern struct holiday	holiday[];
@@ -58,6 +62,7 @@ extern Display		*display;		/* everybody uses this server*/
 extern struct config	config;			/* global configuration data */
 extern struct plist	*mainlist;		/* list of all sched entries */
 extern Pixel		color[NCOLS];		/* colors: COL_* */
+extern XColor		xcolor[NCOLS];		/* for PostScript color */
 extern char		Print_Spooler[100];	/* defined in file_r.c */
 
 char			*Default_Spooler = PS_SPOOLER;
@@ -73,7 +78,7 @@ static Widget		spool_text;		/* Spool String Text Widget */
  * that it comes up with the same defaults.
  */
 
-void create_print_popup()
+void create_print_popup(void)
 {
 	Widget		print_form, w;
 	Widget		mode_frame, mode_form, mode_radio;
@@ -88,7 +93,7 @@ void create_print_popup()
 		XtPopup(print_shell, XtGrabNone);
 		return;
 	}
-	print_shell = XtVaAppCreateShell("Print", "plan",
+	print_shell = XtVaAppCreateShell(_("Print"), "plan",
 					applicationShellWidgetClass, display,
 					XmNdeleteResponse, XmDO_NOTHING,
 					XmNiconic, False,
@@ -99,8 +104,8 @@ void create_print_popup()
 	print_form = XtCreateManagedWidget("printform", xmFormWidgetClass,
 						print_shell, NULL, 0);
 
-	XtAddCallback(print_form,
-			XmNhelpCallback, help_callback, (XtPointer) "print");
+	XtAddCallback(print_form, XmNhelpCallback, (XtCallbackProc)
+					help_callback, (XtPointer)"print");
 
 	mode_frame = XtVaCreateManagedWidget("mode",
 					xmFrameWidgetClass, print_form,
@@ -116,7 +121,7 @@ void create_print_popup()
 						mode_frame, NULL, 0);
 
 	/* Print Mode */
-	w = XtVaCreateManagedWidget("Print mode:",
+	w = XtVaCreateManagedWidget(_("Print mode:"),
 					xmLabelWidgetClass, mode_form,
 					XmNtopAttachment, XmATTACH_FORM,
 					XmNtopOffset, 8,
@@ -124,14 +129,15 @@ void create_print_popup()
 					XmNleftOffset, 8,
 					NULL);
 
-	s[0] = XmStringCreateSimple("Month");
-	s[1] = XmStringCreateSimple("Day");
-	s[2] = XmStringCreateSimple("Week (Landscape)");
-	s[3] = XmStringCreateSimple("Week (Portrait)");
-	s[4] = XmStringCreateSimple("Year");
-	s[5] = XmStringCreateSimple("Year Overview");
+	s[0] = XmStringCreateSimple(_("Month"));
+	s[1] = XmStringCreateSimple(_("Day"));
+	s[2] = XmStringCreateSimple(_("Week (Landscape)"));
+	s[3] = XmStringCreateSimple(_("Week (Portrait)"));
+	s[4] = XmStringCreateSimple(_("Year"));
+	s[5] = XmStringCreateSimple(_("Year Overview"));
 	mode_radio = XmVaCreateSimpleRadioBox(mode_form, "radio",
-					config.pr_mode, mode_callback,
+					config.pr_mode,
+					(XtCallbackProc)mode_callback,
 					XmNtopAttachment, XmATTACH_FORM,
 					XmNtopOffset, 8,
 					XmNleftAttachment, XmATTACH_WIDGET,
@@ -155,7 +161,7 @@ void create_print_popup()
 	}
 
 	/* omission flags */
-	w = XtVaCreateManagedWidget("Omit all appointments",
+	w = XtVaCreateManagedWidget(_("Omit all appointments"),
 					xmToggleButtonWidgetClass, mode_form,
 					XmNtopAttachment, XmATTACH_WIDGET,
 					XmNtopWidget, mode_radio,
@@ -167,9 +173,10 @@ void create_print_popup()
 					XmNset,	config.pr_omit_appts,
 					NULL);
 
-	XtAddCallback(w, XmNvalueChangedCallback, omit_appts_callback, 0);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+					omit_appts_callback, 0);
 
-	w = XtVaCreateManagedWidget("Omit private appointments",
+	w = XtVaCreateManagedWidget(_("Omit private appointments"),
 					xmToggleButtonWidgetClass, mode_form,
 					XmNtopAttachment, XmATTACH_WIDGET,
 					XmNtopWidget, w,
@@ -181,9 +188,25 @@ void create_print_popup()
 					XmNset,	config.pr_omit_priv,
 					NULL);
 
-	XtAddCallback(w, XmNvalueChangedCallback, omit_priv_callback, 0);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+					omit_priv_callback, 0);
 
-	w = XtVaCreateManagedWidget("Omit everyone else's appointments",
+	w = XtVaCreateManagedWidget(_("Omit everyone else's appointments"),
+					xmToggleButtonWidgetClass, mode_form,
+					XmNtopAttachment, XmATTACH_WIDGET,
+					XmNtopWidget, w,
+					XmNtopOffset, 4,
+					XmNleftAttachment, XmATTACH_FORM,
+					XmNleftOffset, 8,
+					XmNselectColor, color[COL_TOGGLE],
+					XmNhighlightThickness, 0,
+					XmNset, config.pr_omit_others,
+					NULL);
+
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+					omit_others_callback, 0);
+
+	w = XtVaCreateManagedWidget(_("Color printout"),
 					xmToggleButtonWidgetClass, mode_form,
 					XmNtopAttachment, XmATTACH_WIDGET,
 					XmNtopWidget, w,
@@ -194,10 +217,11 @@ void create_print_popup()
 					XmNleftOffset, 8,
 					XmNselectColor, color[COL_TOGGLE],
 					XmNhighlightThickness, 0,
-					XmNset, config.pr_omit_others,
+					XmNset, config.pr_color,
 					NULL);
 
-	XtAddCallback(w, XmNvalueChangedCallback, omit_others_callback, 0);
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+					color_callback, 0);
 
 	/* Spool String */
 	spool_frame = XtVaCreateManagedWidget("spool",
@@ -214,7 +238,7 @@ void create_print_popup()
 	spool_form = XtCreateManagedWidget("spool_form", xmFormWidgetClass,
 						spool_frame, NULL, 0);
 
-	w = XtVaCreateManagedWidget("Spooler string:",
+	w = XtVaCreateManagedWidget(_("Spooler string:"),
 					xmLabelWidgetClass, spool_form,
 					XmNtopAttachment, XmATTACH_FORM,
 					XmNtopOffset, 8,
@@ -259,7 +283,7 @@ void create_print_popup()
 					XmNrightOffset, 8,
 					NULL);
 
-	w = XtVaCreateManagedWidget("Print",
+	w = XtVaCreateManagedWidget(_("Print"),
 					xmPushButtonWidgetClass, action_area,
 					XmNtopAttachment, XmATTACH_FORM,
 					XmNbottomAttachment, XmATTACH_FORM,
@@ -267,11 +291,12 @@ void create_print_popup()
 					XmNwidth, 80,
 					NULL);
 
-	XtAddCallback(w, XmNactivateCallback, print_callback, (XtPointer) 0);
-	XtAddCallback(w, XmNhelpCallback, help_callback, (XtPointer)
-								"print_print");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+					print_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)help_callback,
+					(XtPointer) "print_print");
 
-	w = XtVaCreateManagedWidget("Cancel",
+	w = XtVaCreateManagedWidget(_("Cancel"),
 					xmPushButtonWidgetClass, action_area,
 					XmNtopAttachment, XmATTACH_FORM,
 					XmNbottomAttachment, XmATTACH_FORM,
@@ -281,11 +306,12 @@ void create_print_popup()
 					XmNwidth, 80,
 					NULL);
 
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer) 0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-			(XtPointer) "print_cancel");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)done_callback,
+					(XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)help_callback,
+					(XtPointer)"print_cancel");
 
-	w = XtVaCreateManagedWidget("Help",
+	w = XtVaCreateManagedWidget(_("Help"),
 					xmPushButtonWidgetClass, action_area,
 					XmNtopAttachment, XmATTACH_FORM,
 					XmNtopPosition, 0,
@@ -297,16 +323,16 @@ void create_print_popup()
 					XmNwidth, 80,
 					NULL);
 
-	XtAddCallback(w, XmNactivateCallback, help_callback, (XtPointer)
-								"print");
-	XtAddCallback(w, XmNhelpCallback, help_callback, (XtPointer)"print");
-
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)help_callback,
+					(XtPointer) "print");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)help_callback,
+					(XtPointer)"print");
 	XtPopup(print_shell, XtGrabNone);
 
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
 
-	XmAddWMProtocolCallback(print_shell, closewindow, done_callback,
-				(XtPointer) print_shell);
+	XmAddWMProtocolCallback(print_shell, closewindow, (XtCallbackProc)
+					done_callback, (XtPointer)print_shell);
 
 	popup_created = TRUE;
 }
@@ -316,18 +342,20 @@ void create_print_popup()
  * Waste popup if it's been created
  */
 
-void destroy_print_popup()
+void destroy_print_popup(void)
 {
 	if (popup_created)
 		XtPopdown(print_shell);
+	if (mainlist->modified)
+		write_mainlist();
 }
 
 
 /*ARGSUSED*/
-static void mode_callback(widget, item, data)
-	Widget	widget;
-	int	item;
-	XmToggleButtonCallbackStruct *data;
+static void mode_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (data->set) {
 		config.pr_mode     = item;
@@ -337,63 +365,82 @@ static void mode_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void omit_appts_callback(widget, item, data)
-	Widget	widget;
-	int	item;
-	XmToggleButtonCallbackStruct *data;
+static void omit_appts_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
-	config.pr_omit_appts ^= TRUE;
-	mainlist->modified    = TRUE;
+	if (data->set) {
+		config.pr_omit_appts ^= TRUE;
+		mainlist->modified    = TRUE;
+	}
 }
 
 
 /*ARGSUSED*/
-static void omit_priv_callback(widget, item, data)
-	Widget	widget;
-	int	item;
-	XmToggleButtonCallbackStruct *data;
+static void omit_priv_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
-	config.pr_omit_priv ^= TRUE;
-	mainlist->modified   = TRUE;
+	if (data->set) {
+		config.pr_omit_priv ^= TRUE;
+		mainlist->modified   = TRUE;
+	}
 }
 
 
 /*ARGSUSED*/
-static void omit_others_callback(widget, item, data)
-	Widget  widget;
-	int     item;
-	XmToggleButtonCallbackStruct *data;
+static void omit_others_callback(
+	Widget 				 widget,
+	int    				 item,
+	XmToggleButtonCallbackStruct	*data)
 {
-	config.pr_omit_others ^= TRUE;
-	mainlist->modified     = TRUE;
+	if (data->set) {
+		config.pr_omit_others ^= TRUE;
+		mainlist->modified     = TRUE;
+	}
 }
 
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget	widget;
-	int	item;
-	XmToggleButtonCallbackStruct *data;
+static void color_callback(
+	Widget 				 widget,
+	int    				 item,
+	XmToggleButtonCallbackStruct	*data)
+{
+	if (data->set) {
+		config.pr_color   ^= TRUE;
+		mainlist->modified = TRUE;
+	}
+}
+
+
+/*ARGSUSED*/
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_print_popup();
 }
 
 
-static void broken_pipe_handler(sig)
-	int sig;
+static void broken_pipe_handler(
+	int				sig)
 {
 	create_error_popup(0, 0,
-	     "Print failed, aborted with signal %d\nCheck your spooler string.",
+	 _("Print failed, aborted with signal %d\nCheck your spooler string."),
 				sig);
 	signal(SIGPIPE, SIG_IGN);
 }
 
 
 /*ARGSUSED*/
-static void print_callback(widget, item, data)
-	Widget	widget;
-	int	item;
-	XmToggleButtonCallbackStruct *data;
+static void print_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	FILE	*pp;
 	char	*Spooler = XmTextFieldGetString(spool_text);
@@ -410,7 +457,7 @@ static void print_callback(widget, item, data)
 	}
 	if ((pp = popen(tmp, "w")) == NULL)
 		create_error_popup(print_shell, errno,
-					"Cannot open pipe to \"%s\"", tmp);
+					_("Cannot open pipe to \")%s\""), tmp);
 	else
 		Print_Calendar(pp, config.pr_mode, curr_month, 1, curr_year);
 
@@ -419,10 +466,12 @@ static void print_callback(widget, item, data)
 }
 
 
-int Print_Calendar(Fp, Mode, Month, Day, Year)
-	FILE	*Fp;
-	int	Mode;
-	int	Month, Day, Year;
+static int Print_Calendar(
+	FILE	*fp,
+	int	Mode,
+	int	Month,
+	int	Day,
+	int	Year)
 {
 	int	Pslib_Fd;
 	char	*cp;
@@ -446,18 +495,18 @@ int Print_Calendar(Fp, Mode, Month, Day, Year)
 		break;
 
 	  case PR_DAY:
-		print_day_calendar(Fp);
-		pclose(Fp);
+		print_day_calendar(fp, FALSE);
+		pclose(fp);
 		return(0);
 
 	  case PR_WEEK_L:
-		print_week_calendar(Fp, TRUE);
-		pclose(Fp);
+		print_week_calendar(fp, TRUE);
+		pclose(fp);
 		return(0);
 
 	  case PR_WEEK_P:
-		print_week_calendar(Fp, FALSE);
-		pclose(Fp);
+		print_week_calendar(fp, FALSE);
+		pclose(fp);
 		return(0);
 
 	  case PR_YEAR:
@@ -468,8 +517,8 @@ int Print_Calendar(Fp, Mode, Month, Day, Year)
 		break;
 
 	  case PR_YOV:
-		print_yov_calendar(Fp);
-		pclose(Fp);
+		print_yov_calendar(fp);
+		pclose(fp);
 		return(0);
 
 	  default:
@@ -486,33 +535,33 @@ int Print_Calendar(Fp, Mode, Month, Day, Year)
 	find_file(PsLib, PS_LIB, FALSE);
 	if ((Pslib_Fd = open(PsLib, O_RDONLY)) == -1) {
 		create_error_popup(print_shell, errno,
-			"Can't find PostScript skeleton\nfile \"%s\"", PS_LIB);
-		pclose(Fp);
+		     _("Can't find PostScript skeleton\nfile \"%s\""), PS_LIB);
+		pclose(fp);
 		return (-1);
 	}
 	date_to_time(1, Month, Year, &WeekDay, &JulDay, &WeekNum);
 
-	fprintf(Fp, "%%!PS-Adobe\n");
-	fprintf(Fp, "%%\n");
-	fprintf(Fp, "%%%%Creator: plan\n");
-	fprintf(Fp, "%%%%Title: %s Calendar\n", Mode_Str);
-	fprintf(Fp, "%%%%EndComments\n");
-	fprintf(Fp, "%%\n");
+	fprintf(fp, "%%!PS-Adobe\n");
+	fprintf(fp, "%%\n");
+	fprintf(fp, "%%%%Creator: plan\n");
+	fprintf(fp, "%%%%Title: %s Calendar\n", Mode_Str);
+	fprintf(fp, "%%%%EndComments\n");
+	fprintf(fp, "%%\n");
 
-	fprintf(Fp, "%% Begin of PS_LIB (%s)\n", PsLib);
+	fprintf(fp, "%% Begin of PS_LIB (%s)\n", PsLib);
 
 	while ((nb = read(Pslib_Fd, tmp, sizeof(tmp))) > 0)
-		fwrite(tmp, sizeof(char), nb, Fp);
+		fwrite(tmp, sizeof(char), nb, fp);
 	close(Pslib_Fd);
 
-	fprintf(Fp, "%% End of PS_LIB (%s)\n", PsLib);
+	fprintf(fp, "%% End of PS_LIB (%s)\n", PsLib);
 
-	fflush(Fp);
+	fflush(fp);
 
-	fprintf(Fp, "\n%% Plan Configuration values...\n");
+	fprintf(fp, "\n%% Plan Configuration values...\n");
 
 #define BOOL_TO_PS(a,b) \
-	fprintf(Fp, "%s %s def\n", a, (b ? "true" : "false"))
+	fprintf(fp, "%s %s def\n", a, (b ? "true" : "false"))
 
 	BOOL_TO_PS("/SundayFirst", config.sunday_first);
 	BOOL_TO_PS("/MMDDYY", config.mmddyy);
@@ -522,43 +571,43 @@ int Print_Calendar(Fp, Mode, Month, Day, Year)
 
 #undef BOOL_TO_PS
 
-	fprintf(Fp, "\n%% Print Information\n");
+	fprintf(fp, "\n%% Print Information\n");
 
-	fprintf(Fp, "/Print_Mode (%s) def\n", Mode_Str);
-	fprintf(Fp, "/Month	%d def\n", Month+1);
-	fprintf(Fp, "/Day	%d def\n", Day);
-	fprintf(Fp, "/Year	%d def\n", Year+1900);
-	fprintf(Fp, "/WeekDay %d def\n", WeekDay);
-	fprintf(Fp, "/WeekNum %d def\n", WeekNum);
-	fprintf(Fp, "/JulDay	%d def\n", JulDay);
+	fprintf(fp, "/Print_Mode (%s) def\n", Mode_Str);
+	fprintf(fp, "/Month	%d def\n", Month+1);
+	fprintf(fp, "/Day	%d def\n", Day);
+	fprintf(fp, "/Year	%d def\n", Year+1900);
+	fprintf(fp, "/WeekDay %d def\n", WeekDay);
+	fprintf(fp, "/WeekNum %d def\n", WeekNum);
+	fprintf(fp, "/JulDay	%d def\n", JulDay);
 
-	fprintf(Fp, "\n");
+	fprintf(fp, "\n");
 
-	fprintf(Fp, "%% Month Range: %2d thru %2d\n",
+	fprintf(fp, "%% Month Range: %2d thru %2d\n",
 						StartMonth+1, EndMonth+1);
-	fprintf(Fp, "%% Day Range	: %2d thru %2d\n", StartDay, EndDay);
-	fprintf(Fp, "%% Year Range : %2d thru %2d\n", StartYear, EndYear);
+	fprintf(fp, "%% Day Range	: %2d thru %2d\n", StartDay, EndDay);
+	fprintf(fp, "%% Year Range : %2d thru %2d\n", StartYear, EndYear);
 
-	fprintf(Fp, "\nInitCal\n\n");
-	fprintf(Fp, "%% Data...\n\n");
+	fprintf(fp, "\nInitCal\n\n");
+	fprintf(fp, "%% Data...\n\n");
 
 	for (CYear = StartYear; CYear <= EndYear; CYear++) {
 		if ((cp = parse_holidays(CYear, FALSE)) != NULL) {
 			create_error_popup(print_shell, 0, cp);
-			pclose(Fp);
+			pclose(fp);
 			return (-3);
 		}
 		for (CMonth = StartMonth; CMonth <= EndMonth; CMonth++)
 			for (CDay = StartDay; CDay <= EndDay; CDay++)
-				Print_Day(Fp, CDay, CMonth, CYear, Mode);
+				Print_Day(fp, CDay, CMonth, CYear, Mode);
 
 		StartMonth = 1;
 		EndMonth = 12;
 	}
-	fprintf(Fp, "\n");
-	fprintf(Fp, "FinishCal\n");
-	fflush(Fp);
-	pclose(Fp);
+	fprintf(fp, "\n");
+	fprintf(fp, "FinishCal\n");
+	fflush(fp);
+	pclose(fp);
 	return (0);
 }
 
@@ -567,49 +616,59 @@ int Print_Calendar(Fp, Mode, Month, Day, Year)
  * called for each day of month and year views. Prints data into plan_cal.ps.
  */
 
-static int Print_Day(Fp, Day, Month, Year, Mode)
-	FILE		*Fp;
-	int		Day, Month, Year;
-	int		Mode;
+static int Print_Day(
+	FILE		*fp,
+	int		Day,
+	int		Month,
+	int		Year,
+	int		Mode)
 {
-	int		DayStart, DayEnd, WeekNum, JulDay, found;
+	int		DayStart, DayEnd, WeekDay, WeekNum, JulDay, found;
 	time_t		trigger;
 	struct entry	*entry;
-	struct holiday	*Hp;
+	struct holiday	*hp, *hp2;
 	struct lookup	lookup;
 	struct tm	*tm;
-	char		*Holidays[3];
-	int		NumHolidays;
-	int		i, u;
+	int		i, j, u, daycolor;
 
-	if (!(DayStart = date_to_time(Day,Month,Year,NULL,&JulDay,&WeekNum)))
+	if (!(DayStart = date_to_time(Day, Month, Year,
+					&WeekDay, &JulDay, &WeekNum)))
 		return (-1);
 
+	daycolor = WeekDay == 6 || WeekDay == 0 ? COL_WEEKEND : COL_WEEKDAY;
+	for (j=0; j < 2; j++)
+		if (!daycolor && hp->daycolor)
+			daycolor = (i ? holiday : sm_holiday)[JulDay].daycolor;
 	DayEnd = DayStart + 86399;
-	NumHolidays = 0;
-
-	/* Check Holidays */
-	if ((Hp = &sm_holiday[JulDay])->string != NULL && *Hp->string)
-		Holidays[NumHolidays++] = Hp->string;
-
-	if ((Hp = &holiday[JulDay])->string != NULL && *Hp->string)
-		Holidays[NumHolidays++] = Hp->string;
-
-	fprintf(Fp, "%d %d %d %d %d NewDay\n",
+#if 0
+	if (config.pr_color && daycolor)
+		fprintf(fp, "%g %g %g setrgbcolor ",
+				xcolor[daycolor].red   / 65536.,
+				xcolor[daycolor].green / 65536.,
+				xcolor[daycolor].blue  / 65536.);
+#endif
+	fprintf(fp, "%d %d %d %d %d NewDay\n",
 				Month+1, Day, Year, WeekNum+1, JulDay+1);
 
-	if (NumHolidays > 0) {
-		int	i;
-		fprintf(Fp, "[ ");
-		for (i = 0; i < NumHolidays;) {
-			OutStr(Fp, Holidays[i]);
-			if (++i < NumHolidays)
-				fprintf(Fp, "\n	");
+	hp  = &sm_holiday[JulDay];
+	hp2 =    &holiday[JulDay];
+	if (hp->string && *hp->string || hp2->string && *hp2->string) {
+		fprintf(fp, "[ ");
+		for (j=0; j < 2; j++, hp=hp2) {
+			if (!hp->string || !*hp->string)
+				continue;
+			i = hp->stringcolor ? hp->stringcolor : daycolor;
+			if (config.pr_color && i)
+				fprintf(fp, "%g %g %g setrgbcolor ",
+					xcolor[i].red   / 65536.,
+					xcolor[i].green / 65536.,
+					xcolor[i].blue  / 65536.);
+			OutStr(fp, hp->string);
 		}
-		fprintf(Fp, " ] PaintHolidays\n");
+		fprintf(fp, " ] PaintHolidays\n");
 	}
 	if (config.pr_omit_appts) {
-		fflush(Fp);
+		fflush(fp);
 		return (0);
 	}
 
@@ -648,38 +707,46 @@ static int Print_Day(Fp, Day, Month, Year, Mode)
 
 		tm = time_to_tm(entry->time);
 
-		fprintf(Fp, "	");
+		fprintf(fp, "	");
 
+		if (config.pr_color) {
+			int color = entry->acolor ? COL_HBLACK+entry->acolor-1
+						  : COL_WNOTE;
+			fprintf(fp, "%g %g %g setrgbcolor ",
+				xcolor[color].red   / 65536.,
+				xcolor[color].green / 65536.,
+				xcolor[color].blue  / 65536.);
+		}
 		if (config.mmddyy)
-			fprintf(Fp, " (%02d/%02d/%02d)\t",
-				tm->tm_mon+1, tm->tm_mday, tm->tm_year % 100);
+			fprintf(fp, " (%02d/%02d/%02d)\t",
+				tm->tm_mon+1, tm->tm_mday, tm->tm_year);
 		else
-			fprintf(Fp, " (%d.%d.%02d)\t",
-				tm->tm_mday, tm->tm_mon+1, tm->tm_year % 100);
+			fprintf(fp, " (%d.%d.%02d)\t",
+				tm->tm_mday, tm->tm_mon+1, tm->tm_year);
 
 		if (entry->notime)
-			fprintf(Fp, "()");
+			fprintf(fp, "()");
 		else {
 			if (config.ampm)
-				fprintf(Fp, "(%2d:%02d%c)\t",
+				fprintf(fp, "(%2d:%02d%c)\t",
 					tm->tm_hour % 12 ? tm->tm_hour%12 : 12,
 					tm->tm_min,
 					tm->tm_hour < 12 ? 'a' : 'p');
 			else
-				fprintf(Fp, "(%02d:%02d)\t", tm->tm_hour,
+				fprintf(fp, "(%02d:%02d)\t", tm->tm_hour,
 								tm->tm_min);
 		}
-		OutStr(Fp, mknotestring(entry));
+		OutStr(fp, mknotestring(entry));
 		if (entry->message && *entry->message) {
-			fprintf(Fp, "\n	");
-			OutStr(Fp, entry->message);
-			fprintf(Fp, "\n PaintEntry\n");
+			fprintf(fp, "\n	");
+			OutStr(fp, entry->message);
+			fprintf(fp, "\n PaintEntry\n");
 		} else
-			fprintf(Fp, "\t() PaintEntry\n");
+			fprintf(fp, "\t() PaintEntry\n");
 
-		fflush(Fp);
+		fflush(fp);
 	}
-	fflush(Fp);
+	fflush(fp);
 	return (0);
 }
 
@@ -688,13 +755,11 @@ static int Print_Day(Fp, Day, Month, Year, Mode)
  * Output a string in a manner compatible with PostScript..
  */
 
-static void OutStr(Fp, Str)
-	FILE	*Fp;
-	char	*Str;
+static void OutStr(
+	FILE		*fp,
+	char		*Str)
 {
-	char	buf[10];
-
-	putc('(', Fp);
+	putc('(', fp);
 	for (; Str && *Str; Str++)
 		switch (*Str) {
 		  case '\n':
@@ -705,28 +770,28 @@ static void OutStr(Fp, Str)
 			/* Replace Newlines we spaces... */
 			/* In the "PostScript" we output an escaped newline */
 			/* to improve readability */
-			putc(' ', Fp);
+			putc(' ', fp);
 
 		  case '\\':
 		  case '(':
 		  case ')':
-			fprintf(Fp, "\\%c", *Str);
+			fprintf(fp, "\\%c", *Str);
 			break;
 
 		  case '\f':
-			fprintf(Fp, "\\f");
+			fprintf(fp, "\\f");
 			break;
 
 		  case '\r':
-			fprintf(Fp, "\\r");
+			fprintf(fp, "\\r");
 			break;
 
 		default:
 			if (*(unsigned char *)Str >= 160)
-				fprintf(Fp, "\\%o", (unsigned int)*Str & 255);
+				fprintf(fp, "\\%o", (unsigned int)*Str & 255);
 			else
-				putc(*Str, Fp);
+				putc(*Str, fp);
 			break;
 		}
-	putc(')', Fp);
+	putc(')', fp);
 }
