@@ -17,17 +17,17 @@
 #include <sys/types.h>
 #endif
 #include <time.h>
+#include <sys/time.h>
 #include <string.h>
 #include <Xm/Xm.h>
 #include <X11/StringDefs.h>
-#include "config.h"
-#include "proto.h"
+#include "cal.h"
 
 #undef DEBUG			/* define this to debug timezone calc */
 
 extern struct config	config;		/* global configuration data */
 
-short monthlen[12] = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
+short monthlen[12]   = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
 short monthbegin[12] = {0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334};
 
 
@@ -39,10 +39,10 @@ short monthbegin[12] = {0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334};
  * This routine only works correctly for the range 1970..2069.
  */
 
-time_t tm_to_time(tm)
-	struct tm		*tm;		/* time/date to convert */
+time_t tm_to_time(
+	struct tm	*tm)		/* time/date to convert */
 {
-	time_t			t;		/* return value */
+	time_t		t;		/* return value */
 
 	t  = monthbegin[tm->tm_mon]			/* full months */
 	   + tm->tm_mday-1				/* full days */
@@ -67,8 +67,8 @@ time_t tm_to_time(tm)
  * This routine only works correctly for the range 1970..2069.
  */
 
-struct tm *time_to_tm(t)
-	time_t			t;		/* time to convert */
+struct tm *time_to_tm(
+	time_t		t)		/* time to convert */
 {
 	int			n, l;		/* temp */
 	static struct tm	tm;		/* returned tm */
@@ -100,10 +100,10 @@ struct tm *time_to_tm(t)
 /*
  * return current time in seconds since 1/1/70. The timezone is applied
  * such that the return value modulo 86400 is the number of seconds since
- * midnight.
+ * midnight. Do not use localtime etc here!
  */
 
-time_t get_time()
+time_t get_time(void)
 {
 	return(time(0) - config.tzone + config.adjust_time);
 }
@@ -117,7 +117,7 @@ time_t get_time()
  * libraries when it comes to time calculation!
  */
 
-void set_tzone()
+void set_tzone(void)
 {
 	register struct config *c = &config;
 	time_t		now;			/* current local time */
@@ -144,6 +144,11 @@ void set_tzone()
 			c->tzone = c->raw_tzone - 3600;
 		else
 			c->tzone = c->raw_tzone;
+	  	break;
+	  case 3:
+		guess_tzone();
+		c->tzone = c->raw_tzone;
+		c->dst_flag = 3;
 	}
 }
 
@@ -170,15 +175,16 @@ static char *zone_time_string();
 static get_zone_time();
 static int julian_year_date();
 
-void guess_tzone()
+void guess_tzone(void)
 {
 	char		*tz=0;			/* timezone string (TZ) */
 	int		zone=0, dst= -3600;	/* difference from GMT */
 	int		begin=0, begintime=0;	/* dst begin: julian day/time*/
 	int		end=0,   endtime=0;	/* dst end: julian day/time */
 
-	if (((tz = getenv("PLAN_TZ")) && *tz ||
-	     (tz = getenv("TZ"))      && *tz) && strrchr("0123456789-",tz[3])){
+	if (config.dst_flag != 3 && (
+	    (tz = getenv("PLAN_TZ")) && *tz ||
+	    (tz = getenv("TZ"))      && *tz) && strrchr("0123456789-",tz[3])) {
 		do {
 			if (!*tz++ || !*tz++ || !*tz++)		/* MET */
 				break;
@@ -223,14 +229,17 @@ void guess_tzone()
 			} else break;
 		} while (0);
 	} else {
-#if defined(SVR4) || defined(SOLARIS2) || defined(linux)
-		time_t now = get_time();
+		/*------------------------------------------------------------
+		 * this code is largely untested and available only for a few
+		 * platforms. If you have corrections or extensions for other
+		 * platforms, implement it here and tell me (thomas@bitrot.de).
+		 */
+#if defined(SVR4) || defined(SOLARIS2) || defined(linux) || defined(sgi)
+		time_t now = time(0);
 		struct tm *tm = localtime(&now);
 		time_t h = tm->tm_hour;
 		struct tm *gmt = gmtime(&now);
 		zone = (gmt->tm_hour - h) * 3600;
-		dst  = zone - 3600;
-		dst  = 0;	/* jmorriso@bogomips.ee.ubc.ca 28.8.94 */
 #else
 #if defined(bsdi) || defined(SUN) || defined(SVR4) || defined(convex)
 		time_t now;
@@ -239,9 +248,26 @@ void guess_tzone()
 		now = time(0);
 		tm = localtime(&now);
 		zone = -tm->tm_gmtoff;
+#else
+#if defined(__FreeBSD__) /* by Stefan `Sec` Zehl <sec@42.org> */
+		time_t now = time(0);
+		struct tm *tm = localtime(&now);
+		config.tzone = tm->tm_gmtoff;
+		zone = - tm->tm_gmtoff + tm->tm_isdst * 3600;
+#else
+		static int once;
+		if (config.dst_flag != 3 && !once++)
+			create_error_popup(0, 0, "automatic timezone not suppo"
+					"rted for this machine, choose Adjust "
+					"Time from the Config pulldown\n");
+		zone = 0;
 #endif
 #endif
+#endif
+		/*-----------------------------------------------------------*/
 	}
+
+
 #ifdef DEBUG
 	if (tz = getenv("PLAN_TZ"))
 		printf("PLAN_TZ env variable: %s\n", tz);
@@ -278,9 +304,9 @@ void guess_tzone()
  * parse a time string of the form [hours[:minutes[:seconds]]], return seconds
  */
 
-static int get_zone_time(tzp, zdefault)
-	char		**tzp;
-	int		zdefault;
+static int get_zone_time(
+	char		**tzp,
+	int		zdefault)
 {
 	char		*tz = *tzp;
 	int		i, num, zone = 0;
@@ -321,12 +347,12 @@ static int get_zone_time(tzp, zdefault)
 extern int	curr_year;		/* year being displayed, since 1900 */
 time_t		date_to_time();
 
-static int julian_year_date(tzp)
-	char	**tzp;
+static int julian_year_date(
+	char		**tzp)
 {
-	char	*tz = *tzp;
-	int	day, month, week;
-	int	wkday, julian;
+	char		*tz = *tzp;
+	int		day, month, week;
+	int		wkday, julian;
 
 	if (*tz == 'M') {	/* scan the format */
 		tz++;
@@ -377,8 +403,8 @@ static int julian_year_date(tzp)
  */
 
 #ifdef DEBUG
-static char *zone_time_string(t)
-	int		t;
+static char *zone_time_string(
+	int		t)
 {
 	static char buf[12];
 
@@ -398,11 +424,16 @@ static char *zone_time_string(t)
  * Note that *wkday counts from 0=sunday to 6=saturday.
  */
 
-time_t date_to_time(day, month, year, wkday, julian, weeknum)
-	int day, month, year, *wkday, *julian, *weeknum;
+time_t date_to_time(
+	int		day,
+	int		month,
+	int		year,
+	int		*wkday,
+	int		*julian,
+	int		*weeknum)
 {
-	struct tm		tm;
-	time_t			time;
+	struct tm	tm;
+	time_t		time;
 
 	tm.tm_sec   = 0;
 	tm.tm_min   = 0;
@@ -415,9 +446,13 @@ time_t date_to_time(day, month, year, wkday, julian, weeknum)
 		*wkday   = tm.tm_wday;
 	if (julian)
 		*julian  = tm.tm_yday;
-	if (weeknum)
-		*weeknum = config.fullweek
+	if (weeknum) {
+		int x = (tm.tm_wday + 7 - tm.tm_yday) % 7;
+		*weeknum = config.thu_week
+			 ? (tm.tm_yday + x - (x<5 ? 1 : 8)) / 7
+			 : config.fullweek
 				? tm.tm_yday / 7
-				: tm.tm_yday ? ((tm.tm_yday - 1) /7) + 1 : 0;
+				: tm.tm_yday > 0 ? (tm.tm_yday-1) / 7 + 1 : 0;
+	}
 	return(time == -1 || day != tm.tm_mday ? 0 : time);
 }
