@@ -38,13 +38,14 @@
 #include "bm_script.h"
 #include "bm_except.h"
 #include "bm_private.h"
+#include "bm_todo.h"
 #include "bm_icon.h"
 #include "bm_iconsub.h"
 #include "bm_circle.h"
 #include "bm_chkcircle.h"
 #include "bm_checker.h"
 
-static void canvas_callback();
+static void canvas_callback(Widget, XButtonEvent *, String *, int);
 
 extern struct config	config;		/* global configuration data */
 extern Display		*display;	/* everybody uses the same server */
@@ -69,14 +70,14 @@ static char blank_bits[] =
 	{ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 };
 
 static char *pics[NPICS]     = {recycle_bits, message_bits, script_bits,
-				except_bits, private_bits, blank_bits,
-				checker_bits};
+				except_bits, private_bits, todo_bits,
+				blank_bits, checker_bits};
 static int pix_width[NPICS]  = {recycle_width, message_width, script_width,
-				except_width, private_width, recycle_width,
-				checker_width};
+				except_width, private_width, todo_width,
+				recycle_width, checker_width};
 static int pix_height[NPICS] = {recycle_height, message_height, script_height,
-				except_height, private_height, recycle_height,
-				checker_height};
+				except_height, private_height, todo_height,
+				recycle_height, checker_height};
 
 
 /*
@@ -87,7 +88,7 @@ static int pix_height[NPICS] = {recycle_height, message_height, script_height,
  * buttons in the file list; create each with all eight colors.
  */
 
-void init_pixmaps()
+void init_pixmaps(void)
 {
 	int			p;
 	Colormap		cmap;
@@ -113,7 +114,7 @@ void init_pixmaps()
 				color[COL_GRAYICON],
 				failed ? color[COL_BACK] : rgb.pixel,
 				DefaultDepth(display,DefaultScreen(display)))))
-			fatal("no memory for pixmaps");
+			fatal(_("no memory for pixmaps"));
 
 	for (p=0; p < 8; p++)
 		if (!(col_pixmap[p] = XCreatePixmapFromBitmapData(display,
@@ -126,13 +127,13 @@ void init_pixmaps()
 				chkcircle_width, chkcircle_height,
 				color[COL_WUSER_0 + p], color[COL_CALBACK],
 				DefaultDepth(display,DefaultScreen(display)))))
-			fatal("no memory for pixmaps");
+			fatal(_("no memory for pixmaps"));
 
 	if (!(pixmap[PIC_CHECKER] = XCreatePixmapFromBitmapData(display,
 				DefaultRootWindow(display),
 				checker_bits, checker_width, checker_height,
 				~0, 0, 1)))
-			fatal("no memory for pixmaps");
+			fatal(_("no memory for pixmaps"));
 
 	XSetForeground(display, chk_gc, color[COL_CALBACK]);
 	XSetStipple   (display, chk_gc, pixmap[PIC_CHECKER]);
@@ -145,9 +146,9 @@ void init_pixmaps()
  * set icon for the application or a shell.
  */
 
-void set_icon(shell, sub)
-	Widget			shell;
-	int			sub;		/* 0=main, 1=submenu */
+void set_icon(
+	Widget			shell,
+	int			sub)		/* 0=main, 1=submenu */
 {
 	Pixmap			icon;
 
@@ -171,7 +172,7 @@ void set_icon(shell, sub)
  * the screen saver from kicking in.
  */
 
-void print_icon_name()
+void print_icon_name(void)
 {
 	time_t			tod;		/* current time-of-day */
 	char			buf[64];	/* icon label string */
@@ -184,7 +185,7 @@ void print_icon_name()
 			sprintf(buf, "%d/%d", tm->tm_mon+1, tm->tm_mday);
 		else
 			sprintf(buf, "%d.%d.", tm->tm_mday, tm->tm_mon+1);
-		sprintf(buf+strlen(buf), " %s", mktimestring(tod,FALSE), NULL);
+		sprintf(buf+strlen(buf), " %s", mktimestring(tod, FALSE));
 		XtVaSetValues(toplevel, XmNiconName, buf, NULL);
 
 	} else if (config.showicontime) {
@@ -199,11 +200,11 @@ void print_icon_name()
  * return the length of <string> in pixels.
  */
 
-int strlen_in_pixels(string, sfont)
-	register unsigned char *string;	/* string to truncate */
-	int		sfont;		/* FONT_* */
+int strlen_in_pixels(
+	register unsigned char	*string,	/* string to truncate */
+	int			sfont)		/* FONT_* */
 {
-	register int	len;		/* length in pixels */
+	register int		len;		/* length in pixels */
 
 	for (len=0; *string; string++)
 		len += CHARWIDTH(sfont, *string);
@@ -216,10 +217,10 @@ int strlen_in_pixels(string, sfont)
  * drawn with font <sfont>, by storing \0 somewhere in the string.
  */
 
-void truncate_string(string, len, sfont)
-	register unsigned char *string;	/* string to truncate */
-	register int	len;		/* max len in pixels */
-	int		sfont;		/* font of string */
+void truncate_string(
+	register unsigned char	*string,	/* string to truncate */
+	register int		len,		/* max len in pixels */
+	int			sfont)		/* font of string */
 {
 	while (*string) {
 		len -= font[sfont]->per_char
@@ -239,7 +240,9 @@ void truncate_string(string, len, sfont)
  */
 
 #ifndef VARARGS
-void print_button(Widget w, char *fmt, ...)
+void print_button(
+	Widget		w,
+	char		*fmt, ...)
 {
 	va_list		parm;
 	Arg		args;
@@ -257,7 +260,9 @@ void print_button(Widget w, char *fmt, ...)
 	}
 }
 
-void print_text_button(Widget w, char *fmt, ...)
+void print_text_button(
+	Widget		w,
+	char		*fmt, ...)
 {
 	va_list		parm;
 	char		buf[1024];
@@ -273,10 +278,13 @@ void print_text_button(Widget w, char *fmt, ...)
 
 #else /* VARARGS */
 
-void print_button(w, fmt, a, b, c, d)
-	Widget		w;
-	char		*fmt;
-	int		a, b, c, d;
+void print_button(
+	Widget		w,
+	char		*fmt,
+	int		a,
+	int		b,
+	int		c,
+	int		d)
 {
 	Arg		args;
 	XmString	string;
@@ -291,10 +299,13 @@ void print_button(w, fmt, a, b, c, d)
 	}
 }
 
-void print_text_button(w, fmt, a, b, c, d)
-	Widget		w;
-	char		*fmt;
-	int		a, b, c, d;
+void print_text_button(
+	Widget		w,
+	char		*fmt,
+	int		a,
+	int		b,
+	int		c,
+	int		d)
 {
 	XmString	string;
 	char		buf[1024];
@@ -317,10 +328,10 @@ void print_text_button(w, fmt, a, b, c, d)
  * If <n> is -1, draw a blank pixmap.
  */
 
-void print_pixmap(w, n, b)
-	Widget		w;		/* button to draw into */
-	int		n;		/* pixmap #, one of PIC_* */
-	BOOL		b;		/* true: black, false: grayed*/
+void print_pixmap(
+	Widget		w,		/* button to draw into */
+	int		n,		/* pixmap #, one of PIC_* */
+	BOOL		b)		/* true: black, false: grayed*/
 {
 	Arg		arg;
 
@@ -335,8 +346,8 @@ void print_pixmap(w, n, b)
  * set a color into the regular (non-xor) graphical context (GC) for drawing.
  */
 
-void set_color(col)
-	int		col;
+void set_color(
+	int		col)
 {
 	XSetForeground(display, jgc, color[col]);
 	XSetForeground(display, gc,  color[col]);
@@ -361,9 +372,9 @@ static int cursorglyph[] = {
 	XC_hand2		/* M_MONTH_CAL */
 };
 
-void set_cursor(w, n)
-	Widget		w;		/* in which widget */
-	int		n;		/* which cursor, one of M_* */
+void set_cursor(
+	Widget		w,		/* in which widget */
+	int		n)		/* which cursor, one of M_* */
 {
 	static Cursor	cursor[M_NCURSORS];
 	Window		win = XtWindow(w);
@@ -402,12 +413,12 @@ static String translations =
 		 <Motion>:	canvas(motion)	ManagerGadgetButtonMotion()\n\
 		 <Btn1Motion>:	canvas(motion)	ManagerGadgetButtonMotion()";
 
-void drag_init(view, canvas, info, rcb, lcb)
-	int		view;		/* 'm', 'd', 'w', or 'o' */
-	Widget		canvas;		/* drawing area to initialize */
-	Widget		info;		/* label widget for info messages */
-	void		(*rcb)();	/* redraw callback */
-	MOUSE		(*lcb)();	/* locate position in canvas */
+void drag_init(
+	int		view,		/* 'm', 'd', 'w', or 'o' */
+	Widget		canvas,		/* drawing area to initialize */
+	Widget		info,		/* label widget for info messages */
+	void		(*rcb)(),	/* redraw callback */
+	MOUSE		(*lcb)())	/* locate position in canvas */
 {
 	static BOOL	did_init = FALSE;
 	XtActionsRec	action;
@@ -430,15 +441,15 @@ void drag_init(view, canvas, info, rcb, lcb)
 	dc->expose_cb = rcb;
 	dc->locate_cb = lcb;
 
-	XtAddCallback(canvas, XmNexposeCallback, expose_callback,
-						(XtPointer)(p - drag_views));
+	XtAddCallback(canvas, XmNexposeCallback, (XtCallbackProc)
+			expose_callback, (XtPointer)(p - drag_views));
 	XtSetArg(arg, XmNtranslations, XtParseTranslationTable(translations));
 	XtSetValues(canvas, &arg, 1);
 	set_cursor(canvas, M_OUTSIDE);
 }
 
-void drag_destroy(view)
-	int		view;		/* 'm', 'd', 'w', or 'o' */
+void drag_destroy(
+	int		view)		/* 'm', 'd', 'w', or 'o' */
 {
 	char		*p;
 	struct dragc_s	*dc;
@@ -446,15 +457,15 @@ void drag_destroy(view)
 	p = strchr(drag_views, view);
 	assert(p);
 	dc = &drag_context[p - drag_views];
-	bzero(dc, sizeof(struct dragc_s));
+	mybzero(dc, sizeof(struct dragc_s));
 }
 
 
 /*ARGSUSED*/
-static void expose_callback(canvas, data, info)
-	Widget				canvas;		/* drawing area */
-	XtPointer			data;		/* view: 0..NVIEWS-1 */
-	XmDrawingAreaCallbackStruct	*info;		/* what & where */
+static void expose_callback(
+	Widget				canvas,		/* drawing area */
+	XtPointer			data,		/* view: 0..NVIEWS-1 */
+	XmDrawingAreaCallbackStruct	*info)		/* what & where */
 {
 	XEvent dummy;
 	Region region = XCreateRegion();
@@ -472,15 +483,15 @@ static void expose_callback(canvas, data, info)
  * (drag_init). It handles all calendar views.
  */
 
-static void drag_entry();
-static void draw_rubberband();
+static void drag_entry		(int, MOUSE, time_t, time_t);
+static void draw_rubberband	(Widget, BOOL, int, int, int, int);
 
 /*ARGSUSED*/
-static void canvas_callback(canvas, event, args, nargs)
-	Widget		canvas;		/* canvas, == calendar drawing area */
-	XButtonEvent	*event;		/* X event, contains position */
-	String		*args;		/* what happened, up/down/motion */
-	int		nargs;		/* # of args, must be 1 */
+static void canvas_callback(
+	Widget		canvas,		/* canvas, == calendar drawing area */
+	XButtonEvent	*event,		/* X event, contains position */
+	String		*args,		/* what happened, up/down/motion */
+	int		nargs)		/* # of args, must be 1 */
 {
 	static struct entry *entry;	/* entry being dragged */
 	static BOOL	warn;		/* just the n-days-ahead copy? */
@@ -495,7 +506,6 @@ static void canvas_callback(canvas, event, args, nargs)
 	struct dragc_s	*dc;		/* drag context for callbacks */
 	int		x, y, xs, ys;	/* new item start and size */
 	int		dx, dy;		/* movement since initial press */
-	int		u;		/* index into user[] array */
 	char		buf[1024];	/* for date string */
 	int		i;
 
@@ -530,7 +540,7 @@ static void canvas_callback(canvas, event, args, nargs)
 		if (dc->view == 'o' && mode == M_RIGHT && entry->rep_every
 						&& entry->rep_every != 86400)
 			print_button(dc->info,
-				"Cannot resize entry with nondaily repeat");
+				_("Cannot resize entry with nondaily repeat"));
 		else if (!moving) {
 			x = abs(event->x - down_x);
 			y = abs(event->y - down_y);
@@ -543,9 +553,9 @@ static void canvas_callback(canvas, event, args, nargs)
 					return;
 				clone_entry(&edit.entry, entry);
 				if (!server_entry_op(&edit.entry, 'l')) {
-					create_error_popup(0, 0, "%s\n%s\n",
-					    "Somebody else is editing this ",
-					    "entry. Please try again later.");
+					create_error_popup(0, 0,
+					  _("Somebody else is editing this "\
+					    "entry. Please try again later."));
 					return;
 				}
 				edit.editing  = TRUE;
@@ -613,7 +623,7 @@ static void canvas_callback(canvas, event, args, nargs)
 						   mktimestring(time, FALSE));
 			return;
 		}
-		sprintf(buf, warn ? "Advance warning: %s" : "%s",
+		sprintf(buf, warn ? _("Advance warning: %s") : "%s",
 						mkdatestring(trigger));
 		if (entry->rep_last > entry->time && !warn)
 			sprintf(buf+strlen(buf), " - %s",
@@ -636,7 +646,7 @@ static void canvas_callback(canvas, event, args, nargs)
 							event->x, event->y);
 			if (m != M_OUTSIDE && m != M_LEFT && m != M_RIGHT)
 				print_button(dc->info,
-						"Cannot move there, aborted.");
+					_("Cannot move there, aborted."));
 			else {
 				drag_entry(dc->view, mode, time0, time);
 				confirm_new_entry();
@@ -666,11 +676,11 @@ static void canvas_callback(canvas, event, args, nargs)
  * appointment.
  */
 
-static void drag_entry(view, mode, time0, time)
-	int		view;		/* current view: 'm'=month, ... */
-	MOUSE		mode;		/* what's being moved: M_LEFT? */
-	time_t		time0;		/* mouse time when first pressed */
-	time_t		time;		/* current mouse time */
+static void drag_entry(
+	int		view,		/* current view: 'm'=month, ... */
+	MOUSE		mode,		/* what's being moved: M_LEFT? */
+	time_t		time0,		/* mouse time when first pressed */
+	time_t		time)		/* current mouse time */
 {
 	time_t		mod;		/* unit of movement, 5 min or 1 day */
 	time_t		d_t;		/* time+date difference */
@@ -708,13 +718,13 @@ static void drag_entry(view, mode, time0, time)
  * must be called in draw-undraw pairs.
  */
 
-static void draw_rubberband(canvas, draw, x, y, xs, ys)
-	Widget		canvas;		/* drawing area to draw into */
-	BOOL		draw;		/* draw or undraw */
-	int		x;		/* position of box */
-	int		y;
-	int		xs;		/* size of box */
-	int		ys;
+static void draw_rubberband(
+	Widget		canvas,		/* drawing area to draw into */
+	BOOL		draw,		/* draw or undraw */
+	int		x,		/* position of box */
+	int		y,
+	int		xs,		/* size of box */
+	int		ys)
 {
 	static BOOL	is_drawn;	/* TRUE if rubber band exists */
 	static int	lx,ly,lxs,lys;	/* drawn rubberband */
